{% if page.parent %}
{% with page=page.parent %}
{% include "components/breadcrumbs.html" %}
{% endwith %}
<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor"
    stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="lucide lucide-chevron-right h-3.5 w-3.5">
    <path d="m9 18 6-6-6-6"></path>
</svg>
<div class="text-foreground">{{ page.title }}</div>
{% else %}
<span class="truncate">{{ page.title }}</span>
{% endif %}