<!DOCTYPE html>
<html lang="en">

<head>
    <script>
        // for search plugin notably
        const base_url = "{{ config.site_url }}";
    </script>
    {% include "templates/dark.html" %}


    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>{% if page.title %}{{ page.title }} - {% endif %}{{ config.site_name }}</title>
    {% include "templates/seo.html" %}

    {%- if config.theme.favicon %}
    <link rel="icon" href="{{ config.theme.favicon | url }}">
    {%- else %}
    <link rel="icon" href="{{ 'img/favicon.ico' | url }}">
    {%- endif %}

    <link href="{{ 'css/base.css' | url }}" rel="stylesheet">
    <link href="{{ 'css/geist.css' | url }}" rel="stylesheet">

    {% if "codehilite" in config.markdown_extensions %}
    {% include "templates/pygments.html" %}
    {% endif %}

    {%- for path in config.extra_css %}
    <link href="{{ path | url }}" rel="stylesheet">
    {%- endfor %}

    {% if page.meta.extra_css %}
    {%- for path in page.meta.extra_css %}
    <link href="{{ path | url }}" rel="stylesheet">
    {%- endfor %}
    {% endif %}

    <script src="{{ 'js/callbacks.js' | url }}"></script>

    {% if "pymdownx.arithmatex" in config.markdown_extensions %}
    {% include "templates/katex.html" %}
    {% endif %}

    {% if "shadcn.extensions.echarts.alpha" in config.markdown_extensions %}
    {% include "templates/echarts.html" %}
    {% endif %}

    {% if "shadcn/excalidraw" in config.plugins and is_dev_server %}
    {% include "templates/excalidraw.html" %}
    {% endif %}

</head>

<body
    class="text-foreground group/body overscroll-none font-sans antialiased [--footer-height:calc(var(--spacing)*14)] [--header-height:calc(var(--spacing)*14)] xl:[--footer-height:calc(var(--spacing)*24)] theme-default">
    <div id="inner-body" class="bg-background relative z-10 flex min-h-svh flex-col">
        {% include "templates/header.html" %}
        <main class="flex flex-1 flex-col">
            <div class="container-wrapper flex flex-1 flex-col px-2">
                <div data-slot="sidebar-wrapper" style="--sidebar-width: 16rem; --sidebar-width-icon: 3rem;"
                    class="group/sidebar-wrapper has-data-[variant=inset]:bg-sidebar flex w-full 3xl:fixed:container 3xl:fixed:px-3 min-h-min flex-1 items-start px-0 [--sidebar-width:220px] [--top-spacing:0] lg:grid lg:grid-cols-[var(--sidebar-width)_minmax(0,1fr)] lg:[--sidebar-width:240px] lg:[--top-spacing:calc(var(--spacing)*4)]">
                    <div data-slot="sidebar"
                        class="text-sidebar-foreground w-(--sidebar-width) flex-col sticky top-[calc(var(--header-height)+1px)] z-30 hidden h-[calc(100svh-var(--header-height)-var(--footer-height))] bg-transparent lg:flex">
                        <div data-slot="sidebar-content" data-sidebar="content"
                            class="flex min-h-0 flex-1 flex-col gap-2 overflow-auto group-data-[collapsible=icon]:overflow-hidden no-scrollbar px-2 pb-12">
                            <div class="h-(--top-spacing) shrink-0"></div>
                            {% include "templates/sidebar.html" %}
                        </div>
                    </div>
                    <div class="h-full w-full">
                        <div data-slot="docs" class="flex items-stretch text-[1.05rem] sm:text-[15px] xl:w-full">
                            <div class="flex min-w-0 flex-1 flex-col">
                                <div class="h-(--top-spacing) shrink-0"></div>
                                {% include "templates/page.html" %}
                                {% include "templates/bottom_navigation.html" %}
                                {% include "templates/bottom_sidebar.html" %}
                            </div>
                            <div
                                class="sticky top-[calc(var(--header-height)+1px)] z-30 ml-auto hidden h-[calc(100svh-var(--header-height)-var(--footer-height))] w-72 flex-col gap-4 overflow-hidden overscroll-none pb-8 xl:flex">
                                <div class="h-(--top-spacing) shrink-0"></div>
                                {% include "templates/toc.html" %}
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </main>
        {% include "templates/footer.html" %}
    </div>


    {%- for script in config.extra_javascript %}
    {% include "templates/script.html" %}
    {%- endfor %}

    {% if page.meta.extra_javascript %}
    {%- for script in page.meta.extra_javascript %}
    {% include "templates/script.html" %}
    {%- endfor %}
    {% endif %}

    <script src="{{ 'js/copy-button.js' | url }}"></script>
    <script>updatePygmentsStylesheet();</script>
    {% if config.theme.show_stargazers %}
    <script>fetchStargazers("{{ config.repo_url }}");</script>
    {% endif %}
    {% if "mkdocstrings" in config.plugins %}
    {% include "templates/mkdocstrings.html" %}
    {% endif %}
    {% if "shadcn.extensions.codexec" in config.markdown_extensions %}
    {% include "templates/codexec.html" %}
    {% endif %}
    {% include "templates/speculation_rules.html" %}
</body>

</html>