{% if config.theme.icon %}
{% if (config.theme.icon | file_exists) or (config.theme.icon | is_http_url) %}
<img class="size-5" src="{{ config.theme.icon | url }}" alt="icon">
{% else %}
{{ config.theme.icon | iconify }}
{% endif %}
{% else %}
{% with override_class="size-5" %}
{% include "icons/shadcn.svg" %}
{% endwith %}
{% endif %}