<li data-slot="sidebar-menu-item" data-sidebar="menu-item" class="group/menu-item relative">
    <a data-slot="sidebar-menu-button" data-active="{{ '%s' % sidebar_item.active|lower }}" data-sidebar="menu-button"
        data-size="default" href="{{ sidebar_item.abs_url }}"
        class="hover:bg-sidebar-accent hover:text-sidebar-accent-foreground peer/menu-button flex items-center gap-2 rounded-md p-2 text-left outline-hidden ring-sidebar-ring transition-[width,height,padding] focus-visible:ring-2 active:bg-sidebar-accent active:text-sidebar-accent-foreground disabled:pointer-events-none disabled:opacity-50 group-has-data-[sidebar=menu-action]/menu-item:pr-8 aria-disabled:pointer-events-none aria-disabled:opacity-50 data-[active=true]:font-medium data-[active=true]:text-sidebar-accent-foreground data-[state=open]:hover:bg-sidebar-accent data-[state=open]:hover:text-sidebar-accent-foreground group-data-[collapsible=icon]:size-8! group-data-[collapsible=icon]:p-2! [&>span:last-child]:truncate [&>svg]:size-4 [&>svg]:shrink-0 data-[active=true]:bg-accent data-[active=true]:border-accent 3xl:fixed:w-full 3xl:fixed:max-w-48 relative h-[30px] w-fit overflow-visible border border-transparent text-[0.8rem] font-medium after:absolute after:inset-x-0 after:-inset-y-1 after:z-0 after:rounded-md">

        {% if sidebar_item.meta and sidebar_item.meta.sidebar_title %}
        {{ sidebar_item.meta.sidebar_title }}
        {% else %}
        {{ sidebar_item.title }}
        {% endif %}

        {% if sidebar_item.meta and sidebar_item.meta.new %}
        {% with tag_content = "New" %}
        {% include "components/tag.html" %}
        {% endwith %}
        {% endif %}

        {% if sidebar_item.meta and sidebar_item.meta.alpha %}
        {% with tag_content = "Alpha" %}
        {% include "components/tag.html" %}
        {% endwith %}
        {% endif %}

        {% if sidebar_item.meta and sidebar_item.meta.beta %}
        {% with tag_content = "Beta" %}
        {% include "components/tag.html" %}
        {% endwith %}
        {% endif %}
    </a>
</li>