pre { line-height: 125%; }
td.linenos .normal { color: inherit; background-color: transparent; padding-left: 5px; padding-right: 5px; }
span.linenos { color: inherit; background-color: transparent; padding-left: 5px; padding-right: 5px; }
td.linenos .special { color: #000000; background-color: #ffffc0; padding-left: 5px; padding-right: 5px; }
span.linenos.special { color: #000000; background-color: #ffffc0; padding-left: 5px; padding-right: 5px; }
.codehilite .hll { background-color: #ffffcc }
.codehilite { background: #ffffff; }
.codehilite .c { color: #008000 } /* Comment */
.codehilite .err { border: 1px solid #F00 } /* Error */
.codehilite .k { color: #00F } /* Keyword */
.codehilite .ch { color: #008000 } /* Comment.Hashbang */
.codehilite .cm { color: #008000 } /* Comment.Multiline */
.codehilite .cp { color: #00F } /* Comment.Preproc */
.codehilite .cpf { color: #008000 } /* Comment.PreprocFile */
.codehilite .c1 { color: #008000 } /* Comment.Single */
.codehilite .cs { color: #008000 } /* Comment.Special */
.codehilite .ge { font-style: italic } /* Generic.Emph */
.codehilite .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite .gh { font-weight: bold } /* Generic.Heading */
.codehilite .gp { font-weight: bold } /* Generic.Prompt */
.codehilite .gs { font-weight: bold } /* Generic.Strong */
.codehilite .gu { font-weight: bold } /* Generic.Subheading */
.codehilite .kc { color: #00F } /* Keyword.Constant */
.codehilite .kd { color: #00F } /* Keyword.Declaration */
.codehilite .kn { color: #00F } /* Keyword.Namespace */
.codehilite .kp { color: #00F } /* Keyword.Pseudo */
.codehilite .kr { color: #00F } /* Keyword.Reserved */
.codehilite .kt { color: #2B91AF } /* Keyword.Type */
.codehilite .s { color: #A31515 } /* Literal.String */
.codehilite .nc { color: #2B91AF } /* Name.Class */
.codehilite .ow { color: #00F } /* Operator.Word */
.codehilite .sa { color: #A31515 } /* Literal.String.Affix */
.codehilite .sb { color: #A31515 } /* Literal.String.Backtick */
.codehilite .sc { color: #A31515 } /* Literal.String.Char */
.codehilite .dl { color: #A31515 } /* Literal.String.Delimiter */
.codehilite .sd { color: #A31515 } /* Literal.String.Doc */
.codehilite .s2 { color: #A31515 } /* Literal.String.Double */
.codehilite .se { color: #A31515 } /* Literal.String.Escape */
.codehilite .sh { color: #A31515 } /* Literal.String.Heredoc */
.codehilite .si { color: #A31515 } /* Literal.String.Interpol */
.codehilite .sx { color: #A31515 } /* Literal.String.Other */
.codehilite .sr { color: #A31515 } /* Literal.String.Regex */
.codehilite .s1 { color: #A31515 } /* Literal.String.Single */
.codehilite .ss { color: #A31515 } /* Literal.String.Symbol */