<!-- katex -->
<link rel="stylesheet" href="{{ 'css/katex.min.css' | url }}">
<!-- The loading of KaTeX is deferred to speed up page rendering -->
<script defer src="{{ 'js/katex.min.js' | url }}"></script>
<!-- To automatically render math in text elements, include the auto-render extension: -->
<script defer src="{{ 'js/auto-render.min.js' | url }}"
    onload='renderMathInElement(document.body, {{ ((config.theme.katex_options or "{}") | tojson) }});'></script>