pre { line-height: 125%; }
td.linenos .normal { color: inherit; background-color: transparent; padding-left: 5px; padding-right: 5px; }
span.linenos { color: inherit; background-color: transparent; padding-left: 5px; padding-right: 5px; }
td.linenos .special { color: #000000; background-color: #ffffc0; padding-left: 5px; padding-right: 5px; }
span.linenos.special { color: #000000; background-color: #ffffc0; padding-left: 5px; padding-right: 5px; }
.codehilite .hll { background-color: #ffffcc }
.codehilite { background: #ffffff; }
.codehilite .c { color: #177500 } /* Comment */
.codehilite .err { color: #000 } /* Error */
.codehilite .k { color: #A90D91 } /* Keyword */
.codehilite .l { color: #1C01CE } /* Literal */
.codehilite .n { color: #000 } /* Name */
.codehilite .o { color: #000 } /* Operator */
.codehilite .ch { color: #177500 } /* Comment.Hashbang */
.codehilite .cm { color: #177500 } /* Comment.Multiline */
.codehilite .cp { color: #633820 } /* Comment.Preproc */
.codehilite .cpf { color: #177500 } /* Comment.PreprocFile */
.codehilite .c1 { color: #177500 } /* Comment.Single */
.codehilite .cs { color: #177500 } /* Comment.Special */
.codehilite .kc { color: #A90D91 } /* Keyword.Constant */
.codehilite .kd { color: #A90D91 } /* Keyword.Declaration */
.codehilite .kn { color: #A90D91 } /* Keyword.Namespace */
.codehilite .kp { color: #A90D91 } /* Keyword.Pseudo */
.codehilite .kr { color: #A90D91 } /* Keyword.Reserved */
.codehilite .kt { color: #A90D91 } /* Keyword.Type */
.codehilite .ld { color: #1C01CE } /* Literal.Date */
.codehilite .m { color: #1C01CE } /* Literal.Number */
.codehilite .s { color: #C41A16 } /* Literal.String */
.codehilite .na { color: #836C28 } /* Name.Attribute */
.codehilite .nb { color: #A90D91 } /* Name.Builtin */
.codehilite .nc { color: #3F6E75 } /* Name.Class */
.codehilite .no { color: #000 } /* Name.Constant */
.codehilite .nd { color: #000 } /* Name.Decorator */
.codehilite .ni { color: #000 } /* Name.Entity */
.codehilite .ne { color: #000 } /* Name.Exception */
.codehilite .nf { color: #000 } /* Name.Function */
.codehilite .nl { color: #000 } /* Name.Label */
.codehilite .nn { color: #000 } /* Name.Namespace */
.codehilite .nx { color: #000 } /* Name.Other */
.codehilite .py { color: #000 } /* Name.Property */
.codehilite .nt { color: #000 } /* Name.Tag */
.codehilite .nv { color: #000 } /* Name.Variable */
.codehilite .ow { color: #000 } /* Operator.Word */
.codehilite .mb { color: #1C01CE } /* Literal.Number.Bin */
.codehilite .mf { color: #1C01CE } /* Literal.Number.Float */
.codehilite .mh { color: #1C01CE } /* Literal.Number.Hex */
.codehilite .mi { color: #1C01CE } /* Literal.Number.Integer */
.codehilite .mo { color: #1C01CE } /* Literal.Number.Oct */
.codehilite .sa { color: #C41A16 } /* Literal.String.Affix */
.codehilite .sb { color: #C41A16 } /* Literal.String.Backtick */
.codehilite .sc { color: #2300CE } /* Literal.String.Char */
.codehilite .dl { color: #C41A16 } /* Literal.String.Delimiter */
.codehilite .sd { color: #C41A16 } /* Literal.String.Doc */
.codehilite .s2 { color: #C41A16 } /* Literal.String.Double */
.codehilite .se { color: #C41A16 } /* Literal.String.Escape */
.codehilite .sh { color: #C41A16 } /* Literal.String.Heredoc */
.codehilite .si { color: #C41A16 } /* Literal.String.Interpol */
.codehilite .sx { color: #C41A16 } /* Literal.String.Other */
.codehilite .sr { color: #C41A16 } /* Literal.String.Regex */
.codehilite .s1 { color: #C41A16 } /* Literal.String.Single */
.codehilite .ss { color: #C41A16 } /* Literal.String.Symbol */
.codehilite .bp { color: #5B269A } /* Name.Builtin.Pseudo */
.codehilite .fm { color: #000 } /* Name.Function.Magic */
.codehilite .vc { color: #000 } /* Name.Variable.Class */
.codehilite .vg { color: #000 } /* Name.Variable.Global */
.codehilite .vi { color: #000 } /* Name.Variable.Instance */
.codehilite .vm { color: #000 } /* Name.Variable.Magic */
.codehilite .il { color: #1C01CE } /* Literal.Number.Integer.Long */