{% if config.theme.pygments_style %}
{% if config.theme.pygments_style is string %}
<link id="pygments-light" href="{{ ('css/pygments/' + config.theme.pygments_style + '.css') | url }}" rel="stylesheet">
{% else %}
<link id="pygments-light" rel="stylesheet"
    href="{{ ('css/pygments/' + config.theme.pygments_style.light + '.css') | url }}">
<link id="pygments-dark" rel="stylesheet"
    href="{{ ('css/pygments/' + config.theme.pygments_style.dark + '.css') | url }}"
    media="(prefers-color-scheme: dark)">
{% endif %}
{% endif %}