.codehilite.abap .hll { background-color: #ffffcc }
.codehilite.abap { background: #ffffff; }
.codehilite.abap .c { color: #888; font-style: italic } /* Comment */
.codehilite.abap .err { color: #F00 } /* Error */
.codehilite.abap .k { color: #00F } /* Keyword */
.codehilite.abap .n { color: #000 } /* Name */
.codehilite.abap .ch { color: #888; font-style: italic } /* Comment.Hashbang */
.codehilite.abap .cm { color: #888; font-style: italic } /* Comment.Multiline */
.codehilite.abap .cp { color: #888; font-style: italic } /* Comment.Preproc */
.codehilite.abap .cpf { color: #888; font-style: italic } /* Comment.PreprocFile */
.codehilite.abap .c1 { color: #888; font-style: italic } /* Comment.Single */
.codehilite.abap .cs { color: #888; font-style: italic } /* Comment.Special */
.codehilite.abap .kc { color: #00F } /* Keyword.Constant */
.codehilite.abap .kd { color: #00F } /* Keyword.Declaration */
.codehilite.abap .kn { color: #00F } /* Keyword.Namespace */
.codehilite.abap .kp { color: #00F } /* Keyword.Pseudo */
.codehilite.abap .kr { color: #00F } /* Keyword.Reserved */
.codehilite.abap .kt { color: #00F } /* Keyword.Type */
.codehilite.abap .m { color: #3AF } /* Literal.Number */
.codehilite.abap .s { color: #5A2 } /* Literal.String */
.codehilite.abap .na { color: #000 } /* Name.Attribute */
.codehilite.abap .nb { color: #000 } /* Name.Builtin */
.codehilite.abap .nc { color: #000 } /* Name.Class */
.codehilite.abap .no { color: #000 } /* Name.Constant */
.codehilite.abap .nd { color: #000 } /* Name.Decorator */
.codehilite.abap .ni { color: #000 } /* Name.Entity */
.codehilite.abap .ne { color: #000 } /* Name.Exception */
.codehilite.abap .nf { color: #000 } /* Name.Function */
.codehilite.abap .nl { color: #000 } /* Name.Label */
.codehilite.abap .nn { color: #000 } /* Name.Namespace */
.codehilite.abap .nx { color: #000 } /* Name.Other */
.codehilite.abap .py { color: #000 } /* Name.Property */
.codehilite.abap .nt { color: #000 } /* Name.Tag */
.codehilite.abap .nv { color: #000 } /* Name.Variable */
.codehilite.abap .ow { color: #00F } /* Operator.Word */
.codehilite.abap .mb { color: #3AF } /* Literal.Number.Bin */
.codehilite.abap .mf { color: #3AF } /* Literal.Number.Float */
.codehilite.abap .mh { color: #3AF } /* Literal.Number.Hex */
.codehilite.abap .mi { color: #3AF } /* Literal.Number.Integer */
.codehilite.abap .mo { color: #3AF } /* Literal.Number.Oct */
.codehilite.abap .sa { color: #5A2 } /* Literal.String.Affix */
.codehilite.abap .sb { color: #5A2 } /* Literal.String.Backtick */
.codehilite.abap .sc { color: #5A2 } /* Literal.String.Char */
.codehilite.abap .dl { color: #5A2 } /* Literal.String.Delimiter */
.codehilite.abap .sd { color: #5A2 } /* Literal.String.Doc */
.codehilite.abap .s2 { color: #5A2 } /* Literal.String.Double */
.codehilite.abap .se { color: #5A2 } /* Literal.String.Escape */
.codehilite.abap .sh { color: #5A2 } /* Literal.String.Heredoc */
.codehilite.abap .si { color: #5A2 } /* Literal.String.Interpol */
.codehilite.abap .sx { color: #5A2 } /* Literal.String.Other */
.codehilite.abap .sr { color: #5A2 } /* Literal.String.Regex */
.codehilite.abap .s1 { color: #5A2 } /* Literal.String.Single */
.codehilite.abap .ss { color: #5A2 } /* Literal.String.Symbol */
.codehilite.abap .bp { color: #000 } /* Name.Builtin.Pseudo */
.codehilite.abap .fm { color: #000 } /* Name.Function.Magic */
.codehilite.abap .vc { color: #000 } /* Name.Variable.Class */
.codehilite.abap .vg { color: #000 } /* Name.Variable.Global */
.codehilite.abap .vi { color: #000 } /* Name.Variable.Instance */
.codehilite.abap .vm { color: #000 } /* Name.Variable.Magic */
.codehilite.abap .il { color: #3AF } /* Literal.Number.Integer.Long */
.codehilite.algol .hll { background-color: #ffffcc }
.codehilite.algol { background: #ffffff; }
.codehilite.algol .c { color: #888; font-style: italic } /* Comment */
.codehilite.algol .err { border: 1px solid #F00 } /* Error */
.codehilite.algol .k { font-weight: bold; text-decoration: underline } /* Keyword */
.codehilite.algol .ch { color: #888; font-style: italic } /* Comment.Hashbang */
.codehilite.algol .cm { color: #888; font-style: italic } /* Comment.Multiline */
.codehilite.algol .cp { color: #888; font-weight: bold } /* Comment.Preproc */
.codehilite.algol .cpf { color: #888; font-style: italic } /* Comment.PreprocFile */
.codehilite.algol .c1 { color: #888; font-style: italic } /* Comment.Single */
.codehilite.algol .cs { color: #888; font-weight: bold } /* Comment.Special */
.codehilite.algol .kc { font-weight: bold; text-decoration: underline } /* Keyword.Constant */
.codehilite.algol .kd { font-weight: bold; font-style: italic; text-decoration: underline } /* Keyword.Declaration */
.codehilite.algol .kn { font-weight: bold; text-decoration: underline } /* Keyword.Namespace */
.codehilite.algol .kp { font-weight: bold; text-decoration: underline } /* Keyword.Pseudo */
.codehilite.algol .kr { font-weight: bold; text-decoration: underline } /* Keyword.Reserved */
.codehilite.algol .kt { font-weight: bold; text-decoration: underline } /* Keyword.Type */
.codehilite.algol .s { color: #666; font-style: italic } /* Literal.String */
.codehilite.algol .nb { font-weight: bold; font-style: italic } /* Name.Builtin */
.codehilite.algol .nc { color: #666; font-weight: bold; font-style: italic } /* Name.Class */
.codehilite.algol .no { color: #666; font-weight: bold; font-style: italic } /* Name.Constant */
.codehilite.algol .nf { color: #666; font-weight: bold; font-style: italic } /* Name.Function */
.codehilite.algol .nn { color: #666; font-weight: bold; font-style: italic } /* Name.Namespace */
.codehilite.algol .nv { color: #666; font-weight: bold; font-style: italic } /* Name.Variable */
.codehilite.algol .ow { font-weight: bold } /* Operator.Word */
.codehilite.algol .sa { color: #666; font-style: italic } /* Literal.String.Affix */
.codehilite.algol .sb { color: #666; font-style: italic } /* Literal.String.Backtick */
.codehilite.algol .sc { color: #666; font-style: italic } /* Literal.String.Char */
.codehilite.algol .dl { color: #666; font-style: italic } /* Literal.String.Delimiter */
.codehilite.algol .sd { color: #666; font-style: italic } /* Literal.String.Doc */
.codehilite.algol .s2 { color: #666; font-style: italic } /* Literal.String.Double */
.codehilite.algol .se { color: #666; font-style: italic } /* Literal.String.Escape */
.codehilite.algol .sh { color: #666; font-style: italic } /* Literal.String.Heredoc */
.codehilite.algol .si { color: #666; font-style: italic } /* Literal.String.Interpol */
.codehilite.algol .sx { color: #666; font-style: italic } /* Literal.String.Other */
.codehilite.algol .sr { color: #666; font-style: italic } /* Literal.String.Regex */
.codehilite.algol .s1 { color: #666; font-style: italic } /* Literal.String.Single */
.codehilite.algol .ss { color: #666; font-style: italic } /* Literal.String.Symbol */
.codehilite.algol .bp { font-weight: bold; font-style: italic } /* Name.Builtin.Pseudo */
.codehilite.algol .fm { color: #666; font-weight: bold; font-style: italic } /* Name.Function.Magic */
.codehilite.algol .vc { color: #666; font-weight: bold; font-style: italic } /* Name.Variable.Class */
.codehilite.algol .vg { color: #666; font-weight: bold; font-style: italic } /* Name.Variable.Global */
.codehilite.algol .vi { color: #666; font-weight: bold; font-style: italic } /* Name.Variable.Instance */
.codehilite.algol .vm { color: #666; font-weight: bold; font-style: italic } /* Name.Variable.Magic */
.codehilite.algol_nu .hll { background-color: #ffffcc }
.codehilite.algol_nu { background: #ffffff; }
.codehilite.algol_nu .c { color: #888; font-style: italic } /* Comment */
.codehilite.algol_nu .err { border: 1px solid #F00 } /* Error */
.codehilite.algol_nu .k { font-weight: bold } /* Keyword */
.codehilite.algol_nu .ch { color: #888; font-style: italic } /* Comment.Hashbang */
.codehilite.algol_nu .cm { color: #888; font-style: italic } /* Comment.Multiline */
.codehilite.algol_nu .cp { color: #888; font-weight: bold } /* Comment.Preproc */
.codehilite.algol_nu .cpf { color: #888; font-style: italic } /* Comment.PreprocFile */
.codehilite.algol_nu .c1 { color: #888; font-style: italic } /* Comment.Single */
.codehilite.algol_nu .cs { color: #888; font-weight: bold } /* Comment.Special */
.codehilite.algol_nu .kc { font-weight: bold } /* Keyword.Constant */
.codehilite.algol_nu .kd { font-weight: bold; font-style: italic } /* Keyword.Declaration */
.codehilite.algol_nu .kn { font-weight: bold } /* Keyword.Namespace */
.codehilite.algol_nu .kp { font-weight: bold } /* Keyword.Pseudo */
.codehilite.algol_nu .kr { font-weight: bold } /* Keyword.Reserved */
.codehilite.algol_nu .kt { font-weight: bold } /* Keyword.Type */
.codehilite.algol_nu .s { color: #666; font-style: italic } /* Literal.String */
.codehilite.algol_nu .nb { font-weight: bold; font-style: italic } /* Name.Builtin */
.codehilite.algol_nu .nc { color: #666; font-weight: bold; font-style: italic } /* Name.Class */
.codehilite.algol_nu .no { color: #666; font-weight: bold; font-style: italic } /* Name.Constant */
.codehilite.algol_nu .nf { color: #666; font-weight: bold; font-style: italic } /* Name.Function */
.codehilite.algol_nu .nn { color: #666; font-weight: bold; font-style: italic } /* Name.Namespace */
.codehilite.algol_nu .nv { color: #666; font-weight: bold; font-style: italic } /* Name.Variable */
.codehilite.algol_nu .ow { font-weight: bold } /* Operator.Word */
.codehilite.algol_nu .sa { color: #666; font-style: italic } /* Literal.String.Affix */
.codehilite.algol_nu .sb { color: #666; font-style: italic } /* Literal.String.Backtick */
.codehilite.algol_nu .sc { color: #666; font-style: italic } /* Literal.String.Char */
.codehilite.algol_nu .dl { color: #666; font-style: italic } /* Literal.String.Delimiter */
.codehilite.algol_nu .sd { color: #666; font-style: italic } /* Literal.String.Doc */
.codehilite.algol_nu .s2 { color: #666; font-style: italic } /* Literal.String.Double */
.codehilite.algol_nu .se { color: #666; font-style: italic } /* Literal.String.Escape */
.codehilite.algol_nu .sh { color: #666; font-style: italic } /* Literal.String.Heredoc */
.codehilite.algol_nu .si { color: #666; font-style: italic } /* Literal.String.Interpol */
.codehilite.algol_nu .sx { color: #666; font-style: italic } /* Literal.String.Other */
.codehilite.algol_nu .sr { color: #666; font-style: italic } /* Literal.String.Regex */
.codehilite.algol_nu .s1 { color: #666; font-style: italic } /* Literal.String.Single */
.codehilite.algol_nu .ss { color: #666; font-style: italic } /* Literal.String.Symbol */
.codehilite.algol_nu .bp { font-weight: bold; font-style: italic } /* Name.Builtin.Pseudo */
.codehilite.algol_nu .fm { color: #666; font-weight: bold; font-style: italic } /* Name.Function.Magic */
.codehilite.algol_nu .vc { color: #666; font-weight: bold; font-style: italic } /* Name.Variable.Class */
.codehilite.algol_nu .vg { color: #666; font-weight: bold; font-style: italic } /* Name.Variable.Global */
.codehilite.algol_nu .vi { color: #666; font-weight: bold; font-style: italic } /* Name.Variable.Instance */
.codehilite.algol_nu .vm { color: #666; font-weight: bold; font-style: italic } /* Name.Variable.Magic */
.codehilite.arduino .hll { background-color: #ffffcc }
.codehilite.arduino { background: #ffffff; }
.codehilite.arduino .c { color: #95A5A6 } /* Comment */
.codehilite.arduino .err { color: #A61717 } /* Error */
.codehilite.arduino .k { color: #728E00 } /* Keyword */
.codehilite.arduino .n { color: #434F54 } /* Name */
.codehilite.arduino .o { color: #728E00 } /* Operator */
.codehilite.arduino .ch { color: #95A5A6 } /* Comment.Hashbang */
.codehilite.arduino .cm { color: #95A5A6 } /* Comment.Multiline */
.codehilite.arduino .cp { color: #728E00 } /* Comment.Preproc */
.codehilite.arduino .cpf { color: #95A5A6 } /* Comment.PreprocFile */
.codehilite.arduino .c1 { color: #95A5A6 } /* Comment.Single */
.codehilite.arduino .cs { color: #95A5A6 } /* Comment.Special */
.codehilite.arduino .kc { color: #00979D } /* Keyword.Constant */
.codehilite.arduino .kd { color: #728E00 } /* Keyword.Declaration */
.codehilite.arduino .kn { color: #728E00 } /* Keyword.Namespace */
.codehilite.arduino .kp { color: #00979D } /* Keyword.Pseudo */
.codehilite.arduino .kr { color: #00979D } /* Keyword.Reserved */
.codehilite.arduino .kt { color: #00979D } /* Keyword.Type */
.codehilite.arduino .m { color: #8A7B52 } /* Literal.Number */
.codehilite.arduino .s { color: #7F8C8D } /* Literal.String */
.codehilite.arduino .na { color: #434F54 } /* Name.Attribute */
.codehilite.arduino .nb { color: #728E00 } /* Name.Builtin */
.codehilite.arduino .nc { color: #434F54 } /* Name.Class */
.codehilite.arduino .no { color: #434F54 } /* Name.Constant */
.codehilite.arduino .nd { color: #434F54 } /* Name.Decorator */
.codehilite.arduino .ni { color: #434F54 } /* Name.Entity */
.codehilite.arduino .ne { color: #434F54 } /* Name.Exception */
.codehilite.arduino .nf { color: #D35400 } /* Name.Function */
.codehilite.arduino .nl { color: #434F54 } /* Name.Label */
.codehilite.arduino .nn { color: #434F54 } /* Name.Namespace */
.codehilite.arduino .nx { color: #728E00 } /* Name.Other */
.codehilite.arduino .py { color: #434F54 } /* Name.Property */
.codehilite.arduino .nt { color: #434F54 } /* Name.Tag */
.codehilite.arduino .nv { color: #434F54 } /* Name.Variable */
.codehilite.arduino .ow { color: #728E00 } /* Operator.Word */
.codehilite.arduino .mb { color: #8A7B52 } /* Literal.Number.Bin */
.codehilite.arduino .mf { color: #8A7B52 } /* Literal.Number.Float */
.codehilite.arduino .mh { color: #8A7B52 } /* Literal.Number.Hex */
.codehilite.arduino .mi { color: #8A7B52 } /* Literal.Number.Integer */
.codehilite.arduino .mo { color: #8A7B52 } /* Literal.Number.Oct */
.codehilite.arduino .sa { color: #7F8C8D } /* Literal.String.Affix */
.codehilite.arduino .sb { color: #7F8C8D } /* Literal.String.Backtick */
.codehilite.arduino .sc { color: #7F8C8D } /* Literal.String.Char */
.codehilite.arduino .dl { color: #7F8C8D } /* Literal.String.Delimiter */
.codehilite.arduino .sd { color: #7F8C8D } /* Literal.String.Doc */
.codehilite.arduino .s2 { color: #7F8C8D } /* Literal.String.Double */
.codehilite.arduino .se { color: #7F8C8D } /* Literal.String.Escape */
.codehilite.arduino .sh { color: #7F8C8D } /* Literal.String.Heredoc */
.codehilite.arduino .si { color: #7F8C8D } /* Literal.String.Interpol */
.codehilite.arduino .sx { color: #7F8C8D } /* Literal.String.Other */
.codehilite.arduino .sr { color: #7F8C8D } /* Literal.String.Regex */
.codehilite.arduino .s1 { color: #7F8C8D } /* Literal.String.Single */
.codehilite.arduino .ss { color: #7F8C8D } /* Literal.String.Symbol */
.codehilite.arduino .bp { color: #728E00 } /* Name.Builtin.Pseudo */
.codehilite.arduino .fm { color: #D35400 } /* Name.Function.Magic */
.codehilite.arduino .vc { color: #434F54 } /* Name.Variable.Class */
.codehilite.arduino .vg { color: #434F54 } /* Name.Variable.Global */
.codehilite.arduino .vi { color: #434F54 } /* Name.Variable.Instance */
.codehilite.arduino .vm { color: #434F54 } /* Name.Variable.Magic */
.codehilite.arduino .il { color: #8A7B52 } /* Literal.Number.Integer.Long */
.codehilite.autumn .hll { background-color: #ffffcc }
.codehilite.autumn { background: #ffffff; }
.codehilite.autumn .c { color: #AAA; font-style: italic } /* Comment */
.codehilite.autumn .err { color: #F00; background-color: #FAA } /* Error */
.codehilite.autumn .k { color: #00A } /* Keyword */
.codehilite.autumn .ch { color: #AAA; font-style: italic } /* Comment.Hashbang */
.codehilite.autumn .cm { color: #AAA; font-style: italic } /* Comment.Multiline */
.codehilite.autumn .cp { color: #4C8317 } /* Comment.Preproc */
.codehilite.autumn .cpf { color: #AAA; font-style: italic } /* Comment.PreprocFile */
.codehilite.autumn .c1 { color: #AAA; font-style: italic } /* Comment.Single */
.codehilite.autumn .cs { color: #00A; font-style: italic } /* Comment.Special */
.codehilite.autumn .gd { color: #A00 } /* Generic.Deleted */
.codehilite.autumn .ge { font-style: italic } /* Generic.Emph */
.codehilite.autumn .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.autumn .gr { color: #A00 } /* Generic.Error */
.codehilite.autumn .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite.autumn .gi { color: #0A0 } /* Generic.Inserted */
.codehilite.autumn .go { color: #888 } /* Generic.Output */
.codehilite.autumn .gp { color: #555 } /* Generic.Prompt */
.codehilite.autumn .gs { font-weight: bold } /* Generic.Strong */
.codehilite.autumn .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite.autumn .gt { color: #A00 } /* Generic.Traceback */
.codehilite.autumn .kc { color: #00A } /* Keyword.Constant */
.codehilite.autumn .kd { color: #00A } /* Keyword.Declaration */
.codehilite.autumn .kn { color: #00A } /* Keyword.Namespace */
.codehilite.autumn .kp { color: #00A } /* Keyword.Pseudo */
.codehilite.autumn .kr { color: #00A } /* Keyword.Reserved */
.codehilite.autumn .kt { color: #0AA } /* Keyword.Type */
.codehilite.autumn .m { color: #099 } /* Literal.Number */
.codehilite.autumn .s { color: #A50 } /* Literal.String */
.codehilite.autumn .na { color: #1E90FF } /* Name.Attribute */
.codehilite.autumn .nb { color: #0AA } /* Name.Builtin */
.codehilite.autumn .nc { color: #0A0; text-decoration: underline } /* Name.Class */
.codehilite.autumn .no { color: #A00 } /* Name.Constant */
.codehilite.autumn .nd { color: #888 } /* Name.Decorator */
.codehilite.autumn .ni { color: #800; font-weight: bold } /* Name.Entity */
.codehilite.autumn .nf { color: #0A0 } /* Name.Function */
.codehilite.autumn .nn { color: #0AA; text-decoration: underline } /* Name.Namespace */
.codehilite.autumn .nt { color: #1E90FF; font-weight: bold } /* Name.Tag */
.codehilite.autumn .nv { color: #A00 } /* Name.Variable */
.codehilite.autumn .ow { color: #00A } /* Operator.Word */
.codehilite.autumn .w { color: #BBB } /* Text.Whitespace */
.codehilite.autumn .mb { color: #099 } /* Literal.Number.Bin */
.codehilite.autumn .mf { color: #099 } /* Literal.Number.Float */
.codehilite.autumn .mh { color: #099 } /* Literal.Number.Hex */
.codehilite.autumn .mi { color: #099 } /* Literal.Number.Integer */
.codehilite.autumn .mo { color: #099 } /* Literal.Number.Oct */
.codehilite.autumn .sa { color: #A50 } /* Literal.String.Affix */
.codehilite.autumn .sb { color: #A50 } /* Literal.String.Backtick */
.codehilite.autumn .sc { color: #A50 } /* Literal.String.Char */
.codehilite.autumn .dl { color: #A50 } /* Literal.String.Delimiter */
.codehilite.autumn .sd { color: #A50 } /* Literal.String.Doc */
.codehilite.autumn .s2 { color: #A50 } /* Literal.String.Double */
.codehilite.autumn .se { color: #A50 } /* Literal.String.Escape */
.codehilite.autumn .sh { color: #A50 } /* Literal.String.Heredoc */
.codehilite.autumn .si { color: #A50 } /* Literal.String.Interpol */
.codehilite.autumn .sx { color: #A50 } /* Literal.String.Other */
.codehilite.autumn .sr { color: #099 } /* Literal.String.Regex */
.codehilite.autumn .s1 { color: #A50 } /* Literal.String.Single */
.codehilite.autumn .ss { color: #00A } /* Literal.String.Symbol */
.codehilite.autumn .bp { color: #0AA } /* Name.Builtin.Pseudo */
.codehilite.autumn .fm { color: #0A0 } /* Name.Function.Magic */
.codehilite.autumn .vc { color: #A00 } /* Name.Variable.Class */
.codehilite.autumn .vg { color: #A00 } /* Name.Variable.Global */
.codehilite.autumn .vi { color: #A00 } /* Name.Variable.Instance */
.codehilite.autumn .vm { color: #A00 } /* Name.Variable.Magic */
.codehilite.autumn .il { color: #099 } /* Literal.Number.Integer.Long */
.codehilite.bw .hll { background-color: #ffffcc }
.codehilite.bw { background: #ffffff; }
.codehilite.bw .c { font-style: italic } /* Comment */
.codehilite.bw .err { border: 1px solid #F00 } /* Error */
.codehilite.bw .k { font-weight: bold } /* Keyword */
.codehilite.bw .ch { font-style: italic } /* Comment.Hashbang */
.codehilite.bw .cm { font-style: italic } /* Comment.Multiline */
.codehilite.bw .cpf { font-style: italic } /* Comment.PreprocFile */
.codehilite.bw .c1 { font-style: italic } /* Comment.Single */
.codehilite.bw .cs { font-style: italic } /* Comment.Special */
.codehilite.bw .ge { font-style: italic } /* Generic.Emph */
.codehilite.bw .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.bw .gh { font-weight: bold } /* Generic.Heading */
.codehilite.bw .gp { font-weight: bold } /* Generic.Prompt */
.codehilite.bw .gs { font-weight: bold } /* Generic.Strong */
.codehilite.bw .gu { font-weight: bold } /* Generic.Subheading */
.codehilite.bw .kc { font-weight: bold } /* Keyword.Constant */
.codehilite.bw .kd { font-weight: bold } /* Keyword.Declaration */
.codehilite.bw .kn { font-weight: bold } /* Keyword.Namespace */
.codehilite.bw .kr { font-weight: bold } /* Keyword.Reserved */
.codehilite.bw .s { font-style: italic } /* Literal.String */
.codehilite.bw .nc { font-weight: bold } /* Name.Class */
.codehilite.bw .ni { font-weight: bold } /* Name.Entity */
.codehilite.bw .ne { font-weight: bold } /* Name.Exception */
.codehilite.bw .nn { font-weight: bold } /* Name.Namespace */
.codehilite.bw .nt { font-weight: bold } /* Name.Tag */
.codehilite.bw .ow { font-weight: bold } /* Operator.Word */
.codehilite.bw .sa { font-style: italic } /* Literal.String.Affix */
.codehilite.bw .sb { font-style: italic } /* Literal.String.Backtick */
.codehilite.bw .sc { font-style: italic } /* Literal.String.Char */
.codehilite.bw .dl { font-style: italic } /* Literal.String.Delimiter */
.codehilite.bw .sd { font-style: italic } /* Literal.String.Doc */
.codehilite.bw .s2 { font-style: italic } /* Literal.String.Double */
.codehilite.bw .se { font-weight: bold; font-style: italic } /* Literal.String.Escape */
.codehilite.bw .sh { font-style: italic } /* Literal.String.Heredoc */
.codehilite.bw .si { font-weight: bold; font-style: italic } /* Literal.String.Interpol */
.codehilite.bw .sx { font-style: italic } /* Literal.String.Other */
.codehilite.bw .sr { font-style: italic } /* Literal.String.Regex */
.codehilite.bw .s1 { font-style: italic } /* Literal.String.Single */
.codehilite.bw .ss { font-style: italic } /* Literal.String.Symbol */
.codehilite.borland .hll { background-color: #ffffcc }
.codehilite.borland { background: #ffffff; }
.codehilite.borland .c { color: #080; font-style: italic } /* Comment */
.codehilite.borland .err { color: #A61717; background-color: #E3D2D2 } /* Error */
.codehilite.borland .k { color: #000080; font-weight: bold } /* Keyword */
.codehilite.borland .ch { color: #080; font-style: italic } /* Comment.Hashbang */
.codehilite.borland .cm { color: #080; font-style: italic } /* Comment.Multiline */
.codehilite.borland .cp { color: #008080 } /* Comment.Preproc */
.codehilite.borland .cpf { color: #080; font-style: italic } /* Comment.PreprocFile */
.codehilite.borland .c1 { color: #080; font-style: italic } /* Comment.Single */
.codehilite.borland .cs { color: #080; font-weight: bold } /* Comment.Special */
.codehilite.borland .gd { color: #000; background-color: #FDD } /* Generic.Deleted */
.codehilite.borland .ge { font-style: italic } /* Generic.Emph */
.codehilite.borland .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.borland .gr { color: #A00 } /* Generic.Error */
.codehilite.borland .gh { color: #999 } /* Generic.Heading */
.codehilite.borland .gi { color: #000; background-color: #DFD } /* Generic.Inserted */
.codehilite.borland .go { color: #888 } /* Generic.Output */
.codehilite.borland .gp { color: #555 } /* Generic.Prompt */
.codehilite.borland .gs { font-weight: bold } /* Generic.Strong */
.codehilite.borland .gu { color: #AAA } /* Generic.Subheading */
.codehilite.borland .gt { color: #A00 } /* Generic.Traceback */
.codehilite.borland .kc { color: #000080; font-weight: bold } /* Keyword.Constant */
.codehilite.borland .kd { color: #000080; font-weight: bold } /* Keyword.Declaration */
.codehilite.borland .kn { color: #000080; font-weight: bold } /* Keyword.Namespace */
.codehilite.borland .kp { color: #000080; font-weight: bold } /* Keyword.Pseudo */
.codehilite.borland .kr { color: #000080; font-weight: bold } /* Keyword.Reserved */
.codehilite.borland .kt { color: #000080; font-weight: bold } /* Keyword.Type */
.codehilite.borland .m { color: #00F } /* Literal.Number */
.codehilite.borland .s { color: #00F } /* Literal.String */
.codehilite.borland .na { color: #F00 } /* Name.Attribute */
.codehilite.borland .nt { color: #000080; font-weight: bold } /* Name.Tag */
.codehilite.borland .ow { font-weight: bold } /* Operator.Word */
.codehilite.borland .w { color: #BBB } /* Text.Whitespace */
.codehilite.borland .mb { color: #00F } /* Literal.Number.Bin */
.codehilite.borland .mf { color: #00F } /* Literal.Number.Float */
.codehilite.borland .mh { color: #00F } /* Literal.Number.Hex */
.codehilite.borland .mi { color: #00F } /* Literal.Number.Integer */
.codehilite.borland .mo { color: #00F } /* Literal.Number.Oct */
.codehilite.borland .sa { color: #00F } /* Literal.String.Affix */
.codehilite.borland .sb { color: #00F } /* Literal.String.Backtick */
.codehilite.borland .sc { color: #800080 } /* Literal.String.Char */
.codehilite.borland .dl { color: #00F } /* Literal.String.Delimiter */
.codehilite.borland .sd { color: #00F } /* Literal.String.Doc */
.codehilite.borland .s2 { color: #00F } /* Literal.String.Double */
.codehilite.borland .se { color: #00F } /* Literal.String.Escape */
.codehilite.borland .sh { color: #00F } /* Literal.String.Heredoc */
.codehilite.borland .si { color: #00F } /* Literal.String.Interpol */
.codehilite.borland .sx { color: #00F } /* Literal.String.Other */
.codehilite.borland .sr { color: #00F } /* Literal.String.Regex */
.codehilite.borland .s1 { color: #00F } /* Literal.String.Single */
.codehilite.borland .ss { color: #00F } /* Literal.String.Symbol */
.codehilite.borland .il { color: #00F } /* Literal.Number.Integer.Long */
.codehilite.coffee .hll { background-color: #ddd0c0 }
.codehilite.coffee { background: #262220; color: #DDD0C0 }
.codehilite.coffee .c { color: #70757A } /* Comment */
.codehilite.coffee .err { color: #AF5F5F } /* Error */
.codehilite.coffee .esc { color: #DDD0C0 } /* Escape */
.codehilite.coffee .g { color: #DDD0C0 } /* Generic */
.codehilite.coffee .k { color: #919191 } /* Keyword */
.codehilite.coffee .l { color: #AF875F } /* Literal */
.codehilite.coffee .n { color: #DDD0C0 } /* Name */
.codehilite.coffee .o { color: #878787 } /* Operator */
.codehilite.coffee .x { color: #DDD0C0 } /* Other */
.codehilite.coffee .p { color: #DDD0C0 } /* Punctuation */
.codehilite.coffee .ch { color: #8F9F9F } /* Comment.Hashbang */
.codehilite.coffee .cm { color: #70757A } /* Comment.Multiline */
.codehilite.coffee .cp { color: #FDD0C0 } /* Comment.Preproc */
.codehilite.coffee .cpf { color: #C9B98F } /* Comment.PreprocFile */
.codehilite.coffee .c1 { color: #70757A } /* Comment.Single */
.codehilite.coffee .cs { color: #AF5F5F } /* Comment.Special */
.codehilite.coffee .gd { color: #BB6868 } /* Generic.Deleted */
.codehilite.coffee .ge { color: #DDD0C0; font-style: italic } /* Generic.Emph */
.codehilite.coffee .ges { color: #DDD0C0 } /* Generic.EmphStrong */
.codehilite.coffee .gr { color: #AF5F5F } /* Generic.Error */
.codehilite.coffee .gh { color: #DDD0C0 } /* Generic.Heading */
.codehilite.coffee .gi { color: #849155 } /* Generic.Inserted */
.codehilite.coffee .go { color: #DDD0C0 } /* Generic.Output */
.codehilite.coffee .gp { color: #DDD0C0 } /* Generic.Prompt */
.codehilite.coffee .gs { color: #DDD0C0; font-weight: bold } /* Generic.Strong */
.codehilite.coffee .gu { color: #DDD0C0 } /* Generic.Subheading */
.codehilite.coffee .gt { color: #AF5F5F } /* Generic.Traceback */
.codehilite.coffee .kc { color: #875F5F } /* Keyword.Constant */
.codehilite.coffee .kd { color: #875F5F } /* Keyword.Declaration */
.codehilite.coffee .kn { color: #875F5F } /* Keyword.Namespace */
.codehilite.coffee .kp { color: #919191 } /* Keyword.Pseudo */
.codehilite.coffee .kr { color: #B46276 } /* Keyword.Reserved */
.codehilite.coffee .kt { color: #AF875F } /* Keyword.Type */
.codehilite.coffee .ld { color: #AF875F } /* Literal.Date */
.codehilite.coffee .m { color: #87AFAF } /* Literal.Number */
.codehilite.coffee .s { color: #C9B98F } /* Literal.String */
.codehilite.coffee .na { color: #DDD0C0 } /* Name.Attribute */
.codehilite.coffee .nb { color: #DDD0C0 } /* Name.Builtin */
.codehilite.coffee .nc { color: #875F5F } /* Name.Class */
.codehilite.coffee .no { color: #AF8787 } /* Name.Constant */
.codehilite.coffee .nd { color: #FDD0C0 } /* Name.Decorator */
.codehilite.coffee .ni { color: #DDD0C0 } /* Name.Entity */
.codehilite.coffee .ne { color: #877575 } /* Name.Exception */
.codehilite.coffee .nf { color: #FDD0C0 } /* Name.Function */
.codehilite.coffee .nl { color: #DDD0C0 } /* Name.Label */
.codehilite.coffee .nn { color: #DDD0C0 } /* Name.Namespace */
.codehilite.coffee .nx { color: #DDD0C0 } /* Name.Other */
.codehilite.coffee .py { color: #DFAF87 } /* Name.Property */
.codehilite.coffee .nt { color: #87AFAF } /* Name.Tag */
.codehilite.coffee .nv { color: #DDD0C0 } /* Name.Variable */
.codehilite.coffee .ow { color: #878787 } /* Operator.Word */
.codehilite.coffee .pm { color: #DDD0C0 } /* Punctuation.Marker */
.codehilite.coffee .w { color: #DDD0C0 } /* Text.Whitespace */
.codehilite.coffee .mb { color: #87AFAF } /* Literal.Number.Bin */
.codehilite.coffee .mf { color: #87AFAF } /* Literal.Number.Float */
.codehilite.coffee .mh { color: #87AFAF } /* Literal.Number.Hex */
.codehilite.coffee .mi { color: #87AFAF } /* Literal.Number.Integer */
.codehilite.coffee .mo { color: #87AFAF } /* Literal.Number.Oct */
.codehilite.coffee .sa { color: #DFAF87 } /* Literal.String.Affix */
.codehilite.coffee .sb { color: #C9B98F } /* Literal.String.Backtick */
.codehilite.coffee .sc { color: #C9B98F } /* Literal.String.Char */
.codehilite.coffee .dl { color: #C9B98F } /* Literal.String.Delimiter */
.codehilite.coffee .sd { color: #878787 } /* Literal.String.Doc */
.codehilite.coffee .s2 { color: #C9B98F } /* Literal.String.Double */
.codehilite.coffee .se { color: #AF5F5F } /* Literal.String.Escape */
.codehilite.coffee .sh { color: #C9B98F } /* Literal.String.Heredoc */
.codehilite.coffee .si { color: #AF5F5F } /* Literal.String.Interpol */
.codehilite.coffee .sx { color: #FDD0C0 } /* Literal.String.Other */
.codehilite.coffee .sr { color: #AF5F5F } /* Literal.String.Regex */
.codehilite.coffee .s1 { color: #C9B98F } /* Literal.String.Single */
.codehilite.coffee .ss { color: #AF5F5F } /* Literal.String.Symbol */
.codehilite.coffee .bp { color: #87AFAF } /* Name.Builtin.Pseudo */
.codehilite.coffee .fm { color: #FDD0C0 } /* Name.Function.Magic */
.codehilite.coffee .vc { color: #DDD0C0 } /* Name.Variable.Class */
.codehilite.coffee .vg { color: #DDD0C0 } /* Name.Variable.Global */
.codehilite.coffee .vi { color: #DDD0C0 } /* Name.Variable.Instance */
.codehilite.coffee .vm { color: #DDD0C0 } /* Name.Variable.Magic */
.codehilite.coffee .il { color: #87AFAF } /* Literal.Number.Integer.Long */
.codehilite.colorful .hll { background-color: #ffffcc }
.codehilite.colorful { background: #ffffff; }
.codehilite.colorful .c { color: #888 } /* Comment */
.codehilite.colorful .err { color: #F00; background-color: #FAA } /* Error */
.codehilite.colorful .k { color: #080; font-weight: bold } /* Keyword */
.codehilite.colorful .o { color: #333 } /* Operator */
.codehilite.colorful .ch { color: #888 } /* Comment.Hashbang */
.codehilite.colorful .cm { color: #888 } /* Comment.Multiline */
.codehilite.colorful .cp { color: #579 } /* Comment.Preproc */
.codehilite.colorful .cpf { color: #888 } /* Comment.PreprocFile */
.codehilite.colorful .c1 { color: #888 } /* Comment.Single */
.codehilite.colorful .cs { color: #C00; font-weight: bold } /* Comment.Special */
.codehilite.colorful .gd { color: #A00000 } /* Generic.Deleted */
.codehilite.colorful .ge { font-style: italic } /* Generic.Emph */
.codehilite.colorful .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.colorful .gr { color: #F00 } /* Generic.Error */
.codehilite.colorful .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite.colorful .gi { color: #00A000 } /* Generic.Inserted */
.codehilite.colorful .go { color: #888 } /* Generic.Output */
.codehilite.colorful .gp { color: #C65D09; font-weight: bold } /* Generic.Prompt */
.codehilite.colorful .gs { font-weight: bold } /* Generic.Strong */
.codehilite.colorful .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite.colorful .gt { color: #04D } /* Generic.Traceback */
.codehilite.colorful .kc { color: #080; font-weight: bold } /* Keyword.Constant */
.codehilite.colorful .kd { color: #080; font-weight: bold } /* Keyword.Declaration */
.codehilite.colorful .kn { color: #080; font-weight: bold } /* Keyword.Namespace */
.codehilite.colorful .kp { color: #038; font-weight: bold } /* Keyword.Pseudo */
.codehilite.colorful .kr { color: #080; font-weight: bold } /* Keyword.Reserved */
.codehilite.colorful .kt { color: #339; font-weight: bold } /* Keyword.Type */
.codehilite.colorful .m { color: #60E; font-weight: bold } /* Literal.Number */
.codehilite.colorful .s { background-color: #FFF0F0 } /* Literal.String */
.codehilite.colorful .na { color: #00C } /* Name.Attribute */
.codehilite.colorful .nb { color: #007020 } /* Name.Builtin */
.codehilite.colorful .nc { color: #B06; font-weight: bold } /* Name.Class */
.codehilite.colorful .no { color: #036; font-weight: bold } /* Name.Constant */
.codehilite.colorful .nd { color: #555; font-weight: bold } /* Name.Decorator */
.codehilite.colorful .ni { color: #800; font-weight: bold } /* Name.Entity */
.codehilite.colorful .ne { color: #F00; font-weight: bold } /* Name.Exception */
.codehilite.colorful .nf { color: #06B; font-weight: bold } /* Name.Function */
.codehilite.colorful .nl { color: #970; font-weight: bold } /* Name.Label */
.codehilite.colorful .nn { color: #0E84B5; font-weight: bold } /* Name.Namespace */
.codehilite.colorful .nt { color: #070 } /* Name.Tag */
.codehilite.colorful .nv { color: #963 } /* Name.Variable */
.codehilite.colorful .ow { color: #000; font-weight: bold } /* Operator.Word */
.codehilite.colorful .w { color: #BBB } /* Text.Whitespace */
.codehilite.colorful .mb { color: #60E; font-weight: bold } /* Literal.Number.Bin */
.codehilite.colorful .mf { color: #60E; font-weight: bold } /* Literal.Number.Float */
.codehilite.colorful .mh { color: #058; font-weight: bold } /* Literal.Number.Hex */
.codehilite.colorful .mi { color: #00D; font-weight: bold } /* Literal.Number.Integer */
.codehilite.colorful .mo { color: #40E; font-weight: bold } /* Literal.Number.Oct */
.codehilite.colorful .sa { background-color: #FFF0F0 } /* Literal.String.Affix */
.codehilite.colorful .sb { background-color: #FFF0F0 } /* Literal.String.Backtick */
.codehilite.colorful .sc { color: #04D } /* Literal.String.Char */
.codehilite.colorful .dl { background-color: #FFF0F0 } /* Literal.String.Delimiter */
.codehilite.colorful .sd { color: #D42 } /* Literal.String.Doc */
.codehilite.colorful .s2 { background-color: #FFF0F0 } /* Literal.String.Double */
.codehilite.colorful .se { color: #666; font-weight: bold; background-color: #FFF0F0 } /* Literal.String.Escape */
.codehilite.colorful .sh { background-color: #FFF0F0 } /* Literal.String.Heredoc */
.codehilite.colorful .si { background-color: #EEE } /* Literal.String.Interpol */
.codehilite.colorful .sx { color: #D20; background-color: #FFF0F0 } /* Literal.String.Other */
.codehilite.colorful .sr { color: #000; background-color: #FFF0FF } /* Literal.String.Regex */
.codehilite.colorful .s1 { background-color: #FFF0F0 } /* Literal.String.Single */
.codehilite.colorful .ss { color: #A60 } /* Literal.String.Symbol */
.codehilite.colorful .bp { color: #007020 } /* Name.Builtin.Pseudo */
.codehilite.colorful .fm { color: #06B; font-weight: bold } /* Name.Function.Magic */
.codehilite.colorful .vc { color: #369 } /* Name.Variable.Class */
.codehilite.colorful .vg { color: #D70; font-weight: bold } /* Name.Variable.Global */
.codehilite.colorful .vi { color: #33B } /* Name.Variable.Instance */
.codehilite.colorful .vm { color: #963 } /* Name.Variable.Magic */
.codehilite.colorful .il { color: #00D; font-weight: bold } /* Literal.Number.Integer.Long */
.codehilite.default .hll { background-color: #ffffcc }
.codehilite.default { background: #f8f8f8; }
.codehilite.default .c { color: #3D7B7B; font-style: italic } /* Comment */
.codehilite.default .err { border: 1px solid #F00 } /* Error */
.codehilite.default .k { color: #008000; font-weight: bold } /* Keyword */
.codehilite.default .o { color: #666 } /* Operator */
.codehilite.default .ch { color: #3D7B7B; font-style: italic } /* Comment.Hashbang */
.codehilite.default .cm { color: #3D7B7B; font-style: italic } /* Comment.Multiline */
.codehilite.default .cp { color: #9C6500 } /* Comment.Preproc */
.codehilite.default .cpf { color: #3D7B7B; font-style: italic } /* Comment.PreprocFile */
.codehilite.default .c1 { color: #3D7B7B; font-style: italic } /* Comment.Single */
.codehilite.default .cs { color: #3D7B7B; font-style: italic } /* Comment.Special */
.codehilite.default .gd { color: #A00000 } /* Generic.Deleted */
.codehilite.default .ge { font-style: italic } /* Generic.Emph */
.codehilite.default .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.default .gr { color: #E40000 } /* Generic.Error */
.codehilite.default .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite.default .gi { color: #008400 } /* Generic.Inserted */
.codehilite.default .go { color: #717171 } /* Generic.Output */
.codehilite.default .gp { color: #000080; font-weight: bold } /* Generic.Prompt */
.codehilite.default .gs { font-weight: bold } /* Generic.Strong */
.codehilite.default .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite.default .gt { color: #04D } /* Generic.Traceback */
.codehilite.default .kc { color: #008000; font-weight: bold } /* Keyword.Constant */
.codehilite.default .kd { color: #008000; font-weight: bold } /* Keyword.Declaration */
.codehilite.default .kn { color: #008000; font-weight: bold } /* Keyword.Namespace */
.codehilite.default .kp { color: #008000 } /* Keyword.Pseudo */
.codehilite.default .kr { color: #008000; font-weight: bold } /* Keyword.Reserved */
.codehilite.default .kt { color: #B00040 } /* Keyword.Type */
.codehilite.default .m { color: #666 } /* Literal.Number */
.codehilite.default .s { color: #BA2121 } /* Literal.String */
.codehilite.default .na { color: #687822 } /* Name.Attribute */
.codehilite.default .nb { color: #008000 } /* Name.Builtin */
.codehilite.default .nc { color: #00F; font-weight: bold } /* Name.Class */
.codehilite.default .no { color: #800 } /* Name.Constant */
.codehilite.default .nd { color: #A2F } /* Name.Decorator */
.codehilite.default .ni { color: #717171; font-weight: bold } /* Name.Entity */
.codehilite.default .ne { color: #CB3F38; font-weight: bold } /* Name.Exception */
.codehilite.default .nf { color: #00F } /* Name.Function */
.codehilite.default .nl { color: #767600 } /* Name.Label */
.codehilite.default .nn { color: #00F; font-weight: bold } /* Name.Namespace */
.codehilite.default .nt { color: #008000; font-weight: bold } /* Name.Tag */
.codehilite.default .nv { color: #19177C } /* Name.Variable */
.codehilite.default .ow { color: #A2F; font-weight: bold } /* Operator.Word */
.codehilite.default .w { color: #BBB } /* Text.Whitespace */
.codehilite.default .mb { color: #666 } /* Literal.Number.Bin */
.codehilite.default .mf { color: #666 } /* Literal.Number.Float */
.codehilite.default .mh { color: #666 } /* Literal.Number.Hex */
.codehilite.default .mi { color: #666 } /* Literal.Number.Integer */
.codehilite.default .mo { color: #666 } /* Literal.Number.Oct */
.codehilite.default .sa { color: #BA2121 } /* Literal.String.Affix */
.codehilite.default .sb { color: #BA2121 } /* Literal.String.Backtick */
.codehilite.default .sc { color: #BA2121 } /* Literal.String.Char */
.codehilite.default .dl { color: #BA2121 } /* Literal.String.Delimiter */
.codehilite.default .sd { color: #BA2121; font-style: italic } /* Literal.String.Doc */
.codehilite.default .s2 { color: #BA2121 } /* Literal.String.Double */
.codehilite.default .se { color: #AA5D1F; font-weight: bold } /* Literal.String.Escape */
.codehilite.default .sh { color: #BA2121 } /* Literal.String.Heredoc */
.codehilite.default .si { color: #A45A77; font-weight: bold } /* Literal.String.Interpol */
.codehilite.default .sx { color: #008000 } /* Literal.String.Other */
.codehilite.default .sr { color: #A45A77 } /* Literal.String.Regex */
.codehilite.default .s1 { color: #BA2121 } /* Literal.String.Single */
.codehilite.default .ss { color: #19177C } /* Literal.String.Symbol */
.codehilite.default .bp { color: #008000 } /* Name.Builtin.Pseudo */
.codehilite.default .fm { color: #00F } /* Name.Function.Magic */
.codehilite.default .vc { color: #19177C } /* Name.Variable.Class */
.codehilite.default .vg { color: #19177C } /* Name.Variable.Global */
.codehilite.default .vi { color: #19177C } /* Name.Variable.Instance */
.codehilite.default .vm { color: #19177C } /* Name.Variable.Magic */
.codehilite.default .il { color: #666 } /* Literal.Number.Integer.Long */
.codehilite.dracula .hll { background-color: #44475a }
.codehilite.dracula { background: #282a36; color: #F8F8F2 }
.codehilite.dracula .c { color: #6272A4 } /* Comment */
.codehilite.dracula .err { color: #F8F8F2 } /* Error */
.codehilite.dracula .g { color: #F8F8F2 } /* Generic */
.codehilite.dracula .k { color: #FF79C6 } /* Keyword */
.codehilite.dracula .l { color: #F8F8F2 } /* Literal */
.codehilite.dracula .n { color: #F8F8F2 } /* Name */
.codehilite.dracula .o { color: #FF79C6 } /* Operator */
.codehilite.dracula .x { color: #F8F8F2 } /* Other */
.codehilite.dracula .p { color: #F8F8F2 } /* Punctuation */
.codehilite.dracula .ch { color: #6272A4 } /* Comment.Hashbang */
.codehilite.dracula .cm { color: #6272A4 } /* Comment.Multiline */
.codehilite.dracula .cp { color: #FF79C6 } /* Comment.Preproc */
.codehilite.dracula .cpf { color: #6272A4 } /* Comment.PreprocFile */
.codehilite.dracula .c1 { color: #6272A4 } /* Comment.Single */
.codehilite.dracula .cs { color: #6272A4 } /* Comment.Special */
.codehilite.dracula .gd { color: #8B080B } /* Generic.Deleted */
.codehilite.dracula .ge { color: #F8F8F2; text-decoration: underline } /* Generic.Emph */
.codehilite.dracula .ges { color: #F8F8F2; text-decoration: underline } /* Generic.EmphStrong */
.codehilite.dracula .gr { color: #F8F8F2 } /* Generic.Error */
.codehilite.dracula .gh { color: #F8F8F2; font-weight: bold } /* Generic.Heading */
.codehilite.dracula .gi { color: #F8F8F2; font-weight: bold } /* Generic.Inserted */
.codehilite.dracula .go { color: #44475A } /* Generic.Output */
.codehilite.dracula .gp { color: #F8F8F2 } /* Generic.Prompt */
.codehilite.dracula .gs { color: #F8F8F2 } /* Generic.Strong */
.codehilite.dracula .gu { color: #F8F8F2; font-weight: bold } /* Generic.Subheading */
.codehilite.dracula .gt { color: #F8F8F2 } /* Generic.Traceback */
.codehilite.dracula .kc { color: #FF79C6 } /* Keyword.Constant */
.codehilite.dracula .kd { color: #8BE9FD; font-style: italic } /* Keyword.Declaration */
.codehilite.dracula .kn { color: #FF79C6 } /* Keyword.Namespace */
.codehilite.dracula .kp { color: #FF79C6 } /* Keyword.Pseudo */
.codehilite.dracula .kr { color: #FF79C6 } /* Keyword.Reserved */
.codehilite.dracula .kt { color: #8BE9FD } /* Keyword.Type */
.codehilite.dracula .ld { color: #F8F8F2 } /* Literal.Date */
.codehilite.dracula .m { color: #FFB86C } /* Literal.Number */
.codehilite.dracula .s { color: #BD93F9 } /* Literal.String */
.codehilite.dracula .na { color: #50FA7B } /* Name.Attribute */
.codehilite.dracula .nb { color: #8BE9FD; font-style: italic } /* Name.Builtin */
.codehilite.dracula .nc { color: #50FA7B } /* Name.Class */
.codehilite.dracula .no { color: #F8F8F2 } /* Name.Constant */
.codehilite.dracula .nd { color: #F8F8F2 } /* Name.Decorator */
.codehilite.dracula .ni { color: #F8F8F2 } /* Name.Entity */
.codehilite.dracula .ne { color: #F8F8F2 } /* Name.Exception */
.codehilite.dracula .nf { color: #50FA7B } /* Name.Function */
.codehilite.dracula .nl { color: #8BE9FD; font-style: italic } /* Name.Label */
.codehilite.dracula .nn { color: #F8F8F2 } /* Name.Namespace */
.codehilite.dracula .nx { color: #F8F8F2 } /* Name.Other */
.codehilite.dracula .py { color: #F8F8F2 } /* Name.Property */
.codehilite.dracula .nt { color: #FF79C6 } /* Name.Tag */
.codehilite.dracula .nv { color: #8BE9FD; font-style: italic } /* Name.Variable */
.codehilite.dracula .ow { color: #FF79C6 } /* Operator.Word */
.codehilite.dracula .pm { color: #F8F8F2 } /* Punctuation.Marker */
.codehilite.dracula .w { color: #F8F8F2 } /* Text.Whitespace */
.codehilite.dracula .mb { color: #FFB86C } /* Literal.Number.Bin */
.codehilite.dracula .mf { color: #FFB86C } /* Literal.Number.Float */
.codehilite.dracula .mh { color: #FFB86C } /* Literal.Number.Hex */
.codehilite.dracula .mi { color: #FFB86C } /* Literal.Number.Integer */
.codehilite.dracula .mo { color: #FFB86C } /* Literal.Number.Oct */
.codehilite.dracula .sa { color: #BD93F9 } /* Literal.String.Affix */
.codehilite.dracula .sb { color: #BD93F9 } /* Literal.String.Backtick */
.codehilite.dracula .sc { color: #BD93F9 } /* Literal.String.Char */
.codehilite.dracula .dl { color: #BD93F9 } /* Literal.String.Delimiter */
.codehilite.dracula .sd { color: #BD93F9 } /* Literal.String.Doc */
.codehilite.dracula .s2 { color: #BD93F9 } /* Literal.String.Double */
.codehilite.dracula .se { color: #BD93F9 } /* Literal.String.Escape */
.codehilite.dracula .sh { color: #BD93F9 } /* Literal.String.Heredoc */
.codehilite.dracula .si { color: #BD93F9 } /* Literal.String.Interpol */
.codehilite.dracula .sx { color: #BD93F9 } /* Literal.String.Other */
.codehilite.dracula .sr { color: #BD93F9 } /* Literal.String.Regex */
.codehilite.dracula .s1 { color: #BD93F9 } /* Literal.String.Single */
.codehilite.dracula .ss { color: #BD93F9 } /* Literal.String.Symbol */
.codehilite.dracula .bp { color: #F8F8F2; font-style: italic } /* Name.Builtin.Pseudo */
.codehilite.dracula .fm { color: #50FA7B } /* Name.Function.Magic */
.codehilite.dracula .vc { color: #8BE9FD; font-style: italic } /* Name.Variable.Class */
.codehilite.dracula .vg { color: #8BE9FD; font-style: italic } /* Name.Variable.Global */
.codehilite.dracula .vi { color: #8BE9FD; font-style: italic } /* Name.Variable.Instance */
.codehilite.dracula .vm { color: #8BE9FD; font-style: italic } /* Name.Variable.Magic */
.codehilite.dracula .il { color: #FFB86C } /* Literal.Number.Integer.Long */
.codehilite.emacs .hll { background-color: #ffffcc }
.codehilite.emacs { background: #f8f8f8; }
.codehilite.emacs .c { color: #080; font-style: italic } /* Comment */
.codehilite.emacs .err { border: 1px solid #F00 } /* Error */
.codehilite.emacs .k { color: #A2F; font-weight: bold } /* Keyword */
.codehilite.emacs .o { color: #666 } /* Operator */
.codehilite.emacs .ch { color: #080; font-style: italic } /* Comment.Hashbang */
.codehilite.emacs .cm { color: #080; font-style: italic } /* Comment.Multiline */
.codehilite.emacs .cp { color: #080 } /* Comment.Preproc */
.codehilite.emacs .cpf { color: #080; font-style: italic } /* Comment.PreprocFile */
.codehilite.emacs .c1 { color: #080; font-style: italic } /* Comment.Single */
.codehilite.emacs .cs { color: #080; font-weight: bold } /* Comment.Special */
.codehilite.emacs .gd { color: #A00000 } /* Generic.Deleted */
.codehilite.emacs .ge { font-style: italic } /* Generic.Emph */
.codehilite.emacs .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.emacs .gr { color: #F00 } /* Generic.Error */
.codehilite.emacs .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite.emacs .gi { color: #00A000 } /* Generic.Inserted */
.codehilite.emacs .go { color: #888 } /* Generic.Output */
.codehilite.emacs .gp { color: #000080; font-weight: bold } /* Generic.Prompt */
.codehilite.emacs .gs { font-weight: bold } /* Generic.Strong */
.codehilite.emacs .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite.emacs .gt { color: #04D } /* Generic.Traceback */
.codehilite.emacs .kc { color: #A2F; font-weight: bold } /* Keyword.Constant */
.codehilite.emacs .kd { color: #A2F; font-weight: bold } /* Keyword.Declaration */
.codehilite.emacs .kn { color: #A2F; font-weight: bold } /* Keyword.Namespace */
.codehilite.emacs .kp { color: #A2F } /* Keyword.Pseudo */
.codehilite.emacs .kr { color: #A2F; font-weight: bold } /* Keyword.Reserved */
.codehilite.emacs .kt { color: #0B0; font-weight: bold } /* Keyword.Type */
.codehilite.emacs .m { color: #666 } /* Literal.Number */
.codehilite.emacs .s { color: #B44 } /* Literal.String */
.codehilite.emacs .na { color: #B44 } /* Name.Attribute */
.codehilite.emacs .nb { color: #A2F } /* Name.Builtin */
.codehilite.emacs .nc { color: #00F } /* Name.Class */
.codehilite.emacs .no { color: #800 } /* Name.Constant */
.codehilite.emacs .nd { color: #A2F } /* Name.Decorator */
.codehilite.emacs .ni { color: #999; font-weight: bold } /* Name.Entity */
.codehilite.emacs .ne { color: #D2413A; font-weight: bold } /* Name.Exception */
.codehilite.emacs .nf { color: #00A000 } /* Name.Function */
.codehilite.emacs .nl { color: #A0A000 } /* Name.Label */
.codehilite.emacs .nn { color: #00F; font-weight: bold } /* Name.Namespace */
.codehilite.emacs .nt { color: #008000; font-weight: bold } /* Name.Tag */
.codehilite.emacs .nv { color: #B8860B } /* Name.Variable */
.codehilite.emacs .ow { color: #A2F; font-weight: bold } /* Operator.Word */
.codehilite.emacs .w { color: #BBB } /* Text.Whitespace */
.codehilite.emacs .mb { color: #666 } /* Literal.Number.Bin */
.codehilite.emacs .mf { color: #666 } /* Literal.Number.Float */
.codehilite.emacs .mh { color: #666 } /* Literal.Number.Hex */
.codehilite.emacs .mi { color: #666 } /* Literal.Number.Integer */
.codehilite.emacs .mo { color: #666 } /* Literal.Number.Oct */
.codehilite.emacs .sa { color: #B44 } /* Literal.String.Affix */
.codehilite.emacs .sb { color: #B44 } /* Literal.String.Backtick */
.codehilite.emacs .sc { color: #B44 } /* Literal.String.Char */
.codehilite.emacs .dl { color: #B44 } /* Literal.String.Delimiter */
.codehilite.emacs .sd { color: #B44; font-style: italic } /* Literal.String.Doc */
.codehilite.emacs .s2 { color: #B44 } /* Literal.String.Double */
.codehilite.emacs .se { color: #B62; font-weight: bold } /* Literal.String.Escape */
.codehilite.emacs .sh { color: #B44 } /* Literal.String.Heredoc */
.codehilite.emacs .si { color: #B68; font-weight: bold } /* Literal.String.Interpol */
.codehilite.emacs .sx { color: #008000 } /* Literal.String.Other */
.codehilite.emacs .sr { color: #B68 } /* Literal.String.Regex */
.codehilite.emacs .s1 { color: #B44 } /* Literal.String.Single */
.codehilite.emacs .ss { color: #B8860B } /* Literal.String.Symbol */
.codehilite.emacs .bp { color: #A2F } /* Name.Builtin.Pseudo */
.codehilite.emacs .fm { color: #00A000 } /* Name.Function.Magic */
.codehilite.emacs .vc { color: #B8860B } /* Name.Variable.Class */
.codehilite.emacs .vg { color: #B8860B } /* Name.Variable.Global */
.codehilite.emacs .vi { color: #B8860B } /* Name.Variable.Instance */
.codehilite.emacs .vm { color: #B8860B } /* Name.Variable.Magic */
.codehilite.emacs .il { color: #666 } /* Literal.Number.Integer.Long */
.codehilite.friendly_grayscale .hll { background-color: #ffffcc }
.codehilite.friendly_grayscale { background: #f0f0f0; }
.codehilite.friendly_grayscale .c { color: #959595; font-style: italic } /* Comment */
.codehilite.friendly_grayscale .err { border: 1px solid #898989 } /* Error */
.codehilite.friendly_grayscale .k { color: #575757; font-weight: bold } /* Keyword */
.codehilite.friendly_grayscale .o { color: #666 } /* Operator */
.codehilite.friendly_grayscale .ch { color: #959595; font-style: italic } /* Comment.Hashbang */
.codehilite.friendly_grayscale .cm { color: #959595; font-style: italic } /* Comment.Multiline */
.codehilite.friendly_grayscale .cp { color: #575757 } /* Comment.Preproc */
.codehilite.friendly_grayscale .cpf { color: #959595; font-style: italic } /* Comment.PreprocFile */
.codehilite.friendly_grayscale .c1 { color: #959595; font-style: italic } /* Comment.Single */
.codehilite.friendly_grayscale .cs { color: #959595; background-color: #F4F4F4 } /* Comment.Special */
.codehilite.friendly_grayscale .gd { color: #545454 } /* Generic.Deleted */
.codehilite.friendly_grayscale .ge { font-style: italic } /* Generic.Emph */
.codehilite.friendly_grayscale .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.friendly_grayscale .gr { color: #898989 } /* Generic.Error */
.codehilite.friendly_grayscale .gh { color: #373737; font-weight: bold } /* Generic.Heading */
.codehilite.friendly_grayscale .gi { color: #7D7D7D } /* Generic.Inserted */
.codehilite.friendly_grayscale .go { color: #888 } /* Generic.Output */
.codehilite.friendly_grayscale .gp { color: #7E7E7E; font-weight: bold } /* Generic.Prompt */
.codehilite.friendly_grayscale .gs { font-weight: bold } /* Generic.Strong */
.codehilite.friendly_grayscale .gu { color: #5A5A5A; font-weight: bold } /* Generic.Subheading */
.codehilite.friendly_grayscale .gt { color: #6D6D6D } /* Generic.Traceback */
.codehilite.friendly_grayscale .kc { color: #575757; font-weight: bold } /* Keyword.Constant */
.codehilite.friendly_grayscale .kd { color: #575757; font-weight: bold } /* Keyword.Declaration */
.codehilite.friendly_grayscale .kn { color: #575757; font-weight: bold } /* Keyword.Namespace */
.codehilite.friendly_grayscale .kp { color: #575757 } /* Keyword.Pseudo */
.codehilite.friendly_grayscale .kr { color: #575757; font-weight: bold } /* Keyword.Reserved */
.codehilite.friendly_grayscale .kt { color: #4F4F4F } /* Keyword.Type */
.codehilite.friendly_grayscale .m { color: #888 } /* Literal.Number */
.codehilite.friendly_grayscale .s { color: #717171 } /* Literal.String */
.codehilite.friendly_grayscale .na { color: #707070 } /* Name.Attribute */
.codehilite.friendly_grayscale .nb { color: #575757 } /* Name.Builtin */
.codehilite.friendly_grayscale .nc { color: #7E7E7E; font-weight: bold } /* Name.Class */
.codehilite.friendly_grayscale .no { color: #A5A5A5 } /* Name.Constant */
.codehilite.friendly_grayscale .nd { color: #555; font-weight: bold } /* Name.Decorator */
.codehilite.friendly_grayscale .ni { color: #848484; font-weight: bold } /* Name.Entity */
.codehilite.friendly_grayscale .ne { color: #575757 } /* Name.Exception */
.codehilite.friendly_grayscale .nf { color: #3F3F3F } /* Name.Function */
.codehilite.friendly_grayscale .nl { color: #363636; font-weight: bold } /* Name.Label */
.codehilite.friendly_grayscale .nn { color: #7E7E7E; font-weight: bold } /* Name.Namespace */
.codehilite.friendly_grayscale .nt { color: #3B3B3B; font-weight: bold } /* Name.Tag */
.codehilite.friendly_grayscale .nv { color: #9A9A9A } /* Name.Variable */
.codehilite.friendly_grayscale .ow { color: #575757; font-weight: bold } /* Operator.Word */
.codehilite.friendly_grayscale .w { color: #BBB } /* Text.Whitespace */
.codehilite.friendly_grayscale .mb { color: #888 } /* Literal.Number.Bin */
.codehilite.friendly_grayscale .mf { color: #888 } /* Literal.Number.Float */
.codehilite.friendly_grayscale .mh { color: #888 } /* Literal.Number.Hex */
.codehilite.friendly_grayscale .mi { color: #888 } /* Literal.Number.Integer */
.codehilite.friendly_grayscale .mo { color: #888 } /* Literal.Number.Oct */
.codehilite.friendly_grayscale .sa { color: #717171 } /* Literal.String.Affix */
.codehilite.friendly_grayscale .sb { color: #717171 } /* Literal.String.Backtick */
.codehilite.friendly_grayscale .sc { color: #717171 } /* Literal.String.Char */
.codehilite.friendly_grayscale .dl { color: #717171 } /* Literal.String.Delimiter */
.codehilite.friendly_grayscale .sd { color: #717171; font-style: italic } /* Literal.String.Doc */
.codehilite.friendly_grayscale .s2 { color: #717171 } /* Literal.String.Double */
.codehilite.friendly_grayscale .se { color: #717171; font-weight: bold } /* Literal.String.Escape */
.codehilite.friendly_grayscale .sh { color: #717171 } /* Literal.String.Heredoc */
.codehilite.friendly_grayscale .si { color: #9F9F9F; font-style: italic } /* Literal.String.Interpol */
.codehilite.friendly_grayscale .sx { color: #7E7E7E } /* Literal.String.Other */
.codehilite.friendly_grayscale .sr { color: #575757 } /* Literal.String.Regex */
.codehilite.friendly_grayscale .s1 { color: #717171 } /* Literal.String.Single */
.codehilite.friendly_grayscale .ss { color: #676767 } /* Literal.String.Symbol */
.codehilite.friendly_grayscale .bp { color: #575757 } /* Name.Builtin.Pseudo */
.codehilite.friendly_grayscale .fm { color: #3F3F3F } /* Name.Function.Magic */
.codehilite.friendly_grayscale .vc { color: #9A9A9A } /* Name.Variable.Class */
.codehilite.friendly_grayscale .vg { color: #9A9A9A } /* Name.Variable.Global */
.codehilite.friendly_grayscale .vi { color: #9A9A9A } /* Name.Variable.Instance */
.codehilite.friendly_grayscale .vm { color: #9A9A9A } /* Name.Variable.Magic */
.codehilite.friendly_grayscale .il { color: #888 } /* Literal.Number.Integer.Long */
.codehilite.friendly .hll { background-color: #ffffcc }
.codehilite.friendly { background: #f0f0f0; }
.codehilite.friendly .c { color: #60A0B0; font-style: italic } /* Comment */
.codehilite.friendly .err { border: 1px solid #F00 } /* Error */
.codehilite.friendly .k { color: #007020; font-weight: bold } /* Keyword */
.codehilite.friendly .o { color: #666 } /* Operator */
.codehilite.friendly .ch { color: #60A0B0; font-style: italic } /* Comment.Hashbang */
.codehilite.friendly .cm { color: #60A0B0; font-style: italic } /* Comment.Multiline */
.codehilite.friendly .cp { color: #007020 } /* Comment.Preproc */
.codehilite.friendly .cpf { color: #60A0B0; font-style: italic } /* Comment.PreprocFile */
.codehilite.friendly .c1 { color: #60A0B0; font-style: italic } /* Comment.Single */
.codehilite.friendly .cs { color: #60A0B0; background-color: #FFF0F0 } /* Comment.Special */
.codehilite.friendly .gd { color: #A00000 } /* Generic.Deleted */
.codehilite.friendly .ge { font-style: italic } /* Generic.Emph */
.codehilite.friendly .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.friendly .gr { color: #F00 } /* Generic.Error */
.codehilite.friendly .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite.friendly .gi { color: #00A000 } /* Generic.Inserted */
.codehilite.friendly .go { color: #888 } /* Generic.Output */
.codehilite.friendly .gp { color: #C65D09; font-weight: bold } /* Generic.Prompt */
.codehilite.friendly .gs { font-weight: bold } /* Generic.Strong */
.codehilite.friendly .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite.friendly .gt { color: #04D } /* Generic.Traceback */
.codehilite.friendly .kc { color: #007020; font-weight: bold } /* Keyword.Constant */
.codehilite.friendly .kd { color: #007020; font-weight: bold } /* Keyword.Declaration */
.codehilite.friendly .kn { color: #007020; font-weight: bold } /* Keyword.Namespace */
.codehilite.friendly .kp { color: #007020 } /* Keyword.Pseudo */
.codehilite.friendly .kr { color: #007020; font-weight: bold } /* Keyword.Reserved */
.codehilite.friendly .kt { color: #902000 } /* Keyword.Type */
.codehilite.friendly .m { color: #40A070 } /* Literal.Number */
.codehilite.friendly .s { color: #4070A0 } /* Literal.String */
.codehilite.friendly .na { color: #4070A0 } /* Name.Attribute */
.codehilite.friendly .nb { color: #007020 } /* Name.Builtin */
.codehilite.friendly .nc { color: #0E84B5; font-weight: bold } /* Name.Class */
.codehilite.friendly .no { color: #60ADD5 } /* Name.Constant */
.codehilite.friendly .nd { color: #555; font-weight: bold } /* Name.Decorator */
.codehilite.friendly .ni { color: #D55537; font-weight: bold } /* Name.Entity */
.codehilite.friendly .ne { color: #007020 } /* Name.Exception */
.codehilite.friendly .nf { color: #06287E } /* Name.Function */
.codehilite.friendly .nl { color: #002070; font-weight: bold } /* Name.Label */
.codehilite.friendly .nn { color: #0E84B5; font-weight: bold } /* Name.Namespace */
.codehilite.friendly .nt { color: #062873; font-weight: bold } /* Name.Tag */
.codehilite.friendly .nv { color: #BB60D5 } /* Name.Variable */
.codehilite.friendly .ow { color: #007020; font-weight: bold } /* Operator.Word */
.codehilite.friendly .w { color: #BBB } /* Text.Whitespace */
.codehilite.friendly .mb { color: #40A070 } /* Literal.Number.Bin */
.codehilite.friendly .mf { color: #40A070 } /* Literal.Number.Float */
.codehilite.friendly .mh { color: #40A070 } /* Literal.Number.Hex */
.codehilite.friendly .mi { color: #40A070 } /* Literal.Number.Integer */
.codehilite.friendly .mo { color: #40A070 } /* Literal.Number.Oct */
.codehilite.friendly .sa { color: #4070A0 } /* Literal.String.Affix */
.codehilite.friendly .sb { color: #4070A0 } /* Literal.String.Backtick */
.codehilite.friendly .sc { color: #4070A0 } /* Literal.String.Char */
.codehilite.friendly .dl { color: #4070A0 } /* Literal.String.Delimiter */
.codehilite.friendly .sd { color: #4070A0; font-style: italic } /* Literal.String.Doc */
.codehilite.friendly .s2 { color: #4070A0 } /* Literal.String.Double */
.codehilite.friendly .se { color: #4070A0; font-weight: bold } /* Literal.String.Escape */
.codehilite.friendly .sh { color: #4070A0 } /* Literal.String.Heredoc */
.codehilite.friendly .si { color: #70A0D0; font-style: italic } /* Literal.String.Interpol */
.codehilite.friendly .sx { color: #C65D09 } /* Literal.String.Other */
.codehilite.friendly .sr { color: #235388 } /* Literal.String.Regex */
.codehilite.friendly .s1 { color: #4070A0 } /* Literal.String.Single */
.codehilite.friendly .ss { color: #517918 } /* Literal.String.Symbol */
.codehilite.friendly .bp { color: #007020 } /* Name.Builtin.Pseudo */
.codehilite.friendly .fm { color: #06287E } /* Name.Function.Magic */
.codehilite.friendly .vc { color: #BB60D5 } /* Name.Variable.Class */
.codehilite.friendly .vg { color: #BB60D5 } /* Name.Variable.Global */
.codehilite.friendly .vi { color: #BB60D5 } /* Name.Variable.Instance */
.codehilite.friendly .vm { color: #BB60D5 } /* Name.Variable.Magic */
.codehilite.friendly .il { color: #40A070 } /* Literal.Number.Integer.Long */
.codehilite.fruity .hll { background-color: #333333 }
.codehilite.fruity { background: #111111; color: #FFF }
.codehilite.fruity .c { color: #080; font-style: italic; background-color: #0F140F } /* Comment */
.codehilite.fruity .err { color: #FFF } /* Error */
.codehilite.fruity .esc { color: #FFF } /* Escape */
.codehilite.fruity .g { color: #FFF } /* Generic */
.codehilite.fruity .k { color: #FB660A; font-weight: bold } /* Keyword */
.codehilite.fruity .l { color: #FFF } /* Literal */
.codehilite.fruity .n { color: #FFF } /* Name */
.codehilite.fruity .o { color: #FFF } /* Operator */
.codehilite.fruity .x { color: #FFF } /* Other */
.codehilite.fruity .p { color: #FFF } /* Punctuation */
.codehilite.fruity .ch { color: #080; font-style: italic; background-color: #0F140F } /* Comment.Hashbang */
.codehilite.fruity .cm { color: #080; font-style: italic; background-color: #0F140F } /* Comment.Multiline */
.codehilite.fruity .cp { color: #FF0007; font-weight: bold; font-style: italic; background-color: #0F140F } /* Comment.Preproc */
.codehilite.fruity .cpf { color: #080; font-style: italic; background-color: #0F140F } /* Comment.PreprocFile */
.codehilite.fruity .c1 { color: #080; font-style: italic; background-color: #0F140F } /* Comment.Single */
.codehilite.fruity .cs { color: #080; font-style: italic; background-color: #0F140F } /* Comment.Special */
.codehilite.fruity .gd { color: #FFF } /* Generic.Deleted */
.codehilite.fruity .ge { color: #FFF } /* Generic.Emph */
.codehilite.fruity .ges { color: #FFF } /* Generic.EmphStrong */
.codehilite.fruity .gr { color: #FFF } /* Generic.Error */
.codehilite.fruity .gh { color: #FFF; font-weight: bold } /* Generic.Heading */
.codehilite.fruity .gi { color: #FFF } /* Generic.Inserted */
.codehilite.fruity .go { color: #444; background-color: #222 } /* Generic.Output */
.codehilite.fruity .gp { color: #FFF } /* Generic.Prompt */
.codehilite.fruity .gs { color: #FFF } /* Generic.Strong */
.codehilite.fruity .gu { color: #FFF; font-weight: bold } /* Generic.Subheading */
.codehilite.fruity .gt { color: #FFF } /* Generic.Traceback */
.codehilite.fruity .kc { color: #FB660A; font-weight: bold } /* Keyword.Constant */
.codehilite.fruity .kd { color: #FB660A; font-weight: bold } /* Keyword.Declaration */
.codehilite.fruity .kn { color: #FB660A; font-weight: bold } /* Keyword.Namespace */
.codehilite.fruity .kp { color: #FB660A } /* Keyword.Pseudo */
.codehilite.fruity .kr { color: #FB660A; font-weight: bold } /* Keyword.Reserved */
.codehilite.fruity .kt { color: #CDCAA9; font-weight: bold } /* Keyword.Type */
.codehilite.fruity .ld { color: #FFF } /* Literal.Date */
.codehilite.fruity .m { color: #0086F7; font-weight: bold } /* Literal.Number */
.codehilite.fruity .s { color: #0086D2 } /* Literal.String */
.codehilite.fruity .na { color: #FF0086; font-weight: bold } /* Name.Attribute */
.codehilite.fruity .nb { color: #FFF } /* Name.Builtin */
.codehilite.fruity .nc { color: #FFF } /* Name.Class */
.codehilite.fruity .no { color: #0086D2 } /* Name.Constant */
.codehilite.fruity .nd { color: #FFF } /* Name.Decorator */
.codehilite.fruity .ni { color: #FFF } /* Name.Entity */
.codehilite.fruity .ne { color: #FFF } /* Name.Exception */
.codehilite.fruity .nf { color: #FF0086; font-weight: bold } /* Name.Function */
.codehilite.fruity .nl { color: #FFF } /* Name.Label */
.codehilite.fruity .nn { color: #FFF } /* Name.Namespace */
.codehilite.fruity .nx { color: #FFF } /* Name.Other */
.codehilite.fruity .py { color: #FFF } /* Name.Property */
.codehilite.fruity .nt { color: #FB660A; font-weight: bold } /* Name.Tag */
.codehilite.fruity .nv { color: #FB660A } /* Name.Variable */
.codehilite.fruity .ow { color: #FFF } /* Operator.Word */
.codehilite.fruity .pm { color: #FFF } /* Punctuation.Marker */
.codehilite.fruity .w { color: #888 } /* Text.Whitespace */
.codehilite.fruity .mb { color: #0086F7; font-weight: bold } /* Literal.Number.Bin */
.codehilite.fruity .mf { color: #0086F7; font-weight: bold } /* Literal.Number.Float */
.codehilite.fruity .mh { color: #0086F7; font-weight: bold } /* Literal.Number.Hex */
.codehilite.fruity .mi { color: #0086F7; font-weight: bold } /* Literal.Number.Integer */
.codehilite.fruity .mo { color: #0086F7; font-weight: bold } /* Literal.Number.Oct */
.codehilite.fruity .sa { color: #0086D2 } /* Literal.String.Affix */
.codehilite.fruity .sb { color: #0086D2 } /* Literal.String.Backtick */
.codehilite.fruity .sc { color: #0086D2 } /* Literal.String.Char */
.codehilite.fruity .dl { color: #0086D2 } /* Literal.String.Delimiter */
.codehilite.fruity .sd { color: #0086D2 } /* Literal.String.Doc */
.codehilite.fruity .s2 { color: #0086D2 } /* Literal.String.Double */
.codehilite.fruity .se { color: #0086D2 } /* Literal.String.Escape */
.codehilite.fruity .sh { color: #0086D2 } /* Literal.String.Heredoc */
.codehilite.fruity .si { color: #0086D2 } /* Literal.String.Interpol */
.codehilite.fruity .sx { color: #0086D2 } /* Literal.String.Other */
.codehilite.fruity .sr { color: #0086D2 } /* Literal.String.Regex */
.codehilite.fruity .s1 { color: #0086D2 } /* Literal.String.Single */
.codehilite.fruity .ss { color: #0086D2 } /* Literal.String.Symbol */
.codehilite.fruity .bp { color: #FFF } /* Name.Builtin.Pseudo */
.codehilite.fruity .fm { color: #FF0086; font-weight: bold } /* Name.Function.Magic */
.codehilite.fruity .vc { color: #FB660A } /* Name.Variable.Class */
.codehilite.fruity .vg { color: #FB660A } /* Name.Variable.Global */
.codehilite.fruity .vi { color: #FB660A } /* Name.Variable.Instance */
.codehilite.fruity .vm { color: #FB660A } /* Name.Variable.Magic */
.codehilite.fruity .il { color: #0086F7; font-weight: bold } /* Literal.Number.Integer.Long */
.codehilite.github-dark .hll { background-color: #6e7681 }
.codehilite.github-dark { background: #0d1117; color: #E6EDF3 }
.codehilite.github-dark .c { color: #8B949E; font-style: italic } /* Comment */
.codehilite.github-dark .err { color: #F85149 } /* Error */
.codehilite.github-dark .esc { color: #E6EDF3 } /* Escape */
.codehilite.github-dark .g { color: #E6EDF3 } /* Generic */
.codehilite.github-dark .k { color: #FF7B72 } /* Keyword */
.codehilite.github-dark .l { color: #A5D6FF } /* Literal */
.codehilite.github-dark .n { color: #E6EDF3 } /* Name */
.codehilite.github-dark .o { color: #FF7B72; font-weight: bold } /* Operator */
.codehilite.github-dark .x { color: #E6EDF3 } /* Other */
.codehilite.github-dark .p { color: #E6EDF3 } /* Punctuation */
.codehilite.github-dark .ch { color: #8B949E; font-style: italic } /* Comment.Hashbang */
.codehilite.github-dark .cm { color: #8B949E; font-style: italic } /* Comment.Multiline */
.codehilite.github-dark .cp { color: #8B949E; font-weight: bold; font-style: italic } /* Comment.Preproc */
.codehilite.github-dark .cpf { color: #8B949E; font-style: italic } /* Comment.PreprocFile */
.codehilite.github-dark .c1 { color: #8B949E; font-style: italic } /* Comment.Single */
.codehilite.github-dark .cs { color: #8B949E; font-weight: bold; font-style: italic } /* Comment.Special */
.codehilite.github-dark .gd { color: #FFA198; background-color: #490202 } /* Generic.Deleted */
.codehilite.github-dark .ge { color: #E6EDF3; font-style: italic } /* Generic.Emph */
.codehilite.github-dark .ges { color: #E6EDF3; font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.github-dark .gr { color: #FFA198 } /* Generic.Error */
.codehilite.github-dark .gh { color: #79C0FF; font-weight: bold } /* Generic.Heading */
.codehilite.github-dark .gi { color: #56D364; background-color: #0F5323 } /* Generic.Inserted */
.codehilite.github-dark .go { color: #8B949E } /* Generic.Output */
.codehilite.github-dark .gp { color: #8B949E } /* Generic.Prompt */
.codehilite.github-dark .gs { color: #E6EDF3; font-weight: bold } /* Generic.Strong */
.codehilite.github-dark .gu { color: #79C0FF } /* Generic.Subheading */
.codehilite.github-dark .gt { color: #FF7B72 } /* Generic.Traceback */
.codehilite.github-dark .g-Underline { color: #E6EDF3; text-decoration: underline } /* Generic.Underline */
.codehilite.github-dark .kc { color: #79C0FF } /* Keyword.Constant */
.codehilite.github-dark .kd { color: #FF7B72 } /* Keyword.Declaration */
.codehilite.github-dark .kn { color: #FF7B72 } /* Keyword.Namespace */
.codehilite.github-dark .kp { color: #79C0FF } /* Keyword.Pseudo */
.codehilite.github-dark .kr { color: #FF7B72 } /* Keyword.Reserved */
.codehilite.github-dark .kt { color: #FF7B72 } /* Keyword.Type */
.codehilite.github-dark .ld { color: #79C0FF } /* Literal.Date */
.codehilite.github-dark .m { color: #A5D6FF } /* Literal.Number */
.codehilite.github-dark .s { color: #A5D6FF } /* Literal.String */
.codehilite.github-dark .na { color: #E6EDF3 } /* Name.Attribute */
.codehilite.github-dark .nb { color: #E6EDF3 } /* Name.Builtin */
.codehilite.github-dark .nc { color: #F0883E; font-weight: bold } /* Name.Class */
.codehilite.github-dark .no { color: #79C0FF; font-weight: bold } /* Name.Constant */
.codehilite.github-dark .nd { color: #D2A8FF; font-weight: bold } /* Name.Decorator */
.codehilite.github-dark .ni { color: #FFA657 } /* Name.Entity */
.codehilite.github-dark .ne { color: #F0883E; font-weight: bold } /* Name.Exception */
.codehilite.github-dark .nf { color: #D2A8FF; font-weight: bold } /* Name.Function */
.codehilite.github-dark .nl { color: #79C0FF; font-weight: bold } /* Name.Label */
.codehilite.github-dark .nn { color: #FF7B72 } /* Name.Namespace */
.codehilite.github-dark .nx { color: #E6EDF3 } /* Name.Other */
.codehilite.github-dark .py { color: #79C0FF } /* Name.Property */
.codehilite.github-dark .nt { color: #7EE787 } /* Name.Tag */
.codehilite.github-dark .nv { color: #79C0FF } /* Name.Variable */
.codehilite.github-dark .ow { color: #FF7B72; font-weight: bold } /* Operator.Word */
.codehilite.github-dark .pm { color: #E6EDF3 } /* Punctuation.Marker */
.codehilite.github-dark .w { color: #6E7681 } /* Text.Whitespace */
.codehilite.github-dark .mb { color: #A5D6FF } /* Literal.Number.Bin */
.codehilite.github-dark .mf { color: #A5D6FF } /* Literal.Number.Float */
.codehilite.github-dark .mh { color: #A5D6FF } /* Literal.Number.Hex */
.codehilite.github-dark .mi { color: #A5D6FF } /* Literal.Number.Integer */
.codehilite.github-dark .mo { color: #A5D6FF } /* Literal.Number.Oct */
.codehilite.github-dark .sa { color: #79C0FF } /* Literal.String.Affix */
.codehilite.github-dark .sb { color: #A5D6FF } /* Literal.String.Backtick */
.codehilite.github-dark .sc { color: #A5D6FF } /* Literal.String.Char */
.codehilite.github-dark .dl { color: #79C0FF } /* Literal.String.Delimiter */
.codehilite.github-dark .sd { color: #A5D6FF } /* Literal.String.Doc */
.codehilite.github-dark .s2 { color: #A5D6FF } /* Literal.String.Double */
.codehilite.github-dark .se { color: #79C0FF } /* Literal.String.Escape */
.codehilite.github-dark .sh { color: #79C0FF } /* Literal.String.Heredoc */
.codehilite.github-dark .si { color: #A5D6FF } /* Literal.String.Interpol */
.codehilite.github-dark .sx { color: #A5D6FF } /* Literal.String.Other */
.codehilite.github-dark .sr { color: #79C0FF } /* Literal.String.Regex */
.codehilite.github-dark .s1 { color: #A5D6FF } /* Literal.String.Single */
.codehilite.github-dark .ss { color: #A5D6FF } /* Literal.String.Symbol */
.codehilite.github-dark .bp { color: #E6EDF3 } /* Name.Builtin.Pseudo */
.codehilite.github-dark .fm { color: #D2A8FF; font-weight: bold } /* Name.Function.Magic */
.codehilite.github-dark .vc { color: #79C0FF } /* Name.Variable.Class */
.codehilite.github-dark .vg { color: #79C0FF } /* Name.Variable.Global */
.codehilite.github-dark .vi { color: #79C0FF } /* Name.Variable.Instance */
.codehilite.github-dark .vm { color: #79C0FF } /* Name.Variable.Magic */
.codehilite.github-dark .il { color: #A5D6FF } /* Literal.Number.Integer.Long */
.codehilite.gruvbox-dark .hll { background-color: #ebdbb2 }
.codehilite.gruvbox-dark { background: #282828; color: #DDD }
.codehilite.gruvbox-dark .c { color: #928374; font-style: italic } /* Comment */
.codehilite.gruvbox-dark .err { color: #282828; background-color: #FB4934 } /* Error */
.codehilite.gruvbox-dark .esc { color: #DDD } /* Escape */
.codehilite.gruvbox-dark .g { color: #DDD } /* Generic */
.codehilite.gruvbox-dark .k { color: #FB4934 } /* Keyword */
.codehilite.gruvbox-dark .l { color: #DDD } /* Literal */
.codehilite.gruvbox-dark .n { color: #DDD } /* Name */
.codehilite.gruvbox-dark .o { color: #DDD } /* Operator */
.codehilite.gruvbox-dark .x { color: #DDD } /* Other */
.codehilite.gruvbox-dark .p { color: #DDD } /* Punctuation */
.codehilite.gruvbox-dark .ch { color: #928374; font-style: italic } /* Comment.Hashbang */
.codehilite.gruvbox-dark .cm { color: #928374; font-style: italic } /* Comment.Multiline */
.codehilite.gruvbox-dark .c-PreProc { color: #8EC07C; font-style: italic } /* Comment.PreProc */
.codehilite.gruvbox-dark .cp { color: #928374; font-style: italic } /* Comment.Preproc */
.codehilite.gruvbox-dark .cpf { color: #928374; font-style: italic } /* Comment.PreprocFile */
.codehilite.gruvbox-dark .c1 { color: #928374; font-style: italic } /* Comment.Single */
.codehilite.gruvbox-dark .cs { color: #EBDBB2; font-weight: bold; font-style: italic } /* Comment.Special */
.codehilite.gruvbox-dark .gd { color: #282828; background-color: #FB4934 } /* Generic.Deleted */
.codehilite.gruvbox-dark .ge { color: #DDD; font-style: italic } /* Generic.Emph */
.codehilite.gruvbox-dark .ges { color: #DDD; font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.gruvbox-dark .gr { color: #FB4934 } /* Generic.Error */
.codehilite.gruvbox-dark .gh { color: #EBDBB2; font-weight: bold } /* Generic.Heading */
.codehilite.gruvbox-dark .gi { color: #282828; background-color: #B8BB26 } /* Generic.Inserted */
.codehilite.gruvbox-dark .go { color: #F2E5BC } /* Generic.Output */
.codehilite.gruvbox-dark .gp { color: #A89984 } /* Generic.Prompt */
.codehilite.gruvbox-dark .gs { color: #DDD; font-weight: bold } /* Generic.Strong */
.codehilite.gruvbox-dark .gu { color: #EBDBB2; text-decoration: underline } /* Generic.Subheading */
.codehilite.gruvbox-dark .gt { color: #FB4934 } /* Generic.Traceback */
.codehilite.gruvbox-dark .kc { color: #FB4934 } /* Keyword.Constant */
.codehilite.gruvbox-dark .kd { color: #FB4934 } /* Keyword.Declaration */
.codehilite.gruvbox-dark .kn { color: #FB4934 } /* Keyword.Namespace */
.codehilite.gruvbox-dark .kp { color: #FB4934 } /* Keyword.Pseudo */
.codehilite.gruvbox-dark .kr { color: #FB4934 } /* Keyword.Reserved */
.codehilite.gruvbox-dark .kt { color: #FB4934 } /* Keyword.Type */
.codehilite.gruvbox-dark .ld { color: #DDD } /* Literal.Date */
.codehilite.gruvbox-dark .m { color: #D3869B } /* Literal.Number */
.codehilite.gruvbox-dark .s { color: #B8BB26 } /* Literal.String */
.codehilite.gruvbox-dark .na { color: #FABD2F } /* Name.Attribute */
.codehilite.gruvbox-dark .nb { color: #FE8019 } /* Name.Builtin */
.codehilite.gruvbox-dark .nc { color: #8EC07C } /* Name.Class */
.codehilite.gruvbox-dark .no { color: #D3869B } /* Name.Constant */
.codehilite.gruvbox-dark .nd { color: #FB4934 } /* Name.Decorator */
.codehilite.gruvbox-dark .ni { color: #DDD } /* Name.Entity */
.codehilite.gruvbox-dark .ne { color: #FB4934 } /* Name.Exception */
.codehilite.gruvbox-dark .nf { color: #8EC07C } /* Name.Function */
.codehilite.gruvbox-dark .nl { color: #DDD } /* Name.Label */
.codehilite.gruvbox-dark .nn { color: #8EC07C } /* Name.Namespace */
.codehilite.gruvbox-dark .nx { color: #DDD } /* Name.Other */
.codehilite.gruvbox-dark .py { color: #DDD } /* Name.Property */
.codehilite.gruvbox-dark .nt { color: #8EC07C } /* Name.Tag */
.codehilite.gruvbox-dark .nv { color: #83A598 } /* Name.Variable */
.codehilite.gruvbox-dark .ow { color: #FB4934 } /* Operator.Word */
.codehilite.gruvbox-dark .pm { color: #DDD } /* Punctuation.Marker */
.codehilite.gruvbox-dark .w { color: #DDD } /* Text.Whitespace */
.codehilite.gruvbox-dark .mb { color: #D3869B } /* Literal.Number.Bin */
.codehilite.gruvbox-dark .mf { color: #D3869B } /* Literal.Number.Float */
.codehilite.gruvbox-dark .mh { color: #D3869B } /* Literal.Number.Hex */
.codehilite.gruvbox-dark .mi { color: #D3869B } /* Literal.Number.Integer */
.codehilite.gruvbox-dark .mo { color: #D3869B } /* Literal.Number.Oct */
.codehilite.gruvbox-dark .sa { color: #B8BB26 } /* Literal.String.Affix */
.codehilite.gruvbox-dark .sb { color: #B8BB26 } /* Literal.String.Backtick */
.codehilite.gruvbox-dark .sc { color: #B8BB26 } /* Literal.String.Char */
.codehilite.gruvbox-dark .dl { color: #B8BB26 } /* Literal.String.Delimiter */
.codehilite.gruvbox-dark .sd { color: #B8BB26 } /* Literal.String.Doc */
.codehilite.gruvbox-dark .s2 { color: #B8BB26 } /* Literal.String.Double */
.codehilite.gruvbox-dark .se { color: #FE8019 } /* Literal.String.Escape */
.codehilite.gruvbox-dark .sh { color: #B8BB26 } /* Literal.String.Heredoc */
.codehilite.gruvbox-dark .si { color: #B8BB26 } /* Literal.String.Interpol */
.codehilite.gruvbox-dark .sx { color: #B8BB26 } /* Literal.String.Other */
.codehilite.gruvbox-dark .sr { color: #B8BB26 } /* Literal.String.Regex */
.codehilite.gruvbox-dark .s1 { color: #B8BB26 } /* Literal.String.Single */
.codehilite.gruvbox-dark .ss { color: #B8BB26 } /* Literal.String.Symbol */
.codehilite.gruvbox-dark .bp { color: #FE8019 } /* Name.Builtin.Pseudo */
.codehilite.gruvbox-dark .fm { color: #8EC07C } /* Name.Function.Magic */
.codehilite.gruvbox-dark .vc { color: #83A598 } /* Name.Variable.Class */
.codehilite.gruvbox-dark .vg { color: #83A598 } /* Name.Variable.Global */
.codehilite.gruvbox-dark .vi { color: #83A598 } /* Name.Variable.Instance */
.codehilite.gruvbox-dark .vm { color: #83A598 } /* Name.Variable.Magic */
.codehilite.gruvbox-dark .il { color: #D3869B } /* Literal.Number.Integer.Long */
.codehilite.gruvbox-light .hll { background-color: #3c3836 }
.codehilite.gruvbox-light { background: #fbf1c7; }
.codehilite.gruvbox-light .c { color: #928374; font-style: italic } /* Comment */
.codehilite.gruvbox-light .err { color: #FBF1C7; background-color: #9D0006 } /* Error */
.codehilite.gruvbox-light .k { color: #9D0006 } /* Keyword */
.codehilite.gruvbox-light .ch { color: #928374; font-style: italic } /* Comment.Hashbang */
.codehilite.gruvbox-light .cm { color: #928374; font-style: italic } /* Comment.Multiline */
.codehilite.gruvbox-light .c-PreProc { color: #427B58; font-style: italic } /* Comment.PreProc */
.codehilite.gruvbox-light .cp { color: #928374; font-style: italic } /* Comment.Preproc */
.codehilite.gruvbox-light .cpf { color: #928374; font-style: italic } /* Comment.PreprocFile */
.codehilite.gruvbox-light .c1 { color: #928374; font-style: italic } /* Comment.Single */
.codehilite.gruvbox-light .cs { color: #3C3836; font-weight: bold; font-style: italic } /* Comment.Special */
.codehilite.gruvbox-light .gd { color: #FBF1C7; background-color: #9D0006 } /* Generic.Deleted */
.codehilite.gruvbox-light .ge { font-style: italic } /* Generic.Emph */
.codehilite.gruvbox-light .gr { color: #9D0006 } /* Generic.Error */
.codehilite.gruvbox-light .gh { color: #3C3836; font-weight: bold } /* Generic.Heading */
.codehilite.gruvbox-light .gi { color: #FBF1C7; background-color: #79740E } /* Generic.Inserted */
.codehilite.gruvbox-light .go { color: #32302F } /* Generic.Output */
.codehilite.gruvbox-light .gp { color: #7C6F64 } /* Generic.Prompt */
.codehilite.gruvbox-light .gs { font-weight: bold } /* Generic.Strong */
.codehilite.gruvbox-light .gu { color: #3C3836; text-decoration: underline } /* Generic.Subheading */
.codehilite.gruvbox-light .gt { color: #9D0006 } /* Generic.Traceback */
.codehilite.gruvbox-light .kc { color: #9D0006 } /* Keyword.Constant */
.codehilite.gruvbox-light .kd { color: #9D0006 } /* Keyword.Declaration */
.codehilite.gruvbox-light .kn { color: #9D0006 } /* Keyword.Namespace */
.codehilite.gruvbox-light .kp { color: #9D0006 } /* Keyword.Pseudo */
.codehilite.gruvbox-light .kr { color: #9D0006 } /* Keyword.Reserved */
.codehilite.gruvbox-light .kt { color: #9D0006 } /* Keyword.Type */
.codehilite.gruvbox-light .m { color: #8F3F71 } /* Literal.Number */
.codehilite.gruvbox-light .s { color: #79740E } /* Literal.String */
.codehilite.gruvbox-light .na { color: #B57614 } /* Name.Attribute */
.codehilite.gruvbox-light .nb { color: #AF3A03 } /* Name.Builtin */
.codehilite.gruvbox-light .nc { color: #427B58 } /* Name.Class */
.codehilite.gruvbox-light .no { color: #8F3F71 } /* Name.Constant */
.codehilite.gruvbox-light .nd { color: #9D0006 } /* Name.Decorator */
.codehilite.gruvbox-light .ne { color: #9D0006 } /* Name.Exception */
.codehilite.gruvbox-light .nf { color: #427B58 } /* Name.Function */
.codehilite.gruvbox-light .nn { color: #427B58 } /* Name.Namespace */
.codehilite.gruvbox-light .nt { color: #427B58 } /* Name.Tag */
.codehilite.gruvbox-light .nv { color: #076678 } /* Name.Variable */
.codehilite.gruvbox-light .ow { color: #9D0006 } /* Operator.Word */
.codehilite.gruvbox-light .mb { color: #8F3F71 } /* Literal.Number.Bin */
.codehilite.gruvbox-light .mf { color: #8F3F71 } /* Literal.Number.Float */
.codehilite.gruvbox-light .mh { color: #8F3F71 } /* Literal.Number.Hex */
.codehilite.gruvbox-light .mi { color: #8F3F71 } /* Literal.Number.Integer */
.codehilite.gruvbox-light .mo { color: #8F3F71 } /* Literal.Number.Oct */
.codehilite.gruvbox-light .sa { color: #79740E } /* Literal.String.Affix */
.codehilite.gruvbox-light .sb { color: #79740E } /* Literal.String.Backtick */
.codehilite.gruvbox-light .sc { color: #79740E } /* Literal.String.Char */
.codehilite.gruvbox-light .dl { color: #79740E } /* Literal.String.Delimiter */
.codehilite.gruvbox-light .sd { color: #79740E } /* Literal.String.Doc */
.codehilite.gruvbox-light .s2 { color: #79740E } /* Literal.String.Double */
.codehilite.gruvbox-light .se { color: #AF3A03 } /* Literal.String.Escape */
.codehilite.gruvbox-light .sh { color: #79740E } /* Literal.String.Heredoc */
.codehilite.gruvbox-light .si { color: #79740E } /* Literal.String.Interpol */
.codehilite.gruvbox-light .sx { color: #79740E } /* Literal.String.Other */
.codehilite.gruvbox-light .sr { color: #79740E } /* Literal.String.Regex */
.codehilite.gruvbox-light .s1 { color: #79740E } /* Literal.String.Single */
.codehilite.gruvbox-light .ss { color: #79740E } /* Literal.String.Symbol */
.codehilite.gruvbox-light .bp { color: #AF3A03 } /* Name.Builtin.Pseudo */
.codehilite.gruvbox-light .fm { color: #427B58 } /* Name.Function.Magic */
.codehilite.gruvbox-light .vc { color: #076678 } /* Name.Variable.Class */
.codehilite.gruvbox-light .vg { color: #076678 } /* Name.Variable.Global */
.codehilite.gruvbox-light .vi { color: #076678 } /* Name.Variable.Instance */
.codehilite.gruvbox-light .vm { color: #076678 } /* Name.Variable.Magic */
.codehilite.gruvbox-light .il { color: #8F3F71 } /* Literal.Number.Integer.Long */
.codehilite.igor .hll { background-color: #ffffcc }
.codehilite.igor { background: #ffffff; }
.codehilite.igor .c { color: #F00; font-style: italic } /* Comment */
.codehilite.igor .k { color: #00F } /* Keyword */
.codehilite.igor .ch { color: #F00; font-style: italic } /* Comment.Hashbang */
.codehilite.igor .cm { color: #F00; font-style: italic } /* Comment.Multiline */
.codehilite.igor .cp { color: #F00; font-style: italic } /* Comment.Preproc */
.codehilite.igor .cpf { color: #F00; font-style: italic } /* Comment.PreprocFile */
.codehilite.igor .c1 { color: #F00; font-style: italic } /* Comment.Single */
.codehilite.igor .cs { color: #F00; font-style: italic } /* Comment.Special */
.codehilite.igor .kc { color: #00F } /* Keyword.Constant */
.codehilite.igor .kd { color: #00F } /* Keyword.Declaration */
.codehilite.igor .kn { color: #00F } /* Keyword.Namespace */
.codehilite.igor .kp { color: #00F } /* Keyword.Pseudo */
.codehilite.igor .kr { color: #00F } /* Keyword.Reserved */
.codehilite.igor .kt { color: #00F } /* Keyword.Type */
.codehilite.igor .s { color: #009C00 } /* Literal.String */
.codehilite.igor .nc { color: #007575 } /* Name.Class */
.codehilite.igor .nd { color: #CC00A3 } /* Name.Decorator */
.codehilite.igor .nf { color: #C34E00 } /* Name.Function */
.codehilite.igor .sa { color: #009C00 } /* Literal.String.Affix */
.codehilite.igor .sb { color: #009C00 } /* Literal.String.Backtick */
.codehilite.igor .sc { color: #009C00 } /* Literal.String.Char */
.codehilite.igor .dl { color: #009C00 } /* Literal.String.Delimiter */
.codehilite.igor .sd { color: #009C00 } /* Literal.String.Doc */
.codehilite.igor .s2 { color: #009C00 } /* Literal.String.Double */
.codehilite.igor .se { color: #009C00 } /* Literal.String.Escape */
.codehilite.igor .sh { color: #009C00 } /* Literal.String.Heredoc */
.codehilite.igor .si { color: #009C00 } /* Literal.String.Interpol */
.codehilite.igor .sx { color: #009C00 } /* Literal.String.Other */
.codehilite.igor .sr { color: #009C00 } /* Literal.String.Regex */
.codehilite.igor .s1 { color: #009C00 } /* Literal.String.Single */
.codehilite.igor .ss { color: #009C00 } /* Literal.String.Symbol */
.codehilite.igor .fm { color: #C34E00 } /* Name.Function.Magic */
.codehilite.inkpot .hll { background-color: #ffffcc }
.codehilite.inkpot { background: #1e1e27; color: #CFBFAD }
.codehilite.inkpot .c { color: #CD8B00 } /* Comment */
.codehilite.inkpot .err { color: #FFF; background-color: #6E2E2E } /* Error */
.codehilite.inkpot .k { color: #808BED } /* Keyword */
.codehilite.inkpot .n { color: #CFBFAD } /* Name */
.codehilite.inkpot .o { color: #666 } /* Operator */
.codehilite.inkpot .x { color: #CFBFAD } /* Other */
.codehilite.inkpot .p { color: #CFBFAD } /* Punctuation */
.codehilite.inkpot .ch { color: #CD8B00 } /* Comment.Hashbang */
.codehilite.inkpot .cm { color: #CD8B00 } /* Comment.Multiline */
.codehilite.inkpot .cp { color: #409090 } /* Comment.Preproc */
.codehilite.inkpot .cpf { color: #FFCD8B; background-color: #404040 } /* Comment.PreprocFile */
.codehilite.inkpot .c1 { color: #CD8B00 } /* Comment.Single */
.codehilite.inkpot .cs { color: #808BED } /* Comment.Special */
.codehilite.inkpot .gd { color: #A00000 } /* Generic.Deleted */
.codehilite.inkpot .ge { font-style: italic } /* Generic.Emph */
.codehilite.inkpot .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.inkpot .gr { color: #F00 } /* Generic.Error */
.codehilite.inkpot .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite.inkpot .gi { color: #00A000 } /* Generic.Inserted */
.codehilite.inkpot .go { color: #888 } /* Generic.Output */
.codehilite.inkpot .gp { color: #000080; font-weight: bold } /* Generic.Prompt */
.codehilite.inkpot .gs { font-weight: bold } /* Generic.Strong */
.codehilite.inkpot .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite.inkpot .gt { color: #04D } /* Generic.Traceback */
.codehilite.inkpot .kc { color: #808BED } /* Keyword.Constant */
.codehilite.inkpot .kd { color: #808BED } /* Keyword.Declaration */
.codehilite.inkpot .kn { color: #808BED } /* Keyword.Namespace */
.codehilite.inkpot .kp { color: #808BED } /* Keyword.Pseudo */
.codehilite.inkpot .kr { color: #808BED } /* Keyword.Reserved */
.codehilite.inkpot .kt { color: #FF8BFF } /* Keyword.Type */
.codehilite.inkpot .m { color: #F0AD6D } /* Literal.Number */
.codehilite.inkpot .s { color: #FFCD8B; background-color: #404040 } /* Literal.String */
.codehilite.inkpot .na { color: #CFBFAD } /* Name.Attribute */
.codehilite.inkpot .nb { color: #808BED } /* Name.Builtin */
.codehilite.inkpot .nc { color: #FF8BFF } /* Name.Class */
.codehilite.inkpot .no { color: #409090 } /* Name.Constant */
.codehilite.inkpot .nd { color: #409090 } /* Name.Decorator */
.codehilite.inkpot .ni { color: #CFBFAD } /* Name.Entity */
.codehilite.inkpot .ne { color: #F00 } /* Name.Exception */
.codehilite.inkpot .nf { color: #C080D0 } /* Name.Function */
.codehilite.inkpot .nl { color: #808BED } /* Name.Label */
.codehilite.inkpot .nn { color: #F00 } /* Name.Namespace */
.codehilite.inkpot .nx { color: #CFBFAD } /* Name.Other */
.codehilite.inkpot .py { color: #CFBFAD } /* Name.Property */
.codehilite.inkpot .nt { color: #CFBFAD } /* Name.Tag */
.codehilite.inkpot .nv { color: #CFBFAD } /* Name.Variable */
.codehilite.inkpot .ow { color: #666 } /* Operator.Word */
.codehilite.inkpot .pm { color: #CFBFAD } /* Punctuation.Marker */
.codehilite.inkpot .w { color: #434357 } /* Text.Whitespace */
.codehilite.inkpot .mb { color: #F0AD6D } /* Literal.Number.Bin */
.codehilite.inkpot .mf { color: #F0AD6D } /* Literal.Number.Float */
.codehilite.inkpot .mh { color: #F0AD6D } /* Literal.Number.Hex */
.codehilite.inkpot .mi { color: #F0AD6D } /* Literal.Number.Integer */
.codehilite.inkpot .mo { color: #F0AD6D } /* Literal.Number.Oct */
.codehilite.inkpot .sa { color: #FFCD8B; background-color: #404040 } /* Literal.String.Affix */
.codehilite.inkpot .sb { color: #FFCD8B; background-color: #404040 } /* Literal.String.Backtick */
.codehilite.inkpot .sc { color: #FFCD8B; background-color: #404040 } /* Literal.String.Char */
.codehilite.inkpot .dl { color: #FFCD8B; background-color: #404040 } /* Literal.String.Delimiter */
.codehilite.inkpot .sd { color: #808BED; background-color: #404040 } /* Literal.String.Doc */
.codehilite.inkpot .s2 { color: #FFCD8B; background-color: #404040 } /* Literal.String.Double */
.codehilite.inkpot .se { color: #FFCD8B; background-color: #404040 } /* Literal.String.Escape */
.codehilite.inkpot .sh { color: #FFCD8B; background-color: #404040 } /* Literal.String.Heredoc */
.codehilite.inkpot .si { color: #FFCD8B; background-color: #404040 } /* Literal.String.Interpol */
.codehilite.inkpot .sx { color: #FFCD8B; background-color: #404040 } /* Literal.String.Other */
.codehilite.inkpot .sr { color: #FFCD8B; background-color: #404040 } /* Literal.String.Regex */
.codehilite.inkpot .s1 { color: #FFCD8B; background-color: #404040 } /* Literal.String.Single */
.codehilite.inkpot .ss { color: #FFCD8B; background-color: #404040 } /* Literal.String.Symbol */
.codehilite.inkpot .bp { color: #FF0 } /* Name.Builtin.Pseudo */
.codehilite.inkpot .fm { color: #C080D0 } /* Name.Function.Magic */
.codehilite.inkpot .vc { color: #CFBFAD } /* Name.Variable.Class */
.codehilite.inkpot .vg { color: #CFBFAD } /* Name.Variable.Global */
.codehilite.inkpot .vi { color: #CFBFAD } /* Name.Variable.Instance */
.codehilite.inkpot .vm { color: #CFBFAD } /* Name.Variable.Magic */
.codehilite.inkpot .il { color: #F0AD6D } /* Literal.Number.Integer.Long */
.codehilite.lightbulb .hll { background-color: #6e7681 }
.codehilite.lightbulb { background: #1d2331; color: #D4D2C8 }
.codehilite.lightbulb .c { color: #7E8AA1 } /* Comment */
.codehilite.lightbulb .err { color: #F88F7F } /* Error */
.codehilite.lightbulb .esc { color: #D4D2C8 } /* Escape */
.codehilite.lightbulb .g { color: #D4D2C8 } /* Generic */
.codehilite.lightbulb .k { color: #FFAD66 } /* Keyword */
.codehilite.lightbulb .l { color: #D5FF80 } /* Literal */
.codehilite.lightbulb .n { color: #D4D2C8 } /* Name */
.codehilite.lightbulb .o { color: #FFAD66 } /* Operator */
.codehilite.lightbulb .x { color: #D4D2C8 } /* Other */
.codehilite.lightbulb .p { color: #D4D2C8 } /* Punctuation */
.codehilite.lightbulb .ch { color: #F88F7F; font-style: italic } /* Comment.Hashbang */
.codehilite.lightbulb .cm { color: #7E8AA1 } /* Comment.Multiline */
.codehilite.lightbulb .cp { color: #FFAD66; font-weight: bold } /* Comment.Preproc */
.codehilite.lightbulb .cpf { color: #7E8AA1 } /* Comment.PreprocFile */
.codehilite.lightbulb .c1 { color: #7E8AA1 } /* Comment.Single */
.codehilite.lightbulb .cs { color: #7E8AA1; font-style: italic } /* Comment.Special */
.codehilite.lightbulb .gd { color: #F88F7F; background-color: #3D1E20 } /* Generic.Deleted */
.codehilite.lightbulb .ge { color: #D4D2C8; font-style: italic } /* Generic.Emph */
.codehilite.lightbulb .ges { color: #D4D2C8 } /* Generic.EmphStrong */
.codehilite.lightbulb .gr { color: #F88F7F } /* Generic.Error */
.codehilite.lightbulb .gh { color: #D4D2C8 } /* Generic.Heading */
.codehilite.lightbulb .gi { color: #6AD4AF; background-color: #19362C } /* Generic.Inserted */
.codehilite.lightbulb .go { color: #7E8AA1 } /* Generic.Output */
.codehilite.lightbulb .gp { color: #D4D2C8 } /* Generic.Prompt */
.codehilite.lightbulb .gs { color: #D4D2C8; font-weight: bold } /* Generic.Strong */
.codehilite.lightbulb .gu { color: #D4D2C8 } /* Generic.Subheading */
.codehilite.lightbulb .gt { color: #F88F7F } /* Generic.Traceback */
.codehilite.lightbulb .kc { color: #FFAD66 } /* Keyword.Constant */
.codehilite.lightbulb .kd { color: #FFAD66 } /* Keyword.Declaration */
.codehilite.lightbulb .kn { color: #FFAD66 } /* Keyword.Namespace */
.codehilite.lightbulb .kp { color: #FFAD66 } /* Keyword.Pseudo */
.codehilite.lightbulb .kr { color: #FFAD66 } /* Keyword.Reserved */
.codehilite.lightbulb .kt { color: #73D0FF } /* Keyword.Type */
.codehilite.lightbulb .ld { color: #D5FF80 } /* Literal.Date */
.codehilite.lightbulb .m { color: #DFBFFF } /* Literal.Number */
.codehilite.lightbulb .s { color: #D5FF80 } /* Literal.String */
.codehilite.lightbulb .na { color: #FFD173 } /* Name.Attribute */
.codehilite.lightbulb .nb { color: #FFD173 } /* Name.Builtin */
.codehilite.lightbulb .nc { color: #73D0FF } /* Name.Class */
.codehilite.lightbulb .no { color: #FFD173 } /* Name.Constant */
.codehilite.lightbulb .nd { color: #7E8AA1; font-weight: bold; font-style: italic } /* Name.Decorator */
.codehilite.lightbulb .ni { color: #95E6CB } /* Name.Entity */
.codehilite.lightbulb .ne { color: #73D0FF } /* Name.Exception */
.codehilite.lightbulb .nf { color: #FFD173 } /* Name.Function */
.codehilite.lightbulb .nl { color: #D4D2C8 } /* Name.Label */
.codehilite.lightbulb .nn { color: #D4D2C8 } /* Name.Namespace */
.codehilite.lightbulb .nx { color: #D4D2C8 } /* Name.Other */
.codehilite.lightbulb .py { color: #FFD173 } /* Name.Property */
.codehilite.lightbulb .nt { color: #5CCFE6 } /* Name.Tag */
.codehilite.lightbulb .nv { color: #D4D2C8 } /* Name.Variable */
.codehilite.lightbulb .ow { color: #FFAD66 } /* Operator.Word */
.codehilite.lightbulb .pm { color: #D4D2C8 } /* Punctuation.Marker */
.codehilite.lightbulb .w { color: #D4D2C8 } /* Text.Whitespace */
.codehilite.lightbulb .mb { color: #DFBFFF } /* Literal.Number.Bin */
.codehilite.lightbulb .mf { color: #DFBFFF } /* Literal.Number.Float */
.codehilite.lightbulb .mh { color: #DFBFFF } /* Literal.Number.Hex */
.codehilite.lightbulb .mi { color: #DFBFFF } /* Literal.Number.Integer */
.codehilite.lightbulb .mo { color: #DFBFFF } /* Literal.Number.Oct */
.codehilite.lightbulb .sa { color: #F29E74 } /* Literal.String.Affix */
.codehilite.lightbulb .sb { color: #D5FF80 } /* Literal.String.Backtick */
.codehilite.lightbulb .sc { color: #D5FF80 } /* Literal.String.Char */
.codehilite.lightbulb .dl { color: #D5FF80 } /* Literal.String.Delimiter */
.codehilite.lightbulb .sd { color: #7E8AA1 } /* Literal.String.Doc */
.codehilite.lightbulb .s2 { color: #D5FF80 } /* Literal.String.Double */
.codehilite.lightbulb .se { color: #95E6CB } /* Literal.String.Escape */
.codehilite.lightbulb .sh { color: #D5FF80 } /* Literal.String.Heredoc */
.codehilite.lightbulb .si { color: #95E6CB } /* Literal.String.Interpol */
.codehilite.lightbulb .sx { color: #95E6CB } /* Literal.String.Other */
.codehilite.lightbulb .sr { color: #95E6CB } /* Literal.String.Regex */
.codehilite.lightbulb .s1 { color: #D5FF80 } /* Literal.String.Single */
.codehilite.lightbulb .ss { color: #DFBFFF } /* Literal.String.Symbol */
.codehilite.lightbulb .bp { color: #5CCFE6 } /* Name.Builtin.Pseudo */
.codehilite.lightbulb .fm { color: #FFD173 } /* Name.Function.Magic */
.codehilite.lightbulb .vc { color: #D4D2C8 } /* Name.Variable.Class */
.codehilite.lightbulb .vg { color: #D4D2C8 } /* Name.Variable.Global */
.codehilite.lightbulb .vi { color: #D4D2C8 } /* Name.Variable.Instance */
.codehilite.lightbulb .vm { color: #D4D2C8 } /* Name.Variable.Magic */
.codehilite.lightbulb .il { color: #DFBFFF } /* Literal.Number.Integer.Long */
.codehilite.lilypond .hll { background-color: #ffffcc }
.codehilite.lilypond { background: #ffffff; }
.codehilite.lilypond .-ChordModifier { color: #976806 } /* ChordModifier */
.codehilite.lilypond .c { color: #A3AAB2; font-style: italic } /* Comment */
.codehilite.lilypond .k { font-weight: bold } /* Keyword */
.codehilite.lilypond .ch { color: #A3AAB2; font-style: italic } /* Comment.Hashbang */
.codehilite.lilypond .cm { color: #A3AAB2; font-style: italic } /* Comment.Multiline */
.codehilite.lilypond .cp { color: #A3AAB2; font-style: italic } /* Comment.Preproc */
.codehilite.lilypond .cpf { color: #A3AAB2; font-style: italic } /* Comment.PreprocFile */
.codehilite.lilypond .c1 { color: #A3AAB2; font-style: italic } /* Comment.Single */
.codehilite.lilypond .cs { color: #A3AAB2; font-style: italic } /* Comment.Special */
.codehilite.lilypond .kc { font-weight: bold } /* Keyword.Constant */
.codehilite.lilypond .kd { font-weight: bold } /* Keyword.Declaration */
.codehilite.lilypond .kn { font-weight: bold } /* Keyword.Namespace */
.codehilite.lilypond .kp { font-weight: bold } /* Keyword.Pseudo */
.codehilite.lilypond .kr { font-weight: bold } /* Keyword.Reserved */
.codehilite.lilypond .kt { font-weight: bold } /* Keyword.Type */
.codehilite.lilypond .m { color: #976806 } /* Literal.Number */
.codehilite.lilypond .s { color: #AB0909 } /* Literal.String */
.codehilite.lilypond .n-BackslashReference { color: #08547A } /* Name.BackslashReference */
.codehilite.lilypond .n-Lvalue { color: #08547A } /* Name.Lvalue */
.codehilite.lilypond .mb { color: #976806 } /* Literal.Number.Bin */
.codehilite.lilypond .mf { color: #976806 } /* Literal.Number.Float */
.codehilite.lilypond .mh { color: #976806 } /* Literal.Number.Hex */
.codehilite.lilypond .mi { color: #976806 } /* Literal.Number.Integer */
.codehilite.lilypond .mo { color: #976806 } /* Literal.Number.Oct */
.codehilite.lilypond .sa { color: #AB0909 } /* Literal.String.Affix */
.codehilite.lilypond .sb { color: #AB0909 } /* Literal.String.Backtick */
.codehilite.lilypond .sc { color: #AB0909 } /* Literal.String.Char */
.codehilite.lilypond .dl { color: #AB0909 } /* Literal.String.Delimiter */
.codehilite.lilypond .sd { color: #AB0909 } /* Literal.String.Doc */
.codehilite.lilypond .s2 { color: #AB0909 } /* Literal.String.Double */
.codehilite.lilypond .se { color: #C46C6C } /* Literal.String.Escape */
.codehilite.lilypond .sh { color: #AB0909 } /* Literal.String.Heredoc */
.codehilite.lilypond .si { color: #AB0909 } /* Literal.String.Interpol */
.codehilite.lilypond .sx { color: #AB0909 } /* Literal.String.Other */
.codehilite.lilypond .sr { color: #AB0909 } /* Literal.String.Regex */
.codehilite.lilypond .s1 { color: #AB0909 } /* Literal.String.Single */
.codehilite.lilypond .nb-Articulation { color: #68175A } /* Name.Builtin.Articulation */
.codehilite.lilypond .nb-Clef { color: #08547A; font-weight: bold } /* Name.Builtin.Clef */
.codehilite.lilypond .nb-Context { color: #038B8B; font-weight: bold } /* Name.Builtin.Context */
.codehilite.lilypond .nb-ContextProperty { color: #038B8B } /* Name.Builtin.ContextProperty */
.codehilite.lilypond .nb-Dynamic { color: #68175A } /* Name.Builtin.Dynamic */
.codehilite.lilypond .nb-Grob { color: #0C7441; font-weight: bold } /* Name.Builtin.Grob */
.codehilite.lilypond .nb-GrobProperty { color: #0C7441 } /* Name.Builtin.GrobProperty */
.codehilite.lilypond .nb-HeaderVariable { color: #6C5A05; font-weight: bold } /* Name.Builtin.HeaderVariable */
.codehilite.lilypond .nb-MarkupCommand { color: #831E71; font-weight: bold } /* Name.Builtin.MarkupCommand */
.codehilite.lilypond .nb-MusicCommand { color: #08547A; font-weight: bold } /* Name.Builtin.MusicCommand */
.codehilite.lilypond .nb-MusicFunction { color: #08547A; font-weight: bold } /* Name.Builtin.MusicFunction */
.codehilite.lilypond .nb-PaperVariable { color: #6C5A05; font-weight: bold } /* Name.Builtin.PaperVariable */
.codehilite.lilypond .nb-RepeatType { color: #08547A } /* Name.Builtin.RepeatType */
.codehilite.lilypond .nb-Scale { color: #08547A; font-weight: bold } /* Name.Builtin.Scale */
.codehilite.lilypond .nb-SchemeBuiltin { font-weight: bold } /* Name.Builtin.SchemeBuiltin */
.codehilite.lilypond .nb-SchemeFunction { color: #A83401; font-weight: bold } /* Name.Builtin.SchemeFunction */
.codehilite.lilypond .nb-Translator { color: #6200A4; font-weight: bold } /* Name.Builtin.Translator */
.codehilite.lilypond .il { color: #976806 } /* Literal.Number.Integer.Long */
.codehilite.lovelace .hll { background-color: #ffffcc }
.codehilite.lovelace { background: #ffffff; }
.codehilite.lovelace .c { color: #888; font-style: italic } /* Comment */
.codehilite.lovelace .err { background-color: #A848A8 } /* Error */
.codehilite.lovelace .k { color: #2838B0 } /* Keyword */
.codehilite.lovelace .o { color: #666 } /* Operator */
.codehilite.lovelace .p { color: #888 } /* Punctuation */
.codehilite.lovelace .ch { color: #287088; font-style: italic } /* Comment.Hashbang */
.codehilite.lovelace .cm { color: #888; font-style: italic } /* Comment.Multiline */
.codehilite.lovelace .cp { color: #289870 } /* Comment.Preproc */
.codehilite.lovelace .cpf { color: #888; font-style: italic } /* Comment.PreprocFile */
.codehilite.lovelace .c1 { color: #888; font-style: italic } /* Comment.Single */
.codehilite.lovelace .cs { color: #888; font-style: italic } /* Comment.Special */
.codehilite.lovelace .gd { color: #C02828 } /* Generic.Deleted */
.codehilite.lovelace .ge { font-style: italic } /* Generic.Emph */
.codehilite.lovelace .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.lovelace .gr { color: #C02828 } /* Generic.Error */
.codehilite.lovelace .gh { color: #666 } /* Generic.Heading */
.codehilite.lovelace .gi { color: #388038 } /* Generic.Inserted */
.codehilite.lovelace .go { color: #666 } /* Generic.Output */
.codehilite.lovelace .gp { color: #444 } /* Generic.Prompt */
.codehilite.lovelace .gs { font-weight: bold } /* Generic.Strong */
.codehilite.lovelace .gu { color: #444 } /* Generic.Subheading */
.codehilite.lovelace .gt { color: #2838B0 } /* Generic.Traceback */
.codehilite.lovelace .kc { color: #444; font-style: italic } /* Keyword.Constant */
.codehilite.lovelace .kd { color: #2838B0; font-style: italic } /* Keyword.Declaration */
.codehilite.lovelace .kn { color: #2838B0 } /* Keyword.Namespace */
.codehilite.lovelace .kp { color: #2838B0 } /* Keyword.Pseudo */
.codehilite.lovelace .kr { color: #2838B0 } /* Keyword.Reserved */
.codehilite.lovelace .kt { color: #2838B0; font-style: italic } /* Keyword.Type */
.codehilite.lovelace .m { color: #444 } /* Literal.Number */
.codehilite.lovelace .s { color: #B83838 } /* Literal.String */
.codehilite.lovelace .na { color: #388038 } /* Name.Attribute */
.codehilite.lovelace .nb { color: #388038 } /* Name.Builtin */
.codehilite.lovelace .nc { color: #287088 } /* Name.Class */
.codehilite.lovelace .no { color: #B85820 } /* Name.Constant */
.codehilite.lovelace .nd { color: #287088 } /* Name.Decorator */
.codehilite.lovelace .ni { color: #709030 } /* Name.Entity */
.codehilite.lovelace .ne { color: #908828 } /* Name.Exception */
.codehilite.lovelace .nf { color: #785840 } /* Name.Function */
.codehilite.lovelace .nl { color: #289870 } /* Name.Label */
.codehilite.lovelace .nn { color: #289870 } /* Name.Namespace */
.codehilite.lovelace .nt { color: #2838B0 } /* Name.Tag */
.codehilite.lovelace .nv { color: #B04040 } /* Name.Variable */
.codehilite.lovelace .ow { color: #A848A8 } /* Operator.Word */
.codehilite.lovelace .pm { color: #888 } /* Punctuation.Marker */
.codehilite.lovelace .w { color: #A89028 } /* Text.Whitespace */
.codehilite.lovelace .mb { color: #444 } /* Literal.Number.Bin */
.codehilite.lovelace .mf { color: #444 } /* Literal.Number.Float */
.codehilite.lovelace .mh { color: #444 } /* Literal.Number.Hex */
.codehilite.lovelace .mi { color: #444 } /* Literal.Number.Integer */
.codehilite.lovelace .mo { color: #444 } /* Literal.Number.Oct */
.codehilite.lovelace .sa { color: #444 } /* Literal.String.Affix */
.codehilite.lovelace .sb { color: #B83838 } /* Literal.String.Backtick */
.codehilite.lovelace .sc { color: #A848A8 } /* Literal.String.Char */
.codehilite.lovelace .dl { color: #B85820 } /* Literal.String.Delimiter */
.codehilite.lovelace .sd { color: #B85820; font-style: italic } /* Literal.String.Doc */
.codehilite.lovelace .s2 { color: #B83838 } /* Literal.String.Double */
.codehilite.lovelace .se { color: #709030 } /* Literal.String.Escape */
.codehilite.lovelace .sh { color: #B83838 } /* Literal.String.Heredoc */
.codehilite.lovelace .si { color: #B83838; text-decoration: underline } /* Literal.String.Interpol */
.codehilite.lovelace .sx { color: #A848A8 } /* Literal.String.Other */
.codehilite.lovelace .sr { color: #A848A8 } /* Literal.String.Regex */
.codehilite.lovelace .s1 { color: #B83838 } /* Literal.String.Single */
.codehilite.lovelace .ss { color: #B83838 } /* Literal.String.Symbol */
.codehilite.lovelace .bp { color: #388038; font-style: italic } /* Name.Builtin.Pseudo */
.codehilite.lovelace .fm { color: #B85820 } /* Name.Function.Magic */
.codehilite.lovelace .vc { color: #B04040 } /* Name.Variable.Class */
.codehilite.lovelace .vg { color: #908828 } /* Name.Variable.Global */
.codehilite.lovelace .vi { color: #B04040 } /* Name.Variable.Instance */
.codehilite.lovelace .vm { color: #B85820 } /* Name.Variable.Magic */
.codehilite.lovelace .il { color: #444 } /* Literal.Number.Integer.Long */
.codehilite.manni .hll { background-color: #ffffcc }
.codehilite.manni { background: #f0f3f3; }
.codehilite.manni .c { color: #09F; font-style: italic } /* Comment */
.codehilite.manni .err { color: #A00; background-color: #FAA } /* Error */
.codehilite.manni .k { color: #069; font-weight: bold } /* Keyword */
.codehilite.manni .o { color: #555 } /* Operator */
.codehilite.manni .ch { color: #09F; font-style: italic } /* Comment.Hashbang */
.codehilite.manni .cm { color: #09F; font-style: italic } /* Comment.Multiline */
.codehilite.manni .cp { color: #099 } /* Comment.Preproc */
.codehilite.manni .cpf { color: #09F; font-style: italic } /* Comment.PreprocFile */
.codehilite.manni .c1 { color: #09F; font-style: italic } /* Comment.Single */
.codehilite.manni .cs { color: #09F; font-weight: bold; font-style: italic } /* Comment.Special */
.codehilite.manni .gd { background-color: #FCC; border: 1px solid #C00 } /* Generic.Deleted */
.codehilite.manni .ge { font-style: italic } /* Generic.Emph */
.codehilite.manni .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.manni .gr { color: #F00 } /* Generic.Error */
.codehilite.manni .gh { color: #030; font-weight: bold } /* Generic.Heading */
.codehilite.manni .gi { background-color: #CFC; border: 1px solid #0C0 } /* Generic.Inserted */
.codehilite.manni .go { color: #AAA } /* Generic.Output */
.codehilite.manni .gp { color: #009; font-weight: bold } /* Generic.Prompt */
.codehilite.manni .gs { font-weight: bold } /* Generic.Strong */
.codehilite.manni .gu { color: #030; font-weight: bold } /* Generic.Subheading */
.codehilite.manni .gt { color: #9C6 } /* Generic.Traceback */
.codehilite.manni .kc { color: #069; font-weight: bold } /* Keyword.Constant */
.codehilite.manni .kd { color: #069; font-weight: bold } /* Keyword.Declaration */
.codehilite.manni .kn { color: #069; font-weight: bold } /* Keyword.Namespace */
.codehilite.manni .kp { color: #069 } /* Keyword.Pseudo */
.codehilite.manni .kr { color: #069; font-weight: bold } /* Keyword.Reserved */
.codehilite.manni .kt { color: #078; font-weight: bold } /* Keyword.Type */
.codehilite.manni .m { color: #F60 } /* Literal.Number */
.codehilite.manni .s { color: #C30 } /* Literal.String */
.codehilite.manni .na { color: #309 } /* Name.Attribute */
.codehilite.manni .nb { color: #366 } /* Name.Builtin */
.codehilite.manni .nc { color: #0A8; font-weight: bold } /* Name.Class */
.codehilite.manni .no { color: #360 } /* Name.Constant */
.codehilite.manni .nd { color: #99F } /* Name.Decorator */
.codehilite.manni .ni { color: #999; font-weight: bold } /* Name.Entity */
.codehilite.manni .ne { color: #C00; font-weight: bold } /* Name.Exception */
.codehilite.manni .nf { color: #C0F } /* Name.Function */
.codehilite.manni .nl { color: #99F } /* Name.Label */
.codehilite.manni .nn { color: #0CF; font-weight: bold } /* Name.Namespace */
.codehilite.manni .nt { color: #309; font-weight: bold } /* Name.Tag */
.codehilite.manni .nv { color: #033 } /* Name.Variable */
.codehilite.manni .ow { color: #000; font-weight: bold } /* Operator.Word */
.codehilite.manni .w { color: #BBB } /* Text.Whitespace */
.codehilite.manni .mb { color: #F60 } /* Literal.Number.Bin */
.codehilite.manni .mf { color: #F60 } /* Literal.Number.Float */
.codehilite.manni .mh { color: #F60 } /* Literal.Number.Hex */
.codehilite.manni .mi { color: #F60 } /* Literal.Number.Integer */
.codehilite.manni .mo { color: #F60 } /* Literal.Number.Oct */
.codehilite.manni .sa { color: #C30 } /* Literal.String.Affix */
.codehilite.manni .sb { color: #C30 } /* Literal.String.Backtick */
.codehilite.manni .sc { color: #C30 } /* Literal.String.Char */
.codehilite.manni .dl { color: #C30 } /* Literal.String.Delimiter */
.codehilite.manni .sd { color: #C30; font-style: italic } /* Literal.String.Doc */
.codehilite.manni .s2 { color: #C30 } /* Literal.String.Double */
.codehilite.manni .se { color: #C30; font-weight: bold } /* Literal.String.Escape */
.codehilite.manni .sh { color: #C30 } /* Literal.String.Heredoc */
.codehilite.manni .si { color: #A00 } /* Literal.String.Interpol */
.codehilite.manni .sx { color: #C30 } /* Literal.String.Other */
.codehilite.manni .sr { color: #3AA } /* Literal.String.Regex */
.codehilite.manni .s1 { color: #C30 } /* Literal.String.Single */
.codehilite.manni .ss { color: #FC3 } /* Literal.String.Symbol */
.codehilite.manni .bp { color: #366 } /* Name.Builtin.Pseudo */
.codehilite.manni .fm { color: #C0F } /* Name.Function.Magic */
.codehilite.manni .vc { color: #033 } /* Name.Variable.Class */
.codehilite.manni .vg { color: #033 } /* Name.Variable.Global */
.codehilite.manni .vi { color: #033 } /* Name.Variable.Instance */
.codehilite.manni .vm { color: #033 } /* Name.Variable.Magic */
.codehilite.manni .il { color: #F60 } /* Literal.Number.Integer.Long */
.codehilite.material .hll { background-color: #2C3B41 }
.codehilite.material { background: #263238; color: #EFF }
.codehilite.material .c { color: #546E7A; font-style: italic } /* Comment */
.codehilite.material .err { color: #FF5370 } /* Error */
.codehilite.material .esc { color: #89DDFF } /* Escape */
.codehilite.material .g { color: #EFF } /* Generic */
.codehilite.material .k { color: #BB80B3 } /* Keyword */
.codehilite.material .l { color: #C3E88D } /* Literal */
.codehilite.material .n { color: #EFF } /* Name */
.codehilite.material .o { color: #89DDFF } /* Operator */
.codehilite.material .p { color: #89DDFF } /* Punctuation */
.codehilite.material .ch { color: #546E7A; font-style: italic } /* Comment.Hashbang */
.codehilite.material .cm { color: #546E7A; font-style: italic } /* Comment.Multiline */
.codehilite.material .cp { color: #546E7A; font-style: italic } /* Comment.Preproc */
.codehilite.material .cpf { color: #546E7A; font-style: italic } /* Comment.PreprocFile */
.codehilite.material .c1 { color: #546E7A; font-style: italic } /* Comment.Single */
.codehilite.material .cs { color: #546E7A; font-style: italic } /* Comment.Special */
.codehilite.material .gd { color: #FF5370 } /* Generic.Deleted */
.codehilite.material .ge { color: #89DDFF } /* Generic.Emph */
.codehilite.material .ges { color: #FFCB6B } /* Generic.EmphStrong */
.codehilite.material .gr { color: #FF5370 } /* Generic.Error */
.codehilite.material .gh { color: #C3E88D } /* Generic.Heading */
.codehilite.material .gi { color: #C3E88D } /* Generic.Inserted */
.codehilite.material .go { color: #546E7A } /* Generic.Output */
.codehilite.material .gp { color: #FFCB6B } /* Generic.Prompt */
.codehilite.material .gs { color: #FF5370 } /* Generic.Strong */
.codehilite.material .gu { color: #89DDFF } /* Generic.Subheading */
.codehilite.material .gt { color: #FF5370 } /* Generic.Traceback */
.codehilite.material .kc { color: #89DDFF } /* Keyword.Constant */
.codehilite.material .kd { color: #BB80B3 } /* Keyword.Declaration */
.codehilite.material .kn { color: #89DDFF; font-style: italic } /* Keyword.Namespace */
.codehilite.material .kp { color: #89DDFF } /* Keyword.Pseudo */
.codehilite.material .kr { color: #BB80B3 } /* Keyword.Reserved */
.codehilite.material .kt { color: #BB80B3 } /* Keyword.Type */
.codehilite.material .ld { color: #C3E88D } /* Literal.Date */
.codehilite.material .m { color: #F78C6C } /* Literal.Number */
.codehilite.material .s { color: #C3E88D } /* Literal.String */
.codehilite.material .na { color: #BB80B3 } /* Name.Attribute */
.codehilite.material .nb { color: #82AAFF } /* Name.Builtin */
.codehilite.material .nc { color: #FFCB6B } /* Name.Class */
.codehilite.material .no { color: #EFF } /* Name.Constant */
.codehilite.material .nd { color: #82AAFF } /* Name.Decorator */
.codehilite.material .ni { color: #89DDFF } /* Name.Entity */
.codehilite.material .ne { color: #FFCB6B } /* Name.Exception */
.codehilite.material .nf { color: #82AAFF } /* Name.Function */
.codehilite.material .nl { color: #82AAFF } /* Name.Label */
.codehilite.material .nn { color: #FFCB6B } /* Name.Namespace */
.codehilite.material .nx { color: #EFF } /* Name.Other */
.codehilite.material .py { color: #FFCB6B } /* Name.Property */
.codehilite.material .nt { color: #FF5370 } /* Name.Tag */
.codehilite.material .nv { color: #89DDFF } /* Name.Variable */
.codehilite.material .ow { color: #89DDFF; font-style: italic } /* Operator.Word */
.codehilite.material .pm { color: #89DDFF } /* Punctuation.Marker */
.codehilite.material .w { color: #EFF } /* Text.Whitespace */
.codehilite.material .mb { color: #F78C6C } /* Literal.Number.Bin */
.codehilite.material .mf { color: #F78C6C } /* Literal.Number.Float */
.codehilite.material .mh { color: #F78C6C } /* Literal.Number.Hex */
.codehilite.material .mi { color: #F78C6C } /* Literal.Number.Integer */
.codehilite.material .mo { color: #F78C6C } /* Literal.Number.Oct */
.codehilite.material .sa { color: #BB80B3 } /* Literal.String.Affix */
.codehilite.material .sb { color: #C3E88D } /* Literal.String.Backtick */
.codehilite.material .sc { color: #C3E88D } /* Literal.String.Char */
.codehilite.material .dl { color: #EFF } /* Literal.String.Delimiter */
.codehilite.material .sd { color: #546E7A; font-style: italic } /* Literal.String.Doc */
.codehilite.material .s2 { color: #C3E88D } /* Literal.String.Double */
.codehilite.material .se { color: #EFF } /* Literal.String.Escape */
.codehilite.material .sh { color: #C3E88D } /* Literal.String.Heredoc */
.codehilite.material .si { color: #89DDFF } /* Literal.String.Interpol */
.codehilite.material .sx { color: #C3E88D } /* Literal.String.Other */
.codehilite.material .sr { color: #89DDFF } /* Literal.String.Regex */
.codehilite.material .s1 { color: #C3E88D } /* Literal.String.Single */
.codehilite.material .ss { color: #89DDFF } /* Literal.String.Symbol */
.codehilite.material .bp { color: #89DDFF } /* Name.Builtin.Pseudo */
.codehilite.material .fm { color: #82AAFF } /* Name.Function.Magic */
.codehilite.material .vc { color: #89DDFF } /* Name.Variable.Class */
.codehilite.material .vg { color: #89DDFF } /* Name.Variable.Global */
.codehilite.material .vi { color: #89DDFF } /* Name.Variable.Instance */
.codehilite.material .vm { color: #82AAFF } /* Name.Variable.Magic */
.codehilite.material .il { color: #F78C6C } /* Literal.Number.Integer.Long */
.codehilite.monokai .hll { background-color: #49483e }
.codehilite.monokai { background: #272822; color: #F8F8F2 }
.codehilite.monokai .c { color: #959077 } /* Comment */
.codehilite.monokai .err { color: #ED007E; background-color: #1E0010 } /* Error */
.codehilite.monokai .esc { color: #F8F8F2 } /* Escape */
.codehilite.monokai .g { color: #F8F8F2 } /* Generic */
.codehilite.monokai .k { color: #66D9EF } /* Keyword */
.codehilite.monokai .l { color: #AE81FF } /* Literal */
.codehilite.monokai .n { color: #F8F8F2 } /* Name */
.codehilite.monokai .o { color: #FF4689 } /* Operator */
.codehilite.monokai .x { color: #F8F8F2 } /* Other */
.codehilite.monokai .p { color: #F8F8F2 } /* Punctuation */
.codehilite.monokai .ch { color: #959077 } /* Comment.Hashbang */
.codehilite.monokai .cm { color: #959077 } /* Comment.Multiline */
.codehilite.monokai .cp { color: #959077 } /* Comment.Preproc */
.codehilite.monokai .cpf { color: #959077 } /* Comment.PreprocFile */
.codehilite.monokai .c1 { color: #959077 } /* Comment.Single */
.codehilite.monokai .cs { color: #959077 } /* Comment.Special */
.codehilite.monokai .gd { color: #FF4689 } /* Generic.Deleted */
.codehilite.monokai .ge { color: #F8F8F2; font-style: italic } /* Generic.Emph */
.codehilite.monokai .ges { color: #F8F8F2; font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.monokai .gr { color: #F8F8F2 } /* Generic.Error */
.codehilite.monokai .gh { color: #F8F8F2 } /* Generic.Heading */
.codehilite.monokai .gi { color: #A6E22E } /* Generic.Inserted */
.codehilite.monokai .go { color: #66D9EF } /* Generic.Output */
.codehilite.monokai .gp { color: #FF4689; font-weight: bold } /* Generic.Prompt */
.codehilite.monokai .gs { color: #F8F8F2; font-weight: bold } /* Generic.Strong */
.codehilite.monokai .gu { color: #959077 } /* Generic.Subheading */
.codehilite.monokai .gt { color: #F8F8F2 } /* Generic.Traceback */
.codehilite.monokai .kc { color: #66D9EF } /* Keyword.Constant */
.codehilite.monokai .kd { color: #66D9EF } /* Keyword.Declaration */
.codehilite.monokai .kn { color: #FF4689 } /* Keyword.Namespace */
.codehilite.monokai .kp { color: #66D9EF } /* Keyword.Pseudo */
.codehilite.monokai .kr { color: #66D9EF } /* Keyword.Reserved */
.codehilite.monokai .kt { color: #66D9EF } /* Keyword.Type */
.codehilite.monokai .ld { color: #E6DB74 } /* Literal.Date */
.codehilite.monokai .m { color: #AE81FF } /* Literal.Number */
.codehilite.monokai .s { color: #E6DB74 } /* Literal.String */
.codehilite.monokai .na { color: #A6E22E } /* Name.Attribute */
.codehilite.monokai .nb { color: #F8F8F2 } /* Name.Builtin */
.codehilite.monokai .nc { color: #A6E22E } /* Name.Class */
.codehilite.monokai .no { color: #66D9EF } /* Name.Constant */
.codehilite.monokai .nd { color: #A6E22E } /* Name.Decorator */
.codehilite.monokai .ni { color: #F8F8F2 } /* Name.Entity */
.codehilite.monokai .ne { color: #A6E22E } /* Name.Exception */
.codehilite.monokai .nf { color: #A6E22E } /* Name.Function */
.codehilite.monokai .nl { color: #F8F8F2 } /* Name.Label */
.codehilite.monokai .nn { color: #F8F8F2 } /* Name.Namespace */
.codehilite.monokai .nx { color: #A6E22E } /* Name.Other */
.codehilite.monokai .py { color: #F8F8F2 } /* Name.Property */
.codehilite.monokai .nt { color: #FF4689 } /* Name.Tag */
.codehilite.monokai .nv { color: #F8F8F2 } /* Name.Variable */
.codehilite.monokai .ow { color: #FF4689 } /* Operator.Word */
.codehilite.monokai .pm { color: #F8F8F2 } /* Punctuation.Marker */
.codehilite.monokai .w { color: #F8F8F2 } /* Text.Whitespace */
.codehilite.monokai .mb { color: #AE81FF } /* Literal.Number.Bin */
.codehilite.monokai .mf { color: #AE81FF } /* Literal.Number.Float */
.codehilite.monokai .mh { color: #AE81FF } /* Literal.Number.Hex */
.codehilite.monokai .mi { color: #AE81FF } /* Literal.Number.Integer */
.codehilite.monokai .mo { color: #AE81FF } /* Literal.Number.Oct */
.codehilite.monokai .sa { color: #E6DB74 } /* Literal.String.Affix */
.codehilite.monokai .sb { color: #E6DB74 } /* Literal.String.Backtick */
.codehilite.monokai .sc { color: #E6DB74 } /* Literal.String.Char */
.codehilite.monokai .dl { color: #E6DB74 } /* Literal.String.Delimiter */
.codehilite.monokai .sd { color: #E6DB74 } /* Literal.String.Doc */
.codehilite.monokai .s2 { color: #E6DB74 } /* Literal.String.Double */
.codehilite.monokai .se { color: #AE81FF } /* Literal.String.Escape */
.codehilite.monokai .sh { color: #E6DB74 } /* Literal.String.Heredoc */
.codehilite.monokai .si { color: #E6DB74 } /* Literal.String.Interpol */
.codehilite.monokai .sx { color: #E6DB74 } /* Literal.String.Other */
.codehilite.monokai .sr { color: #E6DB74 } /* Literal.String.Regex */
.codehilite.monokai .s1 { color: #E6DB74 } /* Literal.String.Single */
.codehilite.monokai .ss { color: #E6DB74 } /* Literal.String.Symbol */
.codehilite.monokai .bp { color: #F8F8F2 } /* Name.Builtin.Pseudo */
.codehilite.monokai .fm { color: #A6E22E } /* Name.Function.Magic */
.codehilite.monokai .vc { color: #F8F8F2 } /* Name.Variable.Class */
.codehilite.monokai .vg { color: #F8F8F2 } /* Name.Variable.Global */
.codehilite.monokai .vi { color: #F8F8F2 } /* Name.Variable.Instance */
.codehilite.monokai .vm { color: #F8F8F2 } /* Name.Variable.Magic */
.codehilite.monokai .il { color: #AE81FF } /* Literal.Number.Integer.Long */
.codehilite.murphy .hll { background-color: #ffffcc }
.codehilite.murphy { background: #ffffff; }
.codehilite.murphy .c { color: #666; font-style: italic } /* Comment */
.codehilite.murphy .err { color: #F00; background-color: #FAA } /* Error */
.codehilite.murphy .k { color: #289; font-weight: bold } /* Keyword */
.codehilite.murphy .o { color: #333 } /* Operator */
.codehilite.murphy .ch { color: #666; font-style: italic } /* Comment.Hashbang */
.codehilite.murphy .cm { color: #666; font-style: italic } /* Comment.Multiline */
.codehilite.murphy .cp { color: #579 } /* Comment.Preproc */
.codehilite.murphy .cpf { color: #666; font-style: italic } /* Comment.PreprocFile */
.codehilite.murphy .c1 { color: #666; font-style: italic } /* Comment.Single */
.codehilite.murphy .cs { color: #C00; font-weight: bold; font-style: italic } /* Comment.Special */
.codehilite.murphy .gd { color: #A00000 } /* Generic.Deleted */
.codehilite.murphy .ge { font-style: italic } /* Generic.Emph */
.codehilite.murphy .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.murphy .gr { color: #F00 } /* Generic.Error */
.codehilite.murphy .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite.murphy .gi { color: #00A000 } /* Generic.Inserted */
.codehilite.murphy .go { color: #888 } /* Generic.Output */
.codehilite.murphy .gp { color: #C65D09; font-weight: bold } /* Generic.Prompt */
.codehilite.murphy .gs { font-weight: bold } /* Generic.Strong */
.codehilite.murphy .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite.murphy .gt { color: #04D } /* Generic.Traceback */
.codehilite.murphy .kc { color: #289; font-weight: bold } /* Keyword.Constant */
.codehilite.murphy .kd { color: #289; font-weight: bold } /* Keyword.Declaration */
.codehilite.murphy .kn { color: #289; font-weight: bold } /* Keyword.Namespace */
.codehilite.murphy .kp { color: #08F; font-weight: bold } /* Keyword.Pseudo */
.codehilite.murphy .kr { color: #289; font-weight: bold } /* Keyword.Reserved */
.codehilite.murphy .kt { color: #66F; font-weight: bold } /* Keyword.Type */
.codehilite.murphy .m { color: #60E; font-weight: bold } /* Literal.Number */
.codehilite.murphy .s { background-color: #E0E0FF } /* Literal.String */
.codehilite.murphy .na { color: #007 } /* Name.Attribute */
.codehilite.murphy .nb { color: #072 } /* Name.Builtin */
.codehilite.murphy .nc { color: #E9E; font-weight: bold } /* Name.Class */
.codehilite.murphy .no { color: #5ED; font-weight: bold } /* Name.Constant */
.codehilite.murphy .nd { color: #555; font-weight: bold } /* Name.Decorator */
.codehilite.murphy .ni { color: #800 } /* Name.Entity */
.codehilite.murphy .ne { color: #F00; font-weight: bold } /* Name.Exception */
.codehilite.murphy .nf { color: #5ED; font-weight: bold } /* Name.Function */
.codehilite.murphy .nl { color: #970; font-weight: bold } /* Name.Label */
.codehilite.murphy .nn { color: #0E84B5; font-weight: bold } /* Name.Namespace */
.codehilite.murphy .nt { color: #070 } /* Name.Tag */
.codehilite.murphy .nv { color: #036 } /* Name.Variable */
.codehilite.murphy .ow { color: #000; font-weight: bold } /* Operator.Word */
.codehilite.murphy .w { color: #BBB } /* Text.Whitespace */
.codehilite.murphy .mb { color: #60E; font-weight: bold } /* Literal.Number.Bin */
.codehilite.murphy .mf { color: #60E; font-weight: bold } /* Literal.Number.Float */
.codehilite.murphy .mh { color: #058; font-weight: bold } /* Literal.Number.Hex */
.codehilite.murphy .mi { color: #66F; font-weight: bold } /* Literal.Number.Integer */
.codehilite.murphy .mo { color: #40E; font-weight: bold } /* Literal.Number.Oct */
.codehilite.murphy .sa { background-color: #E0E0FF } /* Literal.String.Affix */
.codehilite.murphy .sb { background-color: #E0E0FF } /* Literal.String.Backtick */
.codehilite.murphy .sc { color: #88F } /* Literal.String.Char */
.codehilite.murphy .dl { background-color: #E0E0FF } /* Literal.String.Delimiter */
.codehilite.murphy .sd { color: #D42 } /* Literal.String.Doc */
.codehilite.murphy .s2 { background-color: #E0E0FF } /* Literal.String.Double */
.codehilite.murphy .se { color: #666; font-weight: bold; background-color: #E0E0FF } /* Literal.String.Escape */
.codehilite.murphy .sh { background-color: #E0E0FF } /* Literal.String.Heredoc */
.codehilite.murphy .si { background-color: #EEE } /* Literal.String.Interpol */
.codehilite.murphy .sx { color: #F88; background-color: #E0E0FF } /* Literal.String.Other */
.codehilite.murphy .sr { color: #000; background-color: #E0E0FF } /* Literal.String.Regex */
.codehilite.murphy .s1 { background-color: #E0E0FF } /* Literal.String.Single */
.codehilite.murphy .ss { color: #FC8 } /* Literal.String.Symbol */
.codehilite.murphy .bp { color: #072 } /* Name.Builtin.Pseudo */
.codehilite.murphy .fm { color: #5ED; font-weight: bold } /* Name.Function.Magic */
.codehilite.murphy .vc { color: #CCF } /* Name.Variable.Class */
.codehilite.murphy .vg { color: #F84 } /* Name.Variable.Global */
.codehilite.murphy .vi { color: #AAF } /* Name.Variable.Instance */
.codehilite.murphy .vm { color: #036 } /* Name.Variable.Magic */
.codehilite.murphy .il { color: #66F; font-weight: bold } /* Literal.Number.Integer.Long */
.codehilite.native .hll { background-color: #404040 }
.codehilite.native { background: #202020; color: #D0D0D0 }
.codehilite.native .c { color: #ABABAB; font-style: italic } /* Comment */
.codehilite.native .err { color: #A61717; background-color: #E3D2D2 } /* Error */
.codehilite.native .esc { color: #D0D0D0 } /* Escape */
.codehilite.native .g { color: #D0D0D0 } /* Generic */
.codehilite.native .k { color: #6EBF26; font-weight: bold } /* Keyword */
.codehilite.native .l { color: #D0D0D0 } /* Literal */
.codehilite.native .n { color: #D0D0D0 } /* Name */
.codehilite.native .o { color: #D0D0D0 } /* Operator */
.codehilite.native .x { color: #D0D0D0 } /* Other */
.codehilite.native .p { color: #D0D0D0 } /* Punctuation */
.codehilite.native .ch { color: #ABABAB; font-style: italic } /* Comment.Hashbang */
.codehilite.native .cm { color: #ABABAB; font-style: italic } /* Comment.Multiline */
.codehilite.native .cp { color: #FF3A3A; font-weight: bold } /* Comment.Preproc */
.codehilite.native .cpf { color: #ABABAB; font-style: italic } /* Comment.PreprocFile */
.codehilite.native .c1 { color: #ABABAB; font-style: italic } /* Comment.Single */
.codehilite.native .cs { color: #E50808; font-weight: bold; background-color: #520000 } /* Comment.Special */
.codehilite.native .gd { color: #FF3A3A } /* Generic.Deleted */
.codehilite.native .ge { color: #D0D0D0; font-style: italic } /* Generic.Emph */
.codehilite.native .ges { color: #D0D0D0; font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.native .gr { color: #FF3A3A } /* Generic.Error */
.codehilite.native .gh { color: #FFF; font-weight: bold } /* Generic.Heading */
.codehilite.native .gi { color: #589819 } /* Generic.Inserted */
.codehilite.native .go { color: #CCC } /* Generic.Output */
.codehilite.native .gp { color: #AAA } /* Generic.Prompt */
.codehilite.native .gs { color: #D0D0D0; font-weight: bold } /* Generic.Strong */
.codehilite.native .gu { color: #FFF; text-decoration: underline } /* Generic.Subheading */
.codehilite.native .gt { color: #FF3A3A } /* Generic.Traceback */
.codehilite.native .kc { color: #6EBF26; font-weight: bold } /* Keyword.Constant */
.codehilite.native .kd { color: #6EBF26; font-weight: bold } /* Keyword.Declaration */
.codehilite.native .kn { color: #6EBF26; font-weight: bold } /* Keyword.Namespace */
.codehilite.native .kp { color: #6EBF26 } /* Keyword.Pseudo */
.codehilite.native .kr { color: #6EBF26; font-weight: bold } /* Keyword.Reserved */
.codehilite.native .kt { color: #6EBF26; font-weight: bold } /* Keyword.Type */
.codehilite.native .ld { color: #D0D0D0 } /* Literal.Date */
.codehilite.native .m { color: #51B2FD } /* Literal.Number */
.codehilite.native .s { color: #ED9D13 } /* Literal.String */
.codehilite.native .na { color: #BBB } /* Name.Attribute */
.codehilite.native .nb { color: #2FBCCD } /* Name.Builtin */
.codehilite.native .nc { color: #71ADFF; text-decoration: underline } /* Name.Class */
.codehilite.native .no { color: #40FFFF } /* Name.Constant */
.codehilite.native .nd { color: #FFA500 } /* Name.Decorator */
.codehilite.native .ni { color: #D0D0D0 } /* Name.Entity */
.codehilite.native .ne { color: #BBB } /* Name.Exception */
.codehilite.native .nf { color: #71ADFF } /* Name.Function */
.codehilite.native .nl { color: #D0D0D0 } /* Name.Label */
.codehilite.native .nn { color: #71ADFF; text-decoration: underline } /* Name.Namespace */
.codehilite.native .nx { color: #D0D0D0 } /* Name.Other */
.codehilite.native .py { color: #D0D0D0 } /* Name.Property */
.codehilite.native .nt { color: #6EBF26; font-weight: bold } /* Name.Tag */
.codehilite.native .nv { color: #40FFFF } /* Name.Variable */
.codehilite.native .ow { color: #6EBF26; font-weight: bold } /* Operator.Word */
.codehilite.native .pm { color: #D0D0D0 } /* Punctuation.Marker */
.codehilite.native .w { color: #666 } /* Text.Whitespace */
.codehilite.native .mb { color: #51B2FD } /* Literal.Number.Bin */
.codehilite.native .mf { color: #51B2FD } /* Literal.Number.Float */
.codehilite.native .mh { color: #51B2FD } /* Literal.Number.Hex */
.codehilite.native .mi { color: #51B2FD } /* Literal.Number.Integer */
.codehilite.native .mo { color: #51B2FD } /* Literal.Number.Oct */
.codehilite.native .sa { color: #ED9D13 } /* Literal.String.Affix */
.codehilite.native .sb { color: #ED9D13 } /* Literal.String.Backtick */
.codehilite.native .sc { color: #ED9D13 } /* Literal.String.Char */
.codehilite.native .dl { color: #ED9D13 } /* Literal.String.Delimiter */
.codehilite.native .sd { color: #ED9D13 } /* Literal.String.Doc */
.codehilite.native .s2 { color: #ED9D13 } /* Literal.String.Double */
.codehilite.native .se { color: #ED9D13 } /* Literal.String.Escape */
.codehilite.native .sh { color: #ED9D13 } /* Literal.String.Heredoc */
.codehilite.native .si { color: #ED9D13 } /* Literal.String.Interpol */
.codehilite.native .sx { color: #FFA500 } /* Literal.String.Other */
.codehilite.native .sr { color: #ED9D13 } /* Literal.String.Regex */
.codehilite.native .s1 { color: #ED9D13 } /* Literal.String.Single */
.codehilite.native .ss { color: #ED9D13 } /* Literal.String.Symbol */
.codehilite.native .bp { color: #2FBCCD } /* Name.Builtin.Pseudo */
.codehilite.native .fm { color: #71ADFF } /* Name.Function.Magic */
.codehilite.native .vc { color: #40FFFF } /* Name.Variable.Class */
.codehilite.native .vg { color: #40FFFF } /* Name.Variable.Global */
.codehilite.native .vi { color: #40FFFF } /* Name.Variable.Instance */
.codehilite.native .vm { color: #40FFFF } /* Name.Variable.Magic */
.codehilite.native .il { color: #51B2FD } /* Literal.Number.Integer.Long */
.codehilite.nord-darker .hll { background-color: #3B4252 }
.codehilite.nord-darker { background: #242933; color: #D8DEE9 }
.codehilite.nord-darker .c { color: #616E87; font-style: italic } /* Comment */
.codehilite.nord-darker .err { color: #BF616A } /* Error */
.codehilite.nord-darker .esc { color: #D8DEE9 } /* Escape */
.codehilite.nord-darker .g { color: #D8DEE9 } /* Generic */
.codehilite.nord-darker .k { color: #81A1C1; font-weight: bold } /* Keyword */
.codehilite.nord-darker .l { color: #D8DEE9 } /* Literal */
.codehilite.nord-darker .n { color: #D8DEE9 } /* Name */
.codehilite.nord-darker .o { color: #81A1C1; font-weight: bold } /* Operator */
.codehilite.nord-darker .x { color: #D8DEE9 } /* Other */
.codehilite.nord-darker .p { color: #ECEFF4 } /* Punctuation */
.codehilite.nord-darker .ch { color: #616E87; font-style: italic } /* Comment.Hashbang */
.codehilite.nord-darker .cm { color: #616E87; font-style: italic } /* Comment.Multiline */
.codehilite.nord-darker .cp { color: #5E81AC; font-style: italic } /* Comment.Preproc */
.codehilite.nord-darker .cpf { color: #616E87; font-style: italic } /* Comment.PreprocFile */
.codehilite.nord-darker .c1 { color: #616E87; font-style: italic } /* Comment.Single */
.codehilite.nord-darker .cs { color: #616E87; font-style: italic } /* Comment.Special */
.codehilite.nord-darker .gd { color: #BF616A } /* Generic.Deleted */
.codehilite.nord-darker .ge { color: #D8DEE9; font-style: italic } /* Generic.Emph */
.codehilite.nord-darker .ges { color: #D8DEE9 } /* Generic.EmphStrong */
.codehilite.nord-darker .gr { color: #BF616A } /* Generic.Error */
.codehilite.nord-darker .gh { color: #88C0D0; font-weight: bold } /* Generic.Heading */
.codehilite.nord-darker .gi { color: #A3BE8C } /* Generic.Inserted */
.codehilite.nord-darker .go { color: #D8DEE9 } /* Generic.Output */
.codehilite.nord-darker .gp { color: #616E88; font-weight: bold } /* Generic.Prompt */
.codehilite.nord-darker .gs { color: #D8DEE9; font-weight: bold } /* Generic.Strong */
.codehilite.nord-darker .gu { color: #88C0D0; font-weight: bold } /* Generic.Subheading */
.codehilite.nord-darker .gt { color: #BF616A } /* Generic.Traceback */
.codehilite.nord-darker .kc { color: #81A1C1; font-weight: bold } /* Keyword.Constant */
.codehilite.nord-darker .kd { color: #81A1C1; font-weight: bold } /* Keyword.Declaration */
.codehilite.nord-darker .kn { color: #81A1C1; font-weight: bold } /* Keyword.Namespace */
.codehilite.nord-darker .kp { color: #81A1C1 } /* Keyword.Pseudo */
.codehilite.nord-darker .kr { color: #81A1C1; font-weight: bold } /* Keyword.Reserved */
.codehilite.nord-darker .kt { color: #81A1C1 } /* Keyword.Type */
.codehilite.nord-darker .ld { color: #D8DEE9 } /* Literal.Date */
.codehilite.nord-darker .m { color: #B48EAD } /* Literal.Number */
.codehilite.nord-darker .s { color: #A3BE8C } /* Literal.String */
.codehilite.nord-darker .na { color: #8FBCBB } /* Name.Attribute */
.codehilite.nord-darker .nb { color: #81A1C1 } /* Name.Builtin */
.codehilite.nord-darker .nc { color: #8FBCBB } /* Name.Class */
.codehilite.nord-darker .no { color: #8FBCBB } /* Name.Constant */
.codehilite.nord-darker .nd { color: #D08770 } /* Name.Decorator */
.codehilite.nord-darker .ni { color: #D08770 } /* Name.Entity */
.codehilite.nord-darker .ne { color: #BF616A } /* Name.Exception */
.codehilite.nord-darker .nf { color: #88C0D0 } /* Name.Function */
.codehilite.nord-darker .nl { color: #D8DEE9 } /* Name.Label */
.codehilite.nord-darker .nn { color: #8FBCBB } /* Name.Namespace */
.codehilite.nord-darker .nx { color: #D8DEE9 } /* Name.Other */
.codehilite.nord-darker .py { color: #D8DEE9 } /* Name.Property */
.codehilite.nord-darker .nt { color: #81A1C1 } /* Name.Tag */
.codehilite.nord-darker .nv { color: #D8DEE9 } /* Name.Variable */
.codehilite.nord-darker .ow { color: #81A1C1; font-weight: bold } /* Operator.Word */
.codehilite.nord-darker .pm { color: #ECEFF4 } /* Punctuation.Marker */
.codehilite.nord-darker .w { color: #D8DEE9 } /* Text.Whitespace */
.codehilite.nord-darker .mb { color: #B48EAD } /* Literal.Number.Bin */
.codehilite.nord-darker .mf { color: #B48EAD } /* Literal.Number.Float */
.codehilite.nord-darker .mh { color: #B48EAD } /* Literal.Number.Hex */
.codehilite.nord-darker .mi { color: #B48EAD } /* Literal.Number.Integer */
.codehilite.nord-darker .mo { color: #B48EAD } /* Literal.Number.Oct */
.codehilite.nord-darker .sa { color: #A3BE8C } /* Literal.String.Affix */
.codehilite.nord-darker .sb { color: #A3BE8C } /* Literal.String.Backtick */
.codehilite.nord-darker .sc { color: #A3BE8C } /* Literal.String.Char */
.codehilite.nord-darker .dl { color: #A3BE8C } /* Literal.String.Delimiter */
.codehilite.nord-darker .sd { color: #616E87 } /* Literal.String.Doc */
.codehilite.nord-darker .s2 { color: #A3BE8C } /* Literal.String.Double */
.codehilite.nord-darker .se { color: #EBCB8B } /* Literal.String.Escape */
.codehilite.nord-darker .sh { color: #A3BE8C } /* Literal.String.Heredoc */
.codehilite.nord-darker .si { color: #A3BE8C } /* Literal.String.Interpol */
.codehilite.nord-darker .sx { color: #A3BE8C } /* Literal.String.Other */
.codehilite.nord-darker .sr { color: #EBCB8B } /* Literal.String.Regex */
.codehilite.nord-darker .s1 { color: #A3BE8C } /* Literal.String.Single */
.codehilite.nord-darker .ss { color: #A3BE8C } /* Literal.String.Symbol */
.codehilite.nord-darker .bp { color: #81A1C1 } /* Name.Builtin.Pseudo */
.codehilite.nord-darker .fm { color: #88C0D0 } /* Name.Function.Magic */
.codehilite.nord-darker .vc { color: #D8DEE9 } /* Name.Variable.Class */
.codehilite.nord-darker .vg { color: #D8DEE9 } /* Name.Variable.Global */
.codehilite.nord-darker .vi { color: #D8DEE9 } /* Name.Variable.Instance */
.codehilite.nord-darker .vm { color: #D8DEE9 } /* Name.Variable.Magic */
.codehilite.nord-darker .il { color: #B48EAD } /* Literal.Number.Integer.Long */
.codehilite.nord .hll { background-color: #3B4252 }
.codehilite.nord { background: #2E3440; color: #D8DEE9 }
.codehilite.nord .c { color: #616E87; font-style: italic } /* Comment */
.codehilite.nord .err { color: #BF616A } /* Error */
.codehilite.nord .esc { color: #D8DEE9 } /* Escape */
.codehilite.nord .g { color: #D8DEE9 } /* Generic */
.codehilite.nord .k { color: #81A1C1; font-weight: bold } /* Keyword */
.codehilite.nord .l { color: #D8DEE9 } /* Literal */
.codehilite.nord .n { color: #D8DEE9 } /* Name */
.codehilite.nord .o { color: #81A1C1; font-weight: bold } /* Operator */
.codehilite.nord .x { color: #D8DEE9 } /* Other */
.codehilite.nord .p { color: #ECEFF4 } /* Punctuation */
.codehilite.nord .ch { color: #616E87; font-style: italic } /* Comment.Hashbang */
.codehilite.nord .cm { color: #616E87; font-style: italic } /* Comment.Multiline */
.codehilite.nord .cp { color: #5E81AC; font-style: italic } /* Comment.Preproc */
.codehilite.nord .cpf { color: #616E87; font-style: italic } /* Comment.PreprocFile */
.codehilite.nord .c1 { color: #616E87; font-style: italic } /* Comment.Single */
.codehilite.nord .cs { color: #616E87; font-style: italic } /* Comment.Special */
.codehilite.nord .gd { color: #BF616A } /* Generic.Deleted */
.codehilite.nord .ge { color: #D8DEE9; font-style: italic } /* Generic.Emph */
.codehilite.nord .ges { color: #D8DEE9; font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.nord .gr { color: #BF616A } /* Generic.Error */
.codehilite.nord .gh { color: #88C0D0; font-weight: bold } /* Generic.Heading */
.codehilite.nord .gi { color: #A3BE8C } /* Generic.Inserted */
.codehilite.nord .go { color: #D8DEE9 } /* Generic.Output */
.codehilite.nord .gp { color: #616E88; font-weight: bold } /* Generic.Prompt */
.codehilite.nord .gs { color: #D8DEE9; font-weight: bold } /* Generic.Strong */
.codehilite.nord .gu { color: #88C0D0; font-weight: bold } /* Generic.Subheading */
.codehilite.nord .gt { color: #BF616A } /* Generic.Traceback */
.codehilite.nord .kc { color: #81A1C1; font-weight: bold } /* Keyword.Constant */
.codehilite.nord .kd { color: #81A1C1; font-weight: bold } /* Keyword.Declaration */
.codehilite.nord .kn { color: #81A1C1; font-weight: bold } /* Keyword.Namespace */
.codehilite.nord .kp { color: #81A1C1 } /* Keyword.Pseudo */
.codehilite.nord .kr { color: #81A1C1; font-weight: bold } /* Keyword.Reserved */
.codehilite.nord .kt { color: #81A1C1 } /* Keyword.Type */
.codehilite.nord .ld { color: #D8DEE9 } /* Literal.Date */
.codehilite.nord .m { color: #B48EAD } /* Literal.Number */
.codehilite.nord .s { color: #A3BE8C } /* Literal.String */
.codehilite.nord .na { color: #8FBCBB } /* Name.Attribute */
.codehilite.nord .nb { color: #81A1C1 } /* Name.Builtin */
.codehilite.nord .nc { color: #8FBCBB } /* Name.Class */
.codehilite.nord .no { color: #8FBCBB } /* Name.Constant */
.codehilite.nord .nd { color: #D08770 } /* Name.Decorator */
.codehilite.nord .ni { color: #D08770 } /* Name.Entity */
.codehilite.nord .ne { color: #BF616A } /* Name.Exception */
.codehilite.nord .nf { color: #88C0D0 } /* Name.Function */
.codehilite.nord .nl { color: #D8DEE9 } /* Name.Label */
.codehilite.nord .nn { color: #8FBCBB } /* Name.Namespace */
.codehilite.nord .nx { color: #D8DEE9 } /* Name.Other */
.codehilite.nord .py { color: #D8DEE9 } /* Name.Property */
.codehilite.nord .nt { color: #81A1C1 } /* Name.Tag */
.codehilite.nord .nv { color: #D8DEE9 } /* Name.Variable */
.codehilite.nord .ow { color: #81A1C1; font-weight: bold } /* Operator.Word */
.codehilite.nord .pm { color: #ECEFF4 } /* Punctuation.Marker */
.codehilite.nord .w { color: #D8DEE9 } /* Text.Whitespace */
.codehilite.nord .mb { color: #B48EAD } /* Literal.Number.Bin */
.codehilite.nord .mf { color: #B48EAD } /* Literal.Number.Float */
.codehilite.nord .mh { color: #B48EAD } /* Literal.Number.Hex */
.codehilite.nord .mi { color: #B48EAD } /* Literal.Number.Integer */
.codehilite.nord .mo { color: #B48EAD } /* Literal.Number.Oct */
.codehilite.nord .sa { color: #A3BE8C } /* Literal.String.Affix */
.codehilite.nord .sb { color: #A3BE8C } /* Literal.String.Backtick */
.codehilite.nord .sc { color: #A3BE8C } /* Literal.String.Char */
.codehilite.nord .dl { color: #A3BE8C } /* Literal.String.Delimiter */
.codehilite.nord .sd { color: #616E87 } /* Literal.String.Doc */
.codehilite.nord .s2 { color: #A3BE8C } /* Literal.String.Double */
.codehilite.nord .se { color: #EBCB8B } /* Literal.String.Escape */
.codehilite.nord .sh { color: #A3BE8C } /* Literal.String.Heredoc */
.codehilite.nord .si { color: #A3BE8C } /* Literal.String.Interpol */
.codehilite.nord .sx { color: #A3BE8C } /* Literal.String.Other */
.codehilite.nord .sr { color: #EBCB8B } /* Literal.String.Regex */
.codehilite.nord .s1 { color: #A3BE8C } /* Literal.String.Single */
.codehilite.nord .ss { color: #A3BE8C } /* Literal.String.Symbol */
.codehilite.nord .bp { color: #81A1C1 } /* Name.Builtin.Pseudo */
.codehilite.nord .fm { color: #88C0D0 } /* Name.Function.Magic */
.codehilite.nord .vc { color: #D8DEE9 } /* Name.Variable.Class */
.codehilite.nord .vg { color: #D8DEE9 } /* Name.Variable.Global */
.codehilite.nord .vi { color: #D8DEE9 } /* Name.Variable.Instance */
.codehilite.nord .vm { color: #D8DEE9 } /* Name.Variable.Magic */
.codehilite.nord .il { color: #B48EAD } /* Literal.Number.Integer.Long */
.codehilite.one-dark .hll { background-color: #ffffcc }
.codehilite.one-dark { background: #282C34; color: #ABB2BF }
.codehilite.one-dark .c { color: #7F848E } /* Comment */
.codehilite.one-dark .err { color: #ABB2BF } /* Error */
.codehilite.one-dark .esc { color: #ABB2BF } /* Escape */
.codehilite.one-dark .g { color: #ABB2BF } /* Generic */
.codehilite.one-dark .k { color: #C678DD } /* Keyword */
.codehilite.one-dark .l { color: #ABB2BF } /* Literal */
.codehilite.one-dark .n { color: #E06C75 } /* Name */
.codehilite.one-dark .o { color: #56B6C2 } /* Operator */
.codehilite.one-dark .x { color: #ABB2BF } /* Other */
.codehilite.one-dark .p { color: #ABB2BF } /* Punctuation */
.codehilite.one-dark .ch { color: #7F848E } /* Comment.Hashbang */
.codehilite.one-dark .cm { color: #7F848E } /* Comment.Multiline */
.codehilite.one-dark .cp { color: #7F848E } /* Comment.Preproc */
.codehilite.one-dark .cpf { color: #7F848E } /* Comment.PreprocFile */
.codehilite.one-dark .c1 { color: #7F848E } /* Comment.Single */
.codehilite.one-dark .cs { color: #7F848E } /* Comment.Special */
.codehilite.one-dark .gd { color: #ABB2BF } /* Generic.Deleted */
.codehilite.one-dark .ge { color: #ABB2BF } /* Generic.Emph */
.codehilite.one-dark .ges { color: #ABB2BF } /* Generic.EmphStrong */
.codehilite.one-dark .gr { color: #ABB2BF } /* Generic.Error */
.codehilite.one-dark .gh { color: #ABB2BF } /* Generic.Heading */
.codehilite.one-dark .gi { color: #ABB2BF } /* Generic.Inserted */
.codehilite.one-dark .go { color: #ABB2BF } /* Generic.Output */
.codehilite.one-dark .gp { color: #ABB2BF } /* Generic.Prompt */
.codehilite.one-dark .gs { color: #ABB2BF } /* Generic.Strong */
.codehilite.one-dark .gu { color: #ABB2BF } /* Generic.Subheading */
.codehilite.one-dark .gt { color: #ABB2BF } /* Generic.Traceback */
.codehilite.one-dark .kc { color: #E5C07B } /* Keyword.Constant */
.codehilite.one-dark .kd { color: #C678DD } /* Keyword.Declaration */
.codehilite.one-dark .kn { color: #C678DD } /* Keyword.Namespace */
.codehilite.one-dark .kp { color: #C678DD } /* Keyword.Pseudo */
.codehilite.one-dark .kr { color: #C678DD } /* Keyword.Reserved */
.codehilite.one-dark .kt { color: #E5C07B } /* Keyword.Type */
.codehilite.one-dark .ld { color: #ABB2BF } /* Literal.Date */
.codehilite.one-dark .m { color: #D19A66 } /* Literal.Number */
.codehilite.one-dark .s { color: #98C379 } /* Literal.String */
.codehilite.one-dark .na { color: #E06C75 } /* Name.Attribute */
.codehilite.one-dark .nb { color: #E5C07B } /* Name.Builtin */
.codehilite.one-dark .nc { color: #E5C07B } /* Name.Class */
.codehilite.one-dark .no { color: #E06C75 } /* Name.Constant */
.codehilite.one-dark .nd { color: #61AFEF } /* Name.Decorator */
.codehilite.one-dark .ni { color: #E06C75 } /* Name.Entity */
.codehilite.one-dark .ne { color: #E06C75 } /* Name.Exception */
.codehilite.one-dark .nf { color: #61AFEF; font-weight: bold } /* Name.Function */
.codehilite.one-dark .nl { color: #E06C75 } /* Name.Label */
.codehilite.one-dark .nn { color: #E06C75 } /* Name.Namespace */
.codehilite.one-dark .nx { color: #E06C75 } /* Name.Other */
.codehilite.one-dark .py { color: #E06C75 } /* Name.Property */
.codehilite.one-dark .nt { color: #E06C75 } /* Name.Tag */
.codehilite.one-dark .nv { color: #E06C75 } /* Name.Variable */
.codehilite.one-dark .ow { color: #56B6C2 } /* Operator.Word */
.codehilite.one-dark .pm { color: #ABB2BF } /* Punctuation.Marker */
.codehilite.one-dark .w { color: #ABB2BF } /* Text.Whitespace */
.codehilite.one-dark .mb { color: #D19A66 } /* Literal.Number.Bin */
.codehilite.one-dark .mf { color: #D19A66 } /* Literal.Number.Float */
.codehilite.one-dark .mh { color: #D19A66 } /* Literal.Number.Hex */
.codehilite.one-dark .mi { color: #D19A66 } /* Literal.Number.Integer */
.codehilite.one-dark .mo { color: #D19A66 } /* Literal.Number.Oct */
.codehilite.one-dark .sa { color: #98C379 } /* Literal.String.Affix */
.codehilite.one-dark .sb { color: #98C379 } /* Literal.String.Backtick */
.codehilite.one-dark .sc { color: #98C379 } /* Literal.String.Char */
.codehilite.one-dark .dl { color: #98C379 } /* Literal.String.Delimiter */
.codehilite.one-dark .sd { color: #98C379 } /* Literal.String.Doc */
.codehilite.one-dark .s2 { color: #98C379 } /* Literal.String.Double */
.codehilite.one-dark .se { color: #98C379 } /* Literal.String.Escape */
.codehilite.one-dark .sh { color: #98C379 } /* Literal.String.Heredoc */
.codehilite.one-dark .si { color: #98C379 } /* Literal.String.Interpol */
.codehilite.one-dark .sx { color: #98C379 } /* Literal.String.Other */
.codehilite.one-dark .sr { color: #98C379 } /* Literal.String.Regex */
.codehilite.one-dark .s1 { color: #98C379 } /* Literal.String.Single */
.codehilite.one-dark .ss { color: #98C379 } /* Literal.String.Symbol */
.codehilite.one-dark .bp { color: #E5C07B } /* Name.Builtin.Pseudo */
.codehilite.one-dark .fm { color: #56B6C2; font-weight: bold } /* Name.Function.Magic */
.codehilite.one-dark .vc { color: #E06C75 } /* Name.Variable.Class */
.codehilite.one-dark .vg { color: #E06C75 } /* Name.Variable.Global */
.codehilite.one-dark .vi { color: #E06C75 } /* Name.Variable.Instance */
.codehilite.one-dark .vm { color: #E06C75 } /* Name.Variable.Magic */
.codehilite.one-dark .il { color: #D19A66 } /* Literal.Number.Integer.Long */
.codehilite.paraiso-dark .hll { background-color: #4f424c }
.codehilite.paraiso-dark { background: #2f1e2e; color: #E7E9DB }
.codehilite.paraiso-dark .c { color: #776E71 } /* Comment */
.codehilite.paraiso-dark .err { color: #EF6155 } /* Error */
.codehilite.paraiso-dark .k { color: #815BA4 } /* Keyword */
.codehilite.paraiso-dark .l { color: #F99B15 } /* Literal */
.codehilite.paraiso-dark .n { color: #E7E9DB } /* Name */
.codehilite.paraiso-dark .o { color: #5BC4BF } /* Operator */
.codehilite.paraiso-dark .p { color: #E7E9DB } /* Punctuation */
.codehilite.paraiso-dark .ch { color: #776E71 } /* Comment.Hashbang */
.codehilite.paraiso-dark .cm { color: #776E71 } /* Comment.Multiline */
.codehilite.paraiso-dark .cp { color: #776E71 } /* Comment.Preproc */
.codehilite.paraiso-dark .cpf { color: #776E71 } /* Comment.PreprocFile */
.codehilite.paraiso-dark .c1 { color: #776E71 } /* Comment.Single */
.codehilite.paraiso-dark .cs { color: #776E71 } /* Comment.Special */
.codehilite.paraiso-dark .gd { color: #EF6155 } /* Generic.Deleted */
.codehilite.paraiso-dark .ge { font-style: italic } /* Generic.Emph */
.codehilite.paraiso-dark .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.paraiso-dark .gh { color: #E7E9DB; font-weight: bold } /* Generic.Heading */
.codehilite.paraiso-dark .gi { color: #48B685 } /* Generic.Inserted */
.codehilite.paraiso-dark .gp { color: #776E71; font-weight: bold } /* Generic.Prompt */
.codehilite.paraiso-dark .gs { font-weight: bold } /* Generic.Strong */
.codehilite.paraiso-dark .gu { color: #5BC4BF; font-weight: bold } /* Generic.Subheading */
.codehilite.paraiso-dark .kc { color: #815BA4 } /* Keyword.Constant */
.codehilite.paraiso-dark .kd { color: #815BA4 } /* Keyword.Declaration */
.codehilite.paraiso-dark .kn { color: #5BC4BF } /* Keyword.Namespace */
.codehilite.paraiso-dark .kp { color: #815BA4 } /* Keyword.Pseudo */
.codehilite.paraiso-dark .kr { color: #815BA4 } /* Keyword.Reserved */
.codehilite.paraiso-dark .kt { color: #FEC418 } /* Keyword.Type */
.codehilite.paraiso-dark .ld { color: #48B685 } /* Literal.Date */
.codehilite.paraiso-dark .m { color: #F99B15 } /* Literal.Number */
.codehilite.paraiso-dark .s { color: #48B685 } /* Literal.String */
.codehilite.paraiso-dark .na { color: #06B6EF } /* Name.Attribute */
.codehilite.paraiso-dark .nb { color: #E7E9DB } /* Name.Builtin */
.codehilite.paraiso-dark .nc { color: #FEC418 } /* Name.Class */
.codehilite.paraiso-dark .no { color: #EF6155 } /* Name.Constant */
.codehilite.paraiso-dark .nd { color: #5BC4BF } /* Name.Decorator */
.codehilite.paraiso-dark .ni { color: #E7E9DB } /* Name.Entity */
.codehilite.paraiso-dark .ne { color: #EF6155 } /* Name.Exception */
.codehilite.paraiso-dark .nf { color: #06B6EF } /* Name.Function */
.codehilite.paraiso-dark .nl { color: #E7E9DB } /* Name.Label */
.codehilite.paraiso-dark .nn { color: #FEC418 } /* Name.Namespace */
.codehilite.paraiso-dark .nx { color: #06B6EF } /* Name.Other */
.codehilite.paraiso-dark .py { color: #E7E9DB } /* Name.Property */
.codehilite.paraiso-dark .nt { color: #5BC4BF } /* Name.Tag */
.codehilite.paraiso-dark .nv { color: #EF6155 } /* Name.Variable */
.codehilite.paraiso-dark .ow { color: #5BC4BF } /* Operator.Word */
.codehilite.paraiso-dark .pm { color: #E7E9DB } /* Punctuation.Marker */
.codehilite.paraiso-dark .w { color: #E7E9DB } /* Text.Whitespace */
.codehilite.paraiso-dark .mb { color: #F99B15 } /* Literal.Number.Bin */
.codehilite.paraiso-dark .mf { color: #F99B15 } /* Literal.Number.Float */
.codehilite.paraiso-dark .mh { color: #F99B15 } /* Literal.Number.Hex */
.codehilite.paraiso-dark .mi { color: #F99B15 } /* Literal.Number.Integer */
.codehilite.paraiso-dark .mo { color: #F99B15 } /* Literal.Number.Oct */
.codehilite.paraiso-dark .sa { color: #48B685 } /* Literal.String.Affix */
.codehilite.paraiso-dark .sb { color: #48B685 } /* Literal.String.Backtick */
.codehilite.paraiso-dark .sc { color: #E7E9DB } /* Literal.String.Char */
.codehilite.paraiso-dark .dl { color: #48B685 } /* Literal.String.Delimiter */
.codehilite.paraiso-dark .sd { color: #776E71 } /* Literal.String.Doc */
.codehilite.paraiso-dark .s2 { color: #48B685 } /* Literal.String.Double */
.codehilite.paraiso-dark .se { color: #F99B15 } /* Literal.String.Escape */
.codehilite.paraiso-dark .sh { color: #48B685 } /* Literal.String.Heredoc */
.codehilite.paraiso-dark .si { color: #F99B15 } /* Literal.String.Interpol */
.codehilite.paraiso-dark .sx { color: #48B685 } /* Literal.String.Other */
.codehilite.paraiso-dark .sr { color: #48B685 } /* Literal.String.Regex */
.codehilite.paraiso-dark .s1 { color: #48B685 } /* Literal.String.Single */
.codehilite.paraiso-dark .ss { color: #48B685 } /* Literal.String.Symbol */
.codehilite.paraiso-dark .bp { color: #E7E9DB } /* Name.Builtin.Pseudo */
.codehilite.paraiso-dark .fm { color: #06B6EF } /* Name.Function.Magic */
.codehilite.paraiso-dark .vc { color: #EF6155 } /* Name.Variable.Class */
.codehilite.paraiso-dark .vg { color: #EF6155 } /* Name.Variable.Global */
.codehilite.paraiso-dark .vi { color: #EF6155 } /* Name.Variable.Instance */
.codehilite.paraiso-dark .vm { color: #EF6155 } /* Name.Variable.Magic */
.codehilite.paraiso-dark .il { color: #F99B15 } /* Literal.Number.Integer.Long */
.codehilite.paraiso-light .hll { background-color: #a39e9b }
.codehilite.paraiso-light { background: #e7e9db; color: #2F1E2E }
.codehilite.paraiso-light .c { color: #8D8687 } /* Comment */
.codehilite.paraiso-light .err { color: #EF6155 } /* Error */
.codehilite.paraiso-light .k { color: #815BA4 } /* Keyword */
.codehilite.paraiso-light .l { color: #F99B15 } /* Literal */
.codehilite.paraiso-light .n { color: #2F1E2E } /* Name */
.codehilite.paraiso-light .o { color: #5BC4BF } /* Operator */
.codehilite.paraiso-light .p { color: #2F1E2E } /* Punctuation */
.codehilite.paraiso-light .ch { color: #8D8687 } /* Comment.Hashbang */
.codehilite.paraiso-light .cm { color: #8D8687 } /* Comment.Multiline */
.codehilite.paraiso-light .cp { color: #8D8687 } /* Comment.Preproc */
.codehilite.paraiso-light .cpf { color: #8D8687 } /* Comment.PreprocFile */
.codehilite.paraiso-light .c1 { color: #8D8687 } /* Comment.Single */
.codehilite.paraiso-light .cs { color: #8D8687 } /* Comment.Special */
.codehilite.paraiso-light .gd { color: #EF6155 } /* Generic.Deleted */
.codehilite.paraiso-light .ge { font-style: italic } /* Generic.Emph */
.codehilite.paraiso-light .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.paraiso-light .gh { color: #2F1E2E; font-weight: bold } /* Generic.Heading */
.codehilite.paraiso-light .gi { color: #48B685 } /* Generic.Inserted */
.codehilite.paraiso-light .gp { color: #8D8687; font-weight: bold } /* Generic.Prompt */
.codehilite.paraiso-light .gs { font-weight: bold } /* Generic.Strong */
.codehilite.paraiso-light .gu { color: #5BC4BF; font-weight: bold } /* Generic.Subheading */
.codehilite.paraiso-light .kc { color: #815BA4 } /* Keyword.Constant */
.codehilite.paraiso-light .kd { color: #815BA4 } /* Keyword.Declaration */
.codehilite.paraiso-light .kn { color: #5BC4BF } /* Keyword.Namespace */
.codehilite.paraiso-light .kp { color: #815BA4 } /* Keyword.Pseudo */
.codehilite.paraiso-light .kr { color: #815BA4 } /* Keyword.Reserved */
.codehilite.paraiso-light .kt { color: #FEC418 } /* Keyword.Type */
.codehilite.paraiso-light .ld { color: #48B685 } /* Literal.Date */
.codehilite.paraiso-light .m { color: #F99B15 } /* Literal.Number */
.codehilite.paraiso-light .s { color: #48B685 } /* Literal.String */
.codehilite.paraiso-light .na { color: #06B6EF } /* Name.Attribute */
.codehilite.paraiso-light .nb { color: #2F1E2E } /* Name.Builtin */
.codehilite.paraiso-light .nc { color: #FEC418 } /* Name.Class */
.codehilite.paraiso-light .no { color: #EF6155 } /* Name.Constant */
.codehilite.paraiso-light .nd { color: #5BC4BF } /* Name.Decorator */
.codehilite.paraiso-light .ni { color: #2F1E2E } /* Name.Entity */
.codehilite.paraiso-light .ne { color: #EF6155 } /* Name.Exception */
.codehilite.paraiso-light .nf { color: #06B6EF } /* Name.Function */
.codehilite.paraiso-light .nl { color: #2F1E2E } /* Name.Label */
.codehilite.paraiso-light .nn { color: #FEC418 } /* Name.Namespace */
.codehilite.paraiso-light .nx { color: #06B6EF } /* Name.Other */
.codehilite.paraiso-light .py { color: #2F1E2E } /* Name.Property */
.codehilite.paraiso-light .nt { color: #5BC4BF } /* Name.Tag */
.codehilite.paraiso-light .nv { color: #EF6155 } /* Name.Variable */
.codehilite.paraiso-light .ow { color: #5BC4BF } /* Operator.Word */
.codehilite.paraiso-light .pm { color: #2F1E2E } /* Punctuation.Marker */
.codehilite.paraiso-light .w { color: #2F1E2E } /* Text.Whitespace */
.codehilite.paraiso-light .mb { color: #F99B15 } /* Literal.Number.Bin */
.codehilite.paraiso-light .mf { color: #F99B15 } /* Literal.Number.Float */
.codehilite.paraiso-light .mh { color: #F99B15 } /* Literal.Number.Hex */
.codehilite.paraiso-light .mi { color: #F99B15 } /* Literal.Number.Integer */
.codehilite.paraiso-light .mo { color: #F99B15 } /* Literal.Number.Oct */
.codehilite.paraiso-light .sa { color: #48B685 } /* Literal.String.Affix */
.codehilite.paraiso-light .sb { color: #48B685 } /* Literal.String.Backtick */
.codehilite.paraiso-light .sc { color: #2F1E2E } /* Literal.String.Char */
.codehilite.paraiso-light .dl { color: #48B685 } /* Literal.String.Delimiter */
.codehilite.paraiso-light .sd { color: #8D8687 } /* Literal.String.Doc */
.codehilite.paraiso-light .s2 { color: #48B685 } /* Literal.String.Double */
.codehilite.paraiso-light .se { color: #F99B15 } /* Literal.String.Escape */
.codehilite.paraiso-light .sh { color: #48B685 } /* Literal.String.Heredoc */
.codehilite.paraiso-light .si { color: #F99B15 } /* Literal.String.Interpol */
.codehilite.paraiso-light .sx { color: #48B685 } /* Literal.String.Other */
.codehilite.paraiso-light .sr { color: #48B685 } /* Literal.String.Regex */
.codehilite.paraiso-light .s1 { color: #48B685 } /* Literal.String.Single */
.codehilite.paraiso-light .ss { color: #48B685 } /* Literal.String.Symbol */
.codehilite.paraiso-light .bp { color: #2F1E2E } /* Name.Builtin.Pseudo */
.codehilite.paraiso-light .fm { color: #06B6EF } /* Name.Function.Magic */
.codehilite.paraiso-light .vc { color: #EF6155 } /* Name.Variable.Class */
.codehilite.paraiso-light .vg { color: #EF6155 } /* Name.Variable.Global */
.codehilite.paraiso-light .vi { color: #EF6155 } /* Name.Variable.Instance */
.codehilite.paraiso-light .vm { color: #EF6155 } /* Name.Variable.Magic */
.codehilite.paraiso-light .il { color: #F99B15 } /* Literal.Number.Integer.Long */
.codehilite.pastie .hll { background-color: #ffffcc }
.codehilite.pastie { background: #ffffff; }
.codehilite.pastie .c { color: #888 } /* Comment */
.codehilite.pastie .err { color: #A61717; background-color: #E3D2D2 } /* Error */
.codehilite.pastie .k { color: #080; font-weight: bold } /* Keyword */
.codehilite.pastie .ch { color: #888 } /* Comment.Hashbang */
.codehilite.pastie .cm { color: #888 } /* Comment.Multiline */
.codehilite.pastie .cp { color: #C00; font-weight: bold } /* Comment.Preproc */
.codehilite.pastie .cpf { color: #888 } /* Comment.PreprocFile */
.codehilite.pastie .c1 { color: #888 } /* Comment.Single */
.codehilite.pastie .cs { color: #C00; font-weight: bold; background-color: #FFF0F0 } /* Comment.Special */
.codehilite.pastie .gd { color: #000; background-color: #FDD } /* Generic.Deleted */
.codehilite.pastie .ge { font-style: italic } /* Generic.Emph */
.codehilite.pastie .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.pastie .gr { color: #A00 } /* Generic.Error */
.codehilite.pastie .gh { color: #333 } /* Generic.Heading */
.codehilite.pastie .gi { color: #000; background-color: #DFD } /* Generic.Inserted */
.codehilite.pastie .go { color: #888 } /* Generic.Output */
.codehilite.pastie .gp { color: #555 } /* Generic.Prompt */
.codehilite.pastie .gs { font-weight: bold } /* Generic.Strong */
.codehilite.pastie .gu { color: #666 } /* Generic.Subheading */
.codehilite.pastie .gt { color: #A00 } /* Generic.Traceback */
.codehilite.pastie .kc { color: #080; font-weight: bold } /* Keyword.Constant */
.codehilite.pastie .kd { color: #080; font-weight: bold } /* Keyword.Declaration */
.codehilite.pastie .kn { color: #080; font-weight: bold } /* Keyword.Namespace */
.codehilite.pastie .kp { color: #080 } /* Keyword.Pseudo */
.codehilite.pastie .kr { color: #080; font-weight: bold } /* Keyword.Reserved */
.codehilite.pastie .kt { color: #888; font-weight: bold } /* Keyword.Type */
.codehilite.pastie .m { color: #00D; font-weight: bold } /* Literal.Number */
.codehilite.pastie .s { color: #D20; background-color: #FFF0F0 } /* Literal.String */
.codehilite.pastie .na { color: #369 } /* Name.Attribute */
.codehilite.pastie .nb { color: #038 } /* Name.Builtin */
.codehilite.pastie .nc { color: #B06; font-weight: bold } /* Name.Class */
.codehilite.pastie .no { color: #036; font-weight: bold } /* Name.Constant */
.codehilite.pastie .nd { color: #555 } /* Name.Decorator */
.codehilite.pastie .ne { color: #B06; font-weight: bold } /* Name.Exception */
.codehilite.pastie .nf { color: #06B; font-weight: bold } /* Name.Function */
.codehilite.pastie .nl { color: #369; font-style: italic } /* Name.Label */
.codehilite.pastie .nn { color: #B06; font-weight: bold } /* Name.Namespace */
.codehilite.pastie .py { color: #369; font-weight: bold } /* Name.Property */
.codehilite.pastie .nt { color: #B06; font-weight: bold } /* Name.Tag */
.codehilite.pastie .nv { color: #369 } /* Name.Variable */
.codehilite.pastie .ow { color: #080 } /* Operator.Word */
.codehilite.pastie .w { color: #BBB } /* Text.Whitespace */
.codehilite.pastie .mb { color: #00D; font-weight: bold } /* Literal.Number.Bin */
.codehilite.pastie .mf { color: #00D; font-weight: bold } /* Literal.Number.Float */
.codehilite.pastie .mh { color: #00D; font-weight: bold } /* Literal.Number.Hex */
.codehilite.pastie .mi { color: #00D; font-weight: bold } /* Literal.Number.Integer */
.codehilite.pastie .mo { color: #00D; font-weight: bold } /* Literal.Number.Oct */
.codehilite.pastie .sa { color: #D20; background-color: #FFF0F0 } /* Literal.String.Affix */
.codehilite.pastie .sb { color: #D20; background-color: #FFF0F0 } /* Literal.String.Backtick */
.codehilite.pastie .sc { color: #D20; background-color: #FFF0F0 } /* Literal.String.Char */
.codehilite.pastie .dl { color: #D20; background-color: #FFF0F0 } /* Literal.String.Delimiter */
.codehilite.pastie .sd { color: #D20; background-color: #FFF0F0 } /* Literal.String.Doc */
.codehilite.pastie .s2 { color: #D20; background-color: #FFF0F0 } /* Literal.String.Double */
.codehilite.pastie .se { color: #04D; background-color: #FFF0F0 } /* Literal.String.Escape */
.codehilite.pastie .sh { color: #D20; background-color: #FFF0F0 } /* Literal.String.Heredoc */
.codehilite.pastie .si { color: #33B; background-color: #FFF0F0 } /* Literal.String.Interpol */
.codehilite.pastie .sx { color: #2B2; background-color: #F0FFF0 } /* Literal.String.Other */
.codehilite.pastie .sr { color: #080; background-color: #FFF0FF } /* Literal.String.Regex */
.codehilite.pastie .s1 { color: #D20; background-color: #FFF0F0 } /* Literal.String.Single */
.codehilite.pastie .ss { color: #A60; background-color: #FFF0F0 } /* Literal.String.Symbol */
.codehilite.pastie .bp { color: #038 } /* Name.Builtin.Pseudo */
.codehilite.pastie .fm { color: #06B; font-weight: bold } /* Name.Function.Magic */
.codehilite.pastie .vc { color: #369 } /* Name.Variable.Class */
.codehilite.pastie .vg { color: #D70 } /* Name.Variable.Global */
.codehilite.pastie .vi { color: #33B } /* Name.Variable.Instance */
.codehilite.pastie .vm { color: #369 } /* Name.Variable.Magic */
.codehilite.pastie .il { color: #00D; font-weight: bold } /* Literal.Number.Integer.Long */
.codehilite.perldoc .hll { background-color: #ffffcc }
.codehilite.perldoc { background: #eeeedd; }
.codehilite.perldoc .c { color: #228B22 } /* Comment */
.codehilite.perldoc .err { color: #A61717; background-color: #E3D2D2 } /* Error */
.codehilite.perldoc .k { color: #8B008B; font-weight: bold } /* Keyword */
.codehilite.perldoc .ch { color: #228B22 } /* Comment.Hashbang */
.codehilite.perldoc .cm { color: #228B22 } /* Comment.Multiline */
.codehilite.perldoc .cp { color: #1E889B } /* Comment.Preproc */
.codehilite.perldoc .cpf { color: #228B22 } /* Comment.PreprocFile */
.codehilite.perldoc .c1 { color: #228B22 } /* Comment.Single */
.codehilite.perldoc .cs { color: #8B008B; font-weight: bold } /* Comment.Special */
.codehilite.perldoc .gd { color: #A00 } /* Generic.Deleted */
.codehilite.perldoc .ge { font-style: italic } /* Generic.Emph */
.codehilite.perldoc .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.perldoc .gr { color: #A00 } /* Generic.Error */
.codehilite.perldoc .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite.perldoc .gi { color: #0A0 } /* Generic.Inserted */
.codehilite.perldoc .go { color: #888 } /* Generic.Output */
.codehilite.perldoc .gp { color: #555 } /* Generic.Prompt */
.codehilite.perldoc .gs { font-weight: bold } /* Generic.Strong */
.codehilite.perldoc .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite.perldoc .gt { color: #A00 } /* Generic.Traceback */
.codehilite.perldoc .kc { color: #8B008B; font-weight: bold } /* Keyword.Constant */
.codehilite.perldoc .kd { color: #8B008B; font-weight: bold } /* Keyword.Declaration */
.codehilite.perldoc .kn { color: #8B008B; font-weight: bold } /* Keyword.Namespace */
.codehilite.perldoc .kp { color: #8B008B; font-weight: bold } /* Keyword.Pseudo */
.codehilite.perldoc .kr { color: #8B008B; font-weight: bold } /* Keyword.Reserved */
.codehilite.perldoc .kt { color: #00688B; font-weight: bold } /* Keyword.Type */
.codehilite.perldoc .m { color: #B452CD } /* Literal.Number */
.codehilite.perldoc .s { color: #CD5555 } /* Literal.String */
.codehilite.perldoc .na { color: #658B00 } /* Name.Attribute */
.codehilite.perldoc .nb { color: #658B00 } /* Name.Builtin */
.codehilite.perldoc .nc { color: #008B45; font-weight: bold } /* Name.Class */
.codehilite.perldoc .no { color: #00688B } /* Name.Constant */
.codehilite.perldoc .nd { color: #707A7C } /* Name.Decorator */
.codehilite.perldoc .ne { color: #008B45; font-weight: bold } /* Name.Exception */
.codehilite.perldoc .nf { color: #008B45 } /* Name.Function */
.codehilite.perldoc .nn { color: #008B45; text-decoration: underline } /* Name.Namespace */
.codehilite.perldoc .nt { color: #8B008B; font-weight: bold } /* Name.Tag */
.codehilite.perldoc .nv { color: #00688B } /* Name.Variable */
.codehilite.perldoc .ow { color: #8B008B } /* Operator.Word */
.codehilite.perldoc .w { color: #BBB } /* Text.Whitespace */
.codehilite.perldoc .mb { color: #B452CD } /* Literal.Number.Bin */
.codehilite.perldoc .mf { color: #B452CD } /* Literal.Number.Float */
.codehilite.perldoc .mh { color: #B452CD } /* Literal.Number.Hex */
.codehilite.perldoc .mi { color: #B452CD } /* Literal.Number.Integer */
.codehilite.perldoc .mo { color: #B452CD } /* Literal.Number.Oct */
.codehilite.perldoc .sa { color: #CD5555 } /* Literal.String.Affix */
.codehilite.perldoc .sb { color: #CD5555 } /* Literal.String.Backtick */
.codehilite.perldoc .sc { color: #CD5555 } /* Literal.String.Char */
.codehilite.perldoc .dl { color: #CD5555 } /* Literal.String.Delimiter */
.codehilite.perldoc .sd { color: #CD5555 } /* Literal.String.Doc */
.codehilite.perldoc .s2 { color: #CD5555 } /* Literal.String.Double */
.codehilite.perldoc .se { color: #CD5555 } /* Literal.String.Escape */
.codehilite.perldoc .sh { color: #1C7E71; font-style: italic } /* Literal.String.Heredoc */
.codehilite.perldoc .si { color: #CD5555 } /* Literal.String.Interpol */
.codehilite.perldoc .sx { color: #CB6C20 } /* Literal.String.Other */
.codehilite.perldoc .sr { color: #1C7E71 } /* Literal.String.Regex */
.codehilite.perldoc .s1 { color: #CD5555 } /* Literal.String.Single */
.codehilite.perldoc .ss { color: #CD5555 } /* Literal.String.Symbol */
.codehilite.perldoc .bp { color: #658B00 } /* Name.Builtin.Pseudo */
.codehilite.perldoc .fm { color: #008B45 } /* Name.Function.Magic */
.codehilite.perldoc .vc { color: #00688B } /* Name.Variable.Class */
.codehilite.perldoc .vg { color: #00688B } /* Name.Variable.Global */
.codehilite.perldoc .vi { color: #00688B } /* Name.Variable.Instance */
.codehilite.perldoc .vm { color: #00688B } /* Name.Variable.Magic */
.codehilite.perldoc .il { color: #B452CD } /* Literal.Number.Integer.Long */
.codehilite.rainbow_dash .hll { background-color: #ffffcc }
.codehilite.rainbow_dash { background: #ffffff; color: #4D4D4D }
.codehilite.rainbow_dash .c { color: #0080FF; font-style: italic } /* Comment */
.codehilite.rainbow_dash .err { color: #FFF; background-color: #C00 } /* Error */
.codehilite.rainbow_dash .k { color: #2C5DCD; font-weight: bold } /* Keyword */
.codehilite.rainbow_dash .o { color: #2C5DCD } /* Operator */
.codehilite.rainbow_dash .ch { color: #0080FF; font-style: italic } /* Comment.Hashbang */
.codehilite.rainbow_dash .cm { color: #0080FF; font-style: italic } /* Comment.Multiline */
.codehilite.rainbow_dash .cp { color: #0080FF } /* Comment.Preproc */
.codehilite.rainbow_dash .cpf { color: #0080FF; font-style: italic } /* Comment.PreprocFile */
.codehilite.rainbow_dash .c1 { color: #0080FF; font-style: italic } /* Comment.Single */
.codehilite.rainbow_dash .cs { color: #0080FF; font-weight: bold; font-style: italic } /* Comment.Special */
.codehilite.rainbow_dash .gd { background-color: #FCC; border: 1px solid #C5060B } /* Generic.Deleted */
.codehilite.rainbow_dash .ge { font-style: italic } /* Generic.Emph */
.codehilite.rainbow_dash .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.rainbow_dash .gr { color: #F00 } /* Generic.Error */
.codehilite.rainbow_dash .gh { color: #2C5DCD; font-weight: bold } /* Generic.Heading */
.codehilite.rainbow_dash .gi { background-color: #CFC; border: 1px solid #0C0 } /* Generic.Inserted */
.codehilite.rainbow_dash .go { color: #AAA } /* Generic.Output */
.codehilite.rainbow_dash .gp { color: #2C5DCD; font-weight: bold } /* Generic.Prompt */
.codehilite.rainbow_dash .gs { font-weight: bold } /* Generic.Strong */
.codehilite.rainbow_dash .gu { color: #2C5DCD; font-weight: bold } /* Generic.Subheading */
.codehilite.rainbow_dash .gt { color: #C5060B } /* Generic.Traceback */
.codehilite.rainbow_dash .kc { color: #2C5DCD; font-weight: bold } /* Keyword.Constant */
.codehilite.rainbow_dash .kd { color: #2C5DCD; font-weight: bold } /* Keyword.Declaration */
.codehilite.rainbow_dash .kn { color: #2C5DCD; font-weight: bold } /* Keyword.Namespace */
.codehilite.rainbow_dash .kp { color: #2C5DCD } /* Keyword.Pseudo */
.codehilite.rainbow_dash .kr { color: #2C5DCD; font-weight: bold } /* Keyword.Reserved */
.codehilite.rainbow_dash .kt { color: #5918BB; font-weight: bold } /* Keyword.Type */
.codehilite.rainbow_dash .m { color: #5918BB; font-weight: bold } /* Literal.Number */
.codehilite.rainbow_dash .s { color: #0C6 } /* Literal.String */
.codehilite.rainbow_dash .na { color: #2C5DCD; font-style: italic } /* Name.Attribute */
.codehilite.rainbow_dash .nb { color: #5918BB; font-weight: bold } /* Name.Builtin */
.codehilite.rainbow_dash .nc { text-decoration: underline } /* Name.Class */
.codehilite.rainbow_dash .no { color: #318495 } /* Name.Constant */
.codehilite.rainbow_dash .nd { color: #FF8000; font-weight: bold } /* Name.Decorator */
.codehilite.rainbow_dash .ni { color: #5918BB; font-weight: bold } /* Name.Entity */
.codehilite.rainbow_dash .ne { color: #5918BB; font-weight: bold } /* Name.Exception */
.codehilite.rainbow_dash .nf { color: #FF8000; font-weight: bold } /* Name.Function */
.codehilite.rainbow_dash .nt { color: #2C5DCD; font-weight: bold } /* Name.Tag */
.codehilite.rainbow_dash .ow { color: #2C5DCD; font-weight: bold } /* Operator.Word */
.codehilite.rainbow_dash .w { color: #CBCBCB } /* Text.Whitespace */
.codehilite.rainbow_dash .mb { color: #5918BB; font-weight: bold } /* Literal.Number.Bin */
.codehilite.rainbow_dash .mf { color: #5918BB; font-weight: bold } /* Literal.Number.Float */
.codehilite.rainbow_dash .mh { color: #5918BB; font-weight: bold } /* Literal.Number.Hex */
.codehilite.rainbow_dash .mi { color: #5918BB; font-weight: bold } /* Literal.Number.Integer */
.codehilite.rainbow_dash .mo { color: #5918BB; font-weight: bold } /* Literal.Number.Oct */
.codehilite.rainbow_dash .sa { color: #0C6 } /* Literal.String.Affix */
.codehilite.rainbow_dash .sb { color: #0C6 } /* Literal.String.Backtick */
.codehilite.rainbow_dash .sc { color: #0C6 } /* Literal.String.Char */
.codehilite.rainbow_dash .dl { color: #0C6 } /* Literal.String.Delimiter */
.codehilite.rainbow_dash .sd { color: #0C6; font-style: italic } /* Literal.String.Doc */
.codehilite.rainbow_dash .s2 { color: #0C6 } /* Literal.String.Double */
.codehilite.rainbow_dash .se { color: #C5060B; font-weight: bold } /* Literal.String.Escape */
.codehilite.rainbow_dash .sh { color: #0C6 } /* Literal.String.Heredoc */
.codehilite.rainbow_dash .si { color: #0C6 } /* Literal.String.Interpol */
.codehilite.rainbow_dash .sx { color: #318495 } /* Literal.String.Other */
.codehilite.rainbow_dash .sr { color: #0C6 } /* Literal.String.Regex */
.codehilite.rainbow_dash .s1 { color: #0C6 } /* Literal.String.Single */
.codehilite.rainbow_dash .ss { color: #C5060B; font-weight: bold } /* Literal.String.Symbol */
.codehilite.rainbow_dash .bp { color: #5918BB; font-weight: bold } /* Name.Builtin.Pseudo */
.codehilite.rainbow_dash .fm { color: #FF8000; font-weight: bold } /* Name.Function.Magic */
.codehilite.rainbow_dash .il { color: #5918BB; font-weight: bold } /* Literal.Number.Integer.Long */
.codehilite.rrt .hll { background-color: #0000ff }
.codehilite.rrt { background: #000000; color: #DDD }
.codehilite.rrt .c { color: #0F0 } /* Comment */
.codehilite.rrt .err { color: #DDD } /* Error */
.codehilite.rrt .esc { color: #DDD } /* Escape */
.codehilite.rrt .g { color: #DDD } /* Generic */
.codehilite.rrt .k { color: #F00 } /* Keyword */
.codehilite.rrt .l { color: #DDD } /* Literal */
.codehilite.rrt .n { color: #DDD } /* Name */
.codehilite.rrt .o { color: #DDD } /* Operator */
.codehilite.rrt .x { color: #DDD } /* Other */
.codehilite.rrt .p { color: #DDD } /* Punctuation */
.codehilite.rrt .ch { color: #0F0 } /* Comment.Hashbang */
.codehilite.rrt .cm { color: #0F0 } /* Comment.Multiline */
.codehilite.rrt .cp { color: #E5E5E5 } /* Comment.Preproc */
.codehilite.rrt .cpf { color: #0F0 } /* Comment.PreprocFile */
.codehilite.rrt .c1 { color: #0F0 } /* Comment.Single */
.codehilite.rrt .cs { color: #0F0 } /* Comment.Special */
.codehilite.rrt .gd { color: #DDD } /* Generic.Deleted */
.codehilite.rrt .ge { color: #DDD } /* Generic.Emph */
.codehilite.rrt .ges { color: #DDD } /* Generic.EmphStrong */
.codehilite.rrt .gr { color: #DDD } /* Generic.Error */
.codehilite.rrt .gh { color: #DDD } /* Generic.Heading */
.codehilite.rrt .gi { color: #DDD } /* Generic.Inserted */
.codehilite.rrt .go { color: #DDD } /* Generic.Output */
.codehilite.rrt .gp { color: #DDD } /* Generic.Prompt */
.codehilite.rrt .gs { color: #DDD } /* Generic.Strong */
.codehilite.rrt .gu { color: #DDD } /* Generic.Subheading */
.codehilite.rrt .gt { color: #DDD } /* Generic.Traceback */
.codehilite.rrt .kc { color: #F00 } /* Keyword.Constant */
.codehilite.rrt .kd { color: #F00 } /* Keyword.Declaration */
.codehilite.rrt .kn { color: #F00 } /* Keyword.Namespace */
.codehilite.rrt .kp { color: #F00 } /* Keyword.Pseudo */
.codehilite.rrt .kr { color: #F00 } /* Keyword.Reserved */
.codehilite.rrt .kt { color: #EE82EE } /* Keyword.Type */
.codehilite.rrt .ld { color: #DDD } /* Literal.Date */
.codehilite.rrt .m { color: #F0F } /* Literal.Number */
.codehilite.rrt .s { color: #87CEEB } /* Literal.String */
.codehilite.rrt .na { color: #DDD } /* Name.Attribute */
.codehilite.rrt .nb { color: #DDD } /* Name.Builtin */
.codehilite.rrt .nc { color: #DDD } /* Name.Class */
.codehilite.rrt .no { color: #7FFFD4 } /* Name.Constant */
.codehilite.rrt .nd { color: #DDD } /* Name.Decorator */
.codehilite.rrt .ni { color: #DDD } /* Name.Entity */
.codehilite.rrt .ne { color: #DDD } /* Name.Exception */
.codehilite.rrt .nf { color: #FF0 } /* Name.Function */
.codehilite.rrt .nl { color: #DDD } /* Name.Label */
.codehilite.rrt .nn { color: #DDD } /* Name.Namespace */
.codehilite.rrt .nx { color: #DDD } /* Name.Other */
.codehilite.rrt .py { color: #DDD } /* Name.Property */
.codehilite.rrt .nt { color: #DDD } /* Name.Tag */
.codehilite.rrt .nv { color: #EEDD82 } /* Name.Variable */
.codehilite.rrt .ow { color: #F00 } /* Operator.Word */
.codehilite.rrt .pm { color: #DDD } /* Punctuation.Marker */
.codehilite.rrt .w { color: #DDD } /* Text.Whitespace */
.codehilite.rrt .mb { color: #F0F } /* Literal.Number.Bin */
.codehilite.rrt .mf { color: #F0F } /* Literal.Number.Float */
.codehilite.rrt .mh { color: #F0F } /* Literal.Number.Hex */
.codehilite.rrt .mi { color: #F0F } /* Literal.Number.Integer */
.codehilite.rrt .mo { color: #F0F } /* Literal.Number.Oct */
.codehilite.rrt .sa { color: #87CEEB } /* Literal.String.Affix */
.codehilite.rrt .sb { color: #87CEEB } /* Literal.String.Backtick */
.codehilite.rrt .sc { color: #87CEEB } /* Literal.String.Char */
.codehilite.rrt .dl { color: #87CEEB } /* Literal.String.Delimiter */
.codehilite.rrt .sd { color: #87CEEB } /* Literal.String.Doc */
.codehilite.rrt .s2 { color: #87CEEB } /* Literal.String.Double */
.codehilite.rrt .se { color: #87CEEB } /* Literal.String.Escape */
.codehilite.rrt .sh { color: #87CEEB } /* Literal.String.Heredoc */
.codehilite.rrt .si { color: #87CEEB } /* Literal.String.Interpol */
.codehilite.rrt .sx { color: #87CEEB } /* Literal.String.Other */
.codehilite.rrt .sr { color: #87CEEB } /* Literal.String.Regex */
.codehilite.rrt .s1 { color: #87CEEB } /* Literal.String.Single */
.codehilite.rrt .ss { color: #87CEEB } /* Literal.String.Symbol */
.codehilite.rrt .bp { color: #DDD } /* Name.Builtin.Pseudo */
.codehilite.rrt .fm { color: #FF0 } /* Name.Function.Magic */
.codehilite.rrt .vc { color: #EEDD82 } /* Name.Variable.Class */
.codehilite.rrt .vg { color: #EEDD82 } /* Name.Variable.Global */
.codehilite.rrt .vi { color: #EEDD82 } /* Name.Variable.Instance */
.codehilite.rrt .vm { color: #EEDD82 } /* Name.Variable.Magic */
.codehilite.rrt .il { color: #F0F } /* Literal.Number.Integer.Long */
.codehilite.sas .hll { background-color: #ffffcc }
.codehilite.sas { background: #ffffff; }
.codehilite.sas .c { color: #080; font-style: italic } /* Comment */
.codehilite.sas .err { color: #A61717; background-color: #E3D2D2 } /* Error */
.codehilite.sas .g { color: #2C2CFF } /* Generic */
.codehilite.sas .k { color: #2C2CFF } /* Keyword */
.codehilite.sas .x { background-color: #FFFFE0 } /* Other */
.codehilite.sas .ch { color: #080; font-style: italic } /* Comment.Hashbang */
.codehilite.sas .cm { color: #080; font-style: italic } /* Comment.Multiline */
.codehilite.sas .cp { color: #080; font-style: italic } /* Comment.Preproc */
.codehilite.sas .cpf { color: #080; font-style: italic } /* Comment.PreprocFile */
.codehilite.sas .c1 { color: #080; font-style: italic } /* Comment.Single */
.codehilite.sas .cs { color: #080; font-style: italic } /* Comment.Special */
.codehilite.sas .gd { color: #2C2CFF } /* Generic.Deleted */
.codehilite.sas .ge { color: #080 } /* Generic.Emph */
.codehilite.sas .ges { color: #2C2CFF } /* Generic.EmphStrong */
.codehilite.sas .gr { color: #D30202 } /* Generic.Error */
.codehilite.sas .gh { color: #2C2CFF } /* Generic.Heading */
.codehilite.sas .gi { color: #2C2CFF } /* Generic.Inserted */
.codehilite.sas .go { color: #2C2CFF } /* Generic.Output */
.codehilite.sas .gp { color: #2C2CFF } /* Generic.Prompt */
.codehilite.sas .gs { color: #2C2CFF } /* Generic.Strong */
.codehilite.sas .gu { color: #2C2CFF } /* Generic.Subheading */
.codehilite.sas .gt { color: #2C2CFF } /* Generic.Traceback */
.codehilite.sas .kc { color: #2C2CFF; font-weight: bold } /* Keyword.Constant */
.codehilite.sas .kd { color: #2C2CFF } /* Keyword.Declaration */
.codehilite.sas .kn { color: #2C2CFF } /* Keyword.Namespace */
.codehilite.sas .kp { color: #2C2CFF } /* Keyword.Pseudo */
.codehilite.sas .kr { color: #353580; font-weight: bold } /* Keyword.Reserved */
.codehilite.sas .kt { color: #2C2CFF } /* Keyword.Type */
.codehilite.sas .m { color: #2C8553; font-weight: bold } /* Literal.Number */
.codehilite.sas .s { color: #800080 } /* Literal.String */
.codehilite.sas .nb { color: #2C2CFF } /* Name.Builtin */
.codehilite.sas .nf { font-weight: bold; font-style: italic } /* Name.Function */
.codehilite.sas .nv { color: #2C2CFF; font-weight: bold } /* Name.Variable */
.codehilite.sas .w { color: #BBB } /* Text.Whitespace */
.codehilite.sas .mb { color: #2C8553; font-weight: bold } /* Literal.Number.Bin */
.codehilite.sas .mf { color: #2C8553; font-weight: bold } /* Literal.Number.Float */
.codehilite.sas .mh { color: #2C8553; font-weight: bold } /* Literal.Number.Hex */
.codehilite.sas .mi { color: #2C8553; font-weight: bold } /* Literal.Number.Integer */
.codehilite.sas .mo { color: #2C8553; font-weight: bold } /* Literal.Number.Oct */
.codehilite.sas .sa { color: #800080 } /* Literal.String.Affix */
.codehilite.sas .sb { color: #800080 } /* Literal.String.Backtick */
.codehilite.sas .sc { color: #800080 } /* Literal.String.Char */
.codehilite.sas .dl { color: #800080 } /* Literal.String.Delimiter */
.codehilite.sas .sd { color: #800080 } /* Literal.String.Doc */
.codehilite.sas .s2 { color: #800080 } /* Literal.String.Double */
.codehilite.sas .se { color: #800080 } /* Literal.String.Escape */
.codehilite.sas .sh { color: #800080 } /* Literal.String.Heredoc */
.codehilite.sas .si { color: #800080 } /* Literal.String.Interpol */
.codehilite.sas .sx { color: #800080 } /* Literal.String.Other */
.codehilite.sas .sr { color: #800080 } /* Literal.String.Regex */
.codehilite.sas .s1 { color: #800080 } /* Literal.String.Single */
.codehilite.sas .ss { color: #800080 } /* Literal.String.Symbol */
.codehilite.sas .bp { color: #2C2CFF } /* Name.Builtin.Pseudo */
.codehilite.sas .fm { font-weight: bold; font-style: italic } /* Name.Function.Magic */
.codehilite.sas .vc { color: #2C2CFF; font-weight: bold } /* Name.Variable.Class */
.codehilite.sas .vg { color: #2C2CFF; font-weight: bold } /* Name.Variable.Global */
.codehilite.sas .vi { color: #2C2CFF; font-weight: bold } /* Name.Variable.Instance */
.codehilite.sas .vm { color: #2C2CFF; font-weight: bold } /* Name.Variable.Magic */
.codehilite.sas .il { color: #2C8553; font-weight: bold } /* Literal.Number.Integer.Long */
.codehilite.solarized-dark .hll { background-color: #073642 }
.codehilite.solarized-dark { background: #002b36; color: #839496 }
.codehilite.solarized-dark .c { color: #586E75; font-style: italic } /* Comment */
.codehilite.solarized-dark .err { color: #839496; background-color: #DC322F } /* Error */
.codehilite.solarized-dark .esc { color: #839496 } /* Escape */
.codehilite.solarized-dark .g { color: #839496 } /* Generic */
.codehilite.solarized-dark .k { color: #859900 } /* Keyword */
.codehilite.solarized-dark .l { color: #839496 } /* Literal */
.codehilite.solarized-dark .n { color: #839496 } /* Name */
.codehilite.solarized-dark .o { color: #586E75 } /* Operator */
.codehilite.solarized-dark .x { color: #839496 } /* Other */
.codehilite.solarized-dark .p { color: #839496 } /* Punctuation */
.codehilite.solarized-dark .ch { color: #586E75; font-style: italic } /* Comment.Hashbang */
.codehilite.solarized-dark .cm { color: #586E75; font-style: italic } /* Comment.Multiline */
.codehilite.solarized-dark .cp { color: #D33682 } /* Comment.Preproc */
.codehilite.solarized-dark .cpf { color: #586E75 } /* Comment.PreprocFile */
.codehilite.solarized-dark .c1 { color: #586E75; font-style: italic } /* Comment.Single */
.codehilite.solarized-dark .cs { color: #586E75; font-style: italic } /* Comment.Special */
.codehilite.solarized-dark .gd { color: #DC322F } /* Generic.Deleted */
.codehilite.solarized-dark .ge { color: #839496; font-style: italic } /* Generic.Emph */
.codehilite.solarized-dark .ges { color: #839496; font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.solarized-dark .gr { color: #DC322F } /* Generic.Error */
.codehilite.solarized-dark .gh { color: #839496; font-weight: bold } /* Generic.Heading */
.codehilite.solarized-dark .gi { color: #859900 } /* Generic.Inserted */
.codehilite.solarized-dark .go { color: #839496 } /* Generic.Output */
.codehilite.solarized-dark .gp { color: #268BD2; font-weight: bold } /* Generic.Prompt */
.codehilite.solarized-dark .gs { color: #839496; font-weight: bold } /* Generic.Strong */
.codehilite.solarized-dark .gu { color: #839496; text-decoration: underline } /* Generic.Subheading */
.codehilite.solarized-dark .gt { color: #268BD2 } /* Generic.Traceback */
.codehilite.solarized-dark .kc { color: #2AA198 } /* Keyword.Constant */
.codehilite.solarized-dark .kd { color: #2AA198 } /* Keyword.Declaration */
.codehilite.solarized-dark .kn { color: #CB4B16 } /* Keyword.Namespace */
.codehilite.solarized-dark .kp { color: #859900 } /* Keyword.Pseudo */
.codehilite.solarized-dark .kr { color: #859900 } /* Keyword.Reserved */
.codehilite.solarized-dark .kt { color: #B58900 } /* Keyword.Type */
.codehilite.solarized-dark .ld { color: #839496 } /* Literal.Date */
.codehilite.solarized-dark .m { color: #2AA198 } /* Literal.Number */
.codehilite.solarized-dark .s { color: #2AA198 } /* Literal.String */
.codehilite.solarized-dark .na { color: #839496 } /* Name.Attribute */
.codehilite.solarized-dark .nb { color: #268BD2 } /* Name.Builtin */
.codehilite.solarized-dark .nc { color: #268BD2 } /* Name.Class */
.codehilite.solarized-dark .no { color: #268BD2 } /* Name.Constant */
.codehilite.solarized-dark .nd { color: #268BD2 } /* Name.Decorator */
.codehilite.solarized-dark .ni { color: #268BD2 } /* Name.Entity */
.codehilite.solarized-dark .ne { color: #268BD2 } /* Name.Exception */
.codehilite.solarized-dark .nf { color: #268BD2 } /* Name.Function */
.codehilite.solarized-dark .nl { color: #268BD2 } /* Name.Label */
.codehilite.solarized-dark .nn { color: #268BD2 } /* Name.Namespace */
.codehilite.solarized-dark .nx { color: #839496 } /* Name.Other */
.codehilite.solarized-dark .py { color: #839496 } /* Name.Property */
.codehilite.solarized-dark .nt { color: #268BD2 } /* Name.Tag */
.codehilite.solarized-dark .nv { color: #268BD2 } /* Name.Variable */
.codehilite.solarized-dark .ow { color: #859900 } /* Operator.Word */
.codehilite.solarized-dark .pm { color: #839496 } /* Punctuation.Marker */
.codehilite.solarized-dark .w { color: #839496 } /* Text.Whitespace */
.codehilite.solarized-dark .mb { color: #2AA198 } /* Literal.Number.Bin */
.codehilite.solarized-dark .mf { color: #2AA198 } /* Literal.Number.Float */
.codehilite.solarized-dark .mh { color: #2AA198 } /* Literal.Number.Hex */
.codehilite.solarized-dark .mi { color: #2AA198 } /* Literal.Number.Integer */
.codehilite.solarized-dark .mo { color: #2AA198 } /* Literal.Number.Oct */
.codehilite.solarized-dark .sa { color: #2AA198 } /* Literal.String.Affix */
.codehilite.solarized-dark .sb { color: #2AA198 } /* Literal.String.Backtick */
.codehilite.solarized-dark .sc { color: #2AA198 } /* Literal.String.Char */
.codehilite.solarized-dark .dl { color: #2AA198 } /* Literal.String.Delimiter */
.codehilite.solarized-dark .sd { color: #586E75 } /* Literal.String.Doc */
.codehilite.solarized-dark .s2 { color: #2AA198 } /* Literal.String.Double */
.codehilite.solarized-dark .se { color: #2AA198 } /* Literal.String.Escape */
.codehilite.solarized-dark .sh { color: #2AA198 } /* Literal.String.Heredoc */
.codehilite.solarized-dark .si { color: #2AA198 } /* Literal.String.Interpol */
.codehilite.solarized-dark .sx { color: #2AA198 } /* Literal.String.Other */
.codehilite.solarized-dark .sr { color: #CB4B16 } /* Literal.String.Regex */
.codehilite.solarized-dark .s1 { color: #2AA198 } /* Literal.String.Single */
.codehilite.solarized-dark .ss { color: #2AA198 } /* Literal.String.Symbol */
.codehilite.solarized-dark .bp { color: #268BD2 } /* Name.Builtin.Pseudo */
.codehilite.solarized-dark .fm { color: #268BD2 } /* Name.Function.Magic */
.codehilite.solarized-dark .vc { color: #268BD2 } /* Name.Variable.Class */
.codehilite.solarized-dark .vg { color: #268BD2 } /* Name.Variable.Global */
.codehilite.solarized-dark .vi { color: #268BD2 } /* Name.Variable.Instance */
.codehilite.solarized-dark .vm { color: #268BD2 } /* Name.Variable.Magic */
.codehilite.solarized-dark .il { color: #2AA198 } /* Literal.Number.Integer.Long */
.codehilite.solarized-light .hll { background-color: #eee8d5 }
.codehilite.solarized-light { background: #fdf6e3; color: #657B83 }
.codehilite.solarized-light .c { color: #93A1A1; font-style: italic } /* Comment */
.codehilite.solarized-light .err { color: #657B83; background-color: #DC322F } /* Error */
.codehilite.solarized-light .esc { color: #657B83 } /* Escape */
.codehilite.solarized-light .g { color: #657B83 } /* Generic */
.codehilite.solarized-light .k { color: #859900 } /* Keyword */
.codehilite.solarized-light .l { color: #657B83 } /* Literal */
.codehilite.solarized-light .n { color: #657B83 } /* Name */
.codehilite.solarized-light .o { color: #93A1A1 } /* Operator */
.codehilite.solarized-light .x { color: #657B83 } /* Other */
.codehilite.solarized-light .p { color: #657B83 } /* Punctuation */
.codehilite.solarized-light .ch { color: #93A1A1; font-style: italic } /* Comment.Hashbang */
.codehilite.solarized-light .cm { color: #93A1A1; font-style: italic } /* Comment.Multiline */
.codehilite.solarized-light .cp { color: #D33682 } /* Comment.Preproc */
.codehilite.solarized-light .cpf { color: #93A1A1 } /* Comment.PreprocFile */
.codehilite.solarized-light .c1 { color: #93A1A1; font-style: italic } /* Comment.Single */
.codehilite.solarized-light .cs { color: #93A1A1; font-style: italic } /* Comment.Special */
.codehilite.solarized-light .gd { color: #DC322F } /* Generic.Deleted */
.codehilite.solarized-light .ge { color: #657B83; font-style: italic } /* Generic.Emph */
.codehilite.solarized-light .ges { color: #657B83; font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.solarized-light .gr { color: #DC322F } /* Generic.Error */
.codehilite.solarized-light .gh { color: #657B83; font-weight: bold } /* Generic.Heading */
.codehilite.solarized-light .gi { color: #859900 } /* Generic.Inserted */
.codehilite.solarized-light .go { color: #657B83 } /* Generic.Output */
.codehilite.solarized-light .gp { color: #268BD2; font-weight: bold } /* Generic.Prompt */
.codehilite.solarized-light .gs { color: #657B83; font-weight: bold } /* Generic.Strong */
.codehilite.solarized-light .gu { color: #657B83; text-decoration: underline } /* Generic.Subheading */
.codehilite.solarized-light .gt { color: #268BD2 } /* Generic.Traceback */
.codehilite.solarized-light .kc { color: #2AA198 } /* Keyword.Constant */
.codehilite.solarized-light .kd { color: #2AA198 } /* Keyword.Declaration */
.codehilite.solarized-light .kn { color: #CB4B16 } /* Keyword.Namespace */
.codehilite.solarized-light .kp { color: #859900 } /* Keyword.Pseudo */
.codehilite.solarized-light .kr { color: #859900 } /* Keyword.Reserved */
.codehilite.solarized-light .kt { color: #B58900 } /* Keyword.Type */
.codehilite.solarized-light .ld { color: #657B83 } /* Literal.Date */
.codehilite.solarized-light .m { color: #2AA198 } /* Literal.Number */
.codehilite.solarized-light .s { color: #2AA198 } /* Literal.String */
.codehilite.solarized-light .na { color: #657B83 } /* Name.Attribute */
.codehilite.solarized-light .nb { color: #268BD2 } /* Name.Builtin */
.codehilite.solarized-light .nc { color: #268BD2 } /* Name.Class */
.codehilite.solarized-light .no { color: #268BD2 } /* Name.Constant */
.codehilite.solarized-light .nd { color: #268BD2 } /* Name.Decorator */
.codehilite.solarized-light .ni { color: #268BD2 } /* Name.Entity */
.codehilite.solarized-light .ne { color: #268BD2 } /* Name.Exception */
.codehilite.solarized-light .nf { color: #268BD2 } /* Name.Function */
.codehilite.solarized-light .nl { color: #268BD2 } /* Name.Label */
.codehilite.solarized-light .nn { color: #268BD2 } /* Name.Namespace */
.codehilite.solarized-light .nx { color: #657B83 } /* Name.Other */
.codehilite.solarized-light .py { color: #657B83 } /* Name.Property */
.codehilite.solarized-light .nt { color: #268BD2 } /* Name.Tag */
.codehilite.solarized-light .nv { color: #268BD2 } /* Name.Variable */
.codehilite.solarized-light .ow { color: #859900 } /* Operator.Word */
.codehilite.solarized-light .pm { color: #657B83 } /* Punctuation.Marker */
.codehilite.solarized-light .w { color: #657B83 } /* Text.Whitespace */
.codehilite.solarized-light .mb { color: #2AA198 } /* Literal.Number.Bin */
.codehilite.solarized-light .mf { color: #2AA198 } /* Literal.Number.Float */
.codehilite.solarized-light .mh { color: #2AA198 } /* Literal.Number.Hex */
.codehilite.solarized-light .mi { color: #2AA198 } /* Literal.Number.Integer */
.codehilite.solarized-light .mo { color: #2AA198 } /* Literal.Number.Oct */
.codehilite.solarized-light .sa { color: #2AA198 } /* Literal.String.Affix */
.codehilite.solarized-light .sb { color: #2AA198 } /* Literal.String.Backtick */
.codehilite.solarized-light .sc { color: #2AA198 } /* Literal.String.Char */
.codehilite.solarized-light .dl { color: #2AA198 } /* Literal.String.Delimiter */
.codehilite.solarized-light .sd { color: #93A1A1 } /* Literal.String.Doc */
.codehilite.solarized-light .s2 { color: #2AA198 } /* Literal.String.Double */
.codehilite.solarized-light .se { color: #2AA198 } /* Literal.String.Escape */
.codehilite.solarized-light .sh { color: #2AA198 } /* Literal.String.Heredoc */
.codehilite.solarized-light .si { color: #2AA198 } /* Literal.String.Interpol */
.codehilite.solarized-light .sx { color: #2AA198 } /* Literal.String.Other */
.codehilite.solarized-light .sr { color: #CB4B16 } /* Literal.String.Regex */
.codehilite.solarized-light .s1 { color: #2AA198 } /* Literal.String.Single */
.codehilite.solarized-light .ss { color: #2AA198 } /* Literal.String.Symbol */
.codehilite.solarized-light .bp { color: #268BD2 } /* Name.Builtin.Pseudo */
.codehilite.solarized-light .fm { color: #268BD2 } /* Name.Function.Magic */
.codehilite.solarized-light .vc { color: #268BD2 } /* Name.Variable.Class */
.codehilite.solarized-light .vg { color: #268BD2 } /* Name.Variable.Global */
.codehilite.solarized-light .vi { color: #268BD2 } /* Name.Variable.Instance */
.codehilite.solarized-light .vm { color: #268BD2 } /* Name.Variable.Magic */
.codehilite.solarized-light .il { color: #2AA198 } /* Literal.Number.Integer.Long */
.codehilite.staroffice .hll { background-color: #ffffcc }
.codehilite.staroffice { background: #ffffff; color: #000080 }
.codehilite.staroffice .c { color: #696969 } /* Comment */
.codehilite.staroffice .err { color: #800000 } /* Error */
.codehilite.staroffice .esc { color: #000080 } /* Escape */
.codehilite.staroffice .g { color: #000080 } /* Generic */
.codehilite.staroffice .k { color: #000080 } /* Keyword */
.codehilite.staroffice .l { color: #E00 } /* Literal */
.codehilite.staroffice .n { color: #008000 } /* Name */
.codehilite.staroffice .o { color: #000080 } /* Operator */
.codehilite.staroffice .x { color: #000080 } /* Other */
.codehilite.staroffice .p { color: #000080 } /* Punctuation */
.codehilite.staroffice .ch { color: #696969 } /* Comment.Hashbang */
.codehilite.staroffice .cm { color: #696969 } /* Comment.Multiline */
.codehilite.staroffice .cp { color: #696969 } /* Comment.Preproc */
.codehilite.staroffice .cpf { color: #696969 } /* Comment.PreprocFile */
.codehilite.staroffice .c1 { color: #696969 } /* Comment.Single */
.codehilite.staroffice .cs { color: #696969 } /* Comment.Special */
.codehilite.staroffice .gd { color: #000080 } /* Generic.Deleted */
.codehilite.staroffice .ge { color: #000080 } /* Generic.Emph */
.codehilite.staroffice .ges { color: #000080 } /* Generic.EmphStrong */
.codehilite.staroffice .gr { color: #000080 } /* Generic.Error */
.codehilite.staroffice .gh { color: #000080 } /* Generic.Heading */
.codehilite.staroffice .gi { color: #000080 } /* Generic.Inserted */
.codehilite.staroffice .go { color: #000080 } /* Generic.Output */
.codehilite.staroffice .gp { color: #000080 } /* Generic.Prompt */
.codehilite.staroffice .gs { color: #000080 } /* Generic.Strong */
.codehilite.staroffice .gu { color: #000080 } /* Generic.Subheading */
.codehilite.staroffice .gt { color: #000080 } /* Generic.Traceback */
.codehilite.staroffice .kc { color: #000080 } /* Keyword.Constant */
.codehilite.staroffice .kd { color: #000080 } /* Keyword.Declaration */
.codehilite.staroffice .kn { color: #000080 } /* Keyword.Namespace */
.codehilite.staroffice .kp { color: #000080 } /* Keyword.Pseudo */
.codehilite.staroffice .kr { color: #000080 } /* Keyword.Reserved */
.codehilite.staroffice .kt { color: #000080 } /* Keyword.Type */
.codehilite.staroffice .ld { color: #E00 } /* Literal.Date */
.codehilite.staroffice .m { color: #E00 } /* Literal.Number */
.codehilite.staroffice .s { color: #E00 } /* Literal.String */
.codehilite.staroffice .na { color: #008000 } /* Name.Attribute */
.codehilite.staroffice .nb { color: #008000 } /* Name.Builtin */
.codehilite.staroffice .nc { color: #008000 } /* Name.Class */
.codehilite.staroffice .no { color: #008000 } /* Name.Constant */
.codehilite.staroffice .nd { color: #008000 } /* Name.Decorator */
.codehilite.staroffice .ni { color: #008000 } /* Name.Entity */
.codehilite.staroffice .ne { color: #008000 } /* Name.Exception */
.codehilite.staroffice .nf { color: #008000 } /* Name.Function */
.codehilite.staroffice .nl { color: #008000 } /* Name.Label */
.codehilite.staroffice .nn { color: #008000 } /* Name.Namespace */
.codehilite.staroffice .nx { color: #008000 } /* Name.Other */
.codehilite.staroffice .py { color: #008000 } /* Name.Property */
.codehilite.staroffice .nt { color: #008000 } /* Name.Tag */
.codehilite.staroffice .nv { color: #008000 } /* Name.Variable */
.codehilite.staroffice .ow { color: #000080 } /* Operator.Word */
.codehilite.staroffice .pm { color: #000080 } /* Punctuation.Marker */
.codehilite.staroffice .w { color: #000080 } /* Text.Whitespace */
.codehilite.staroffice .mb { color: #E00 } /* Literal.Number.Bin */
.codehilite.staroffice .mf { color: #E00 } /* Literal.Number.Float */
.codehilite.staroffice .mh { color: #E00 } /* Literal.Number.Hex */
.codehilite.staroffice .mi { color: #E00 } /* Literal.Number.Integer */
.codehilite.staroffice .mo { color: #E00 } /* Literal.Number.Oct */
.codehilite.staroffice .sa { color: #E00 } /* Literal.String.Affix */
.codehilite.staroffice .sb { color: #E00 } /* Literal.String.Backtick */
.codehilite.staroffice .sc { color: #E00 } /* Literal.String.Char */
.codehilite.staroffice .dl { color: #E00 } /* Literal.String.Delimiter */
.codehilite.staroffice .sd { color: #E00 } /* Literal.String.Doc */
.codehilite.staroffice .s2 { color: #E00 } /* Literal.String.Double */
.codehilite.staroffice .se { color: #E00 } /* Literal.String.Escape */
.codehilite.staroffice .sh { color: #E00 } /* Literal.String.Heredoc */
.codehilite.staroffice .si { color: #E00 } /* Literal.String.Interpol */
.codehilite.staroffice .sx { color: #E00 } /* Literal.String.Other */
.codehilite.staroffice .sr { color: #E00 } /* Literal.String.Regex */
.codehilite.staroffice .s1 { color: #E00 } /* Literal.String.Single */
.codehilite.staroffice .ss { color: #E00 } /* Literal.String.Symbol */
.codehilite.staroffice .bp { color: #008000 } /* Name.Builtin.Pseudo */
.codehilite.staroffice .fm { color: #008000 } /* Name.Function.Magic */
.codehilite.staroffice .vc { color: #008000 } /* Name.Variable.Class */
.codehilite.staroffice .vg { color: #008000 } /* Name.Variable.Global */
.codehilite.staroffice .vi { color: #008000 } /* Name.Variable.Instance */
.codehilite.staroffice .vm { color: #008000 } /* Name.Variable.Magic */
.codehilite.staroffice .il { color: #E00 } /* Literal.Number.Integer.Long */
.codehilite.stata-dark .hll { background-color: #49483e }
.codehilite.stata-dark { background: #232629; color: #CCC }
.codehilite.stata-dark .c { color: #777; font-style: italic } /* Comment */
.codehilite.stata-dark .err { color: #A61717; background-color: #E3D2D2 } /* Error */
.codehilite.stata-dark .esc { color: #CCC } /* Escape */
.codehilite.stata-dark .g { color: #CCC } /* Generic */
.codehilite.stata-dark .k { color: #7686BB; font-weight: bold } /* Keyword */
.codehilite.stata-dark .l { color: #CCC } /* Literal */
.codehilite.stata-dark .n { color: #CCC } /* Name */
.codehilite.stata-dark .o { color: #CCC } /* Operator */
.codehilite.stata-dark .x { color: #CCC } /* Other */
.codehilite.stata-dark .p { color: #CCC } /* Punctuation */
.codehilite.stata-dark .ch { color: #777; font-style: italic } /* Comment.Hashbang */
.codehilite.stata-dark .cm { color: #777; font-style: italic } /* Comment.Multiline */
.codehilite.stata-dark .cp { color: #777; font-style: italic } /* Comment.Preproc */
.codehilite.stata-dark .cpf { color: #777; font-style: italic } /* Comment.PreprocFile */
.codehilite.stata-dark .c1 { color: #777; font-style: italic } /* Comment.Single */
.codehilite.stata-dark .cs { color: #777; font-style: italic } /* Comment.Special */
.codehilite.stata-dark .gd { color: #CCC } /* Generic.Deleted */
.codehilite.stata-dark .ge { color: #CCC } /* Generic.Emph */
.codehilite.stata-dark .ges { color: #CCC } /* Generic.EmphStrong */
.codehilite.stata-dark .gr { color: #CCC } /* Generic.Error */
.codehilite.stata-dark .gh { color: #CCC } /* Generic.Heading */
.codehilite.stata-dark .gi { color: #CCC } /* Generic.Inserted */
.codehilite.stata-dark .go { color: #CCC } /* Generic.Output */
.codehilite.stata-dark .gp { color: #FFF } /* Generic.Prompt */
.codehilite.stata-dark .gs { color: #CCC } /* Generic.Strong */
.codehilite.stata-dark .gu { color: #CCC } /* Generic.Subheading */
.codehilite.stata-dark .gt { color: #CCC } /* Generic.Traceback */
.codehilite.stata-dark .kc { color: #7686BB; font-weight: bold } /* Keyword.Constant */
.codehilite.stata-dark .kd { color: #7686BB; font-weight: bold } /* Keyword.Declaration */
.codehilite.stata-dark .kn { color: #7686BB; font-weight: bold } /* Keyword.Namespace */
.codehilite.stata-dark .kp { color: #7686BB; font-weight: bold } /* Keyword.Pseudo */
.codehilite.stata-dark .kr { color: #7686BB; font-weight: bold } /* Keyword.Reserved */
.codehilite.stata-dark .kt { color: #7686BB; font-weight: bold } /* Keyword.Type */
.codehilite.stata-dark .ld { color: #CCC } /* Literal.Date */
.codehilite.stata-dark .m { color: #4FB8CC } /* Literal.Number */
.codehilite.stata-dark .s { color: #51CC99 } /* Literal.String */
.codehilite.stata-dark .na { color: #CCC } /* Name.Attribute */
.codehilite.stata-dark .nb { color: #CCC } /* Name.Builtin */
.codehilite.stata-dark .nc { color: #CCC } /* Name.Class */
.codehilite.stata-dark .no { color: #CCC } /* Name.Constant */
.codehilite.stata-dark .nd { color: #CCC } /* Name.Decorator */
.codehilite.stata-dark .ni { color: #CCC } /* Name.Entity */
.codehilite.stata-dark .ne { color: #CCC } /* Name.Exception */
.codehilite.stata-dark .nf { color: #6A6AFF } /* Name.Function */
.codehilite.stata-dark .nl { color: #CCC } /* Name.Label */
.codehilite.stata-dark .nn { color: #CCC } /* Name.Namespace */
.codehilite.stata-dark .nx { color: #E2828E } /* Name.Other */
.codehilite.stata-dark .py { color: #CCC } /* Name.Property */
.codehilite.stata-dark .nt { color: #CCC } /* Name.Tag */
.codehilite.stata-dark .nv { color: #7AB4DB; font-weight: bold } /* Name.Variable */
.codehilite.stata-dark .ow { color: #CCC } /* Operator.Word */
.codehilite.stata-dark .pm { color: #CCC } /* Punctuation.Marker */
.codehilite.stata-dark .w { color: #BBB } /* Text.Whitespace */
.codehilite.stata-dark .mb { color: #4FB8CC } /* Literal.Number.Bin */
.codehilite.stata-dark .mf { color: #4FB8CC } /* Literal.Number.Float */
.codehilite.stata-dark .mh { color: #4FB8CC } /* Literal.Number.Hex */
.codehilite.stata-dark .mi { color: #4FB8CC } /* Literal.Number.Integer */
.codehilite.stata-dark .mo { color: #4FB8CC } /* Literal.Number.Oct */
.codehilite.stata-dark .sa { color: #51CC99 } /* Literal.String.Affix */
.codehilite.stata-dark .sb { color: #51CC99 } /* Literal.String.Backtick */
.codehilite.stata-dark .sc { color: #51CC99 } /* Literal.String.Char */
.codehilite.stata-dark .dl { color: #51CC99 } /* Literal.String.Delimiter */
.codehilite.stata-dark .sd { color: #51CC99 } /* Literal.String.Doc */
.codehilite.stata-dark .s2 { color: #51CC99 } /* Literal.String.Double */
.codehilite.stata-dark .se { color: #51CC99 } /* Literal.String.Escape */
.codehilite.stata-dark .sh { color: #51CC99 } /* Literal.String.Heredoc */
.codehilite.stata-dark .si { color: #51CC99 } /* Literal.String.Interpol */
.codehilite.stata-dark .sx { color: #51CC99 } /* Literal.String.Other */
.codehilite.stata-dark .sr { color: #51CC99 } /* Literal.String.Regex */
.codehilite.stata-dark .s1 { color: #51CC99 } /* Literal.String.Single */
.codehilite.stata-dark .ss { color: #51CC99 } /* Literal.String.Symbol */
.codehilite.stata-dark .bp { color: #CCC } /* Name.Builtin.Pseudo */
.codehilite.stata-dark .fm { color: #6A6AFF } /* Name.Function.Magic */
.codehilite.stata-dark .vc { color: #7AB4DB; font-weight: bold } /* Name.Variable.Class */
.codehilite.stata-dark .vg { color: #BE646C; font-weight: bold } /* Name.Variable.Global */
.codehilite.stata-dark .vi { color: #7AB4DB; font-weight: bold } /* Name.Variable.Instance */
.codehilite.stata-dark .vm { color: #7AB4DB; font-weight: bold } /* Name.Variable.Magic */
.codehilite.stata-dark .il { color: #4FB8CC } /* Literal.Number.Integer.Long */
.codehilite.stata-light .hll { background-color: #ffffcc }
.codehilite.stata-light { background: #ffffff; color: #111 }
.codehilite.stata-light .c { color: #080; font-style: italic } /* Comment */
.codehilite.stata-light .err { color: #A61717; background-color: #E3D2D2 } /* Error */
.codehilite.stata-light .k { color: #353580; font-weight: bold } /* Keyword */
.codehilite.stata-light .ch { color: #080; font-style: italic } /* Comment.Hashbang */
.codehilite.stata-light .cm { color: #080; font-style: italic } /* Comment.Multiline */
.codehilite.stata-light .cp { color: #080; font-style: italic } /* Comment.Preproc */
.codehilite.stata-light .cpf { color: #080; font-style: italic } /* Comment.PreprocFile */
.codehilite.stata-light .c1 { color: #080; font-style: italic } /* Comment.Single */
.codehilite.stata-light .cs { color: #080; font-style: italic } /* Comment.Special */
.codehilite.stata-light .kc { color: #353580; font-weight: bold } /* Keyword.Constant */
.codehilite.stata-light .kd { color: #353580; font-weight: bold } /* Keyword.Declaration */
.codehilite.stata-light .kn { color: #353580; font-weight: bold } /* Keyword.Namespace */
.codehilite.stata-light .kp { color: #353580; font-weight: bold } /* Keyword.Pseudo */
.codehilite.stata-light .kr { color: #353580; font-weight: bold } /* Keyword.Reserved */
.codehilite.stata-light .kt { color: #353580; font-weight: bold } /* Keyword.Type */
.codehilite.stata-light .m { color: #2C2CFF } /* Literal.Number */
.codehilite.stata-light .s { color: #7A2424 } /* Literal.String */
.codehilite.stata-light .nf { color: #2C2CFF } /* Name.Function */
.codehilite.stata-light .nx { color: #BE646C } /* Name.Other */
.codehilite.stata-light .nv { color: #35BABA; font-weight: bold } /* Name.Variable */
.codehilite.stata-light .w { color: #BBB } /* Text.Whitespace */
.codehilite.stata-light .mb { color: #2C2CFF } /* Literal.Number.Bin */
.codehilite.stata-light .mf { color: #2C2CFF } /* Literal.Number.Float */
.codehilite.stata-light .mh { color: #2C2CFF } /* Literal.Number.Hex */
.codehilite.stata-light .mi { color: #2C2CFF } /* Literal.Number.Integer */
.codehilite.stata-light .mo { color: #2C2CFF } /* Literal.Number.Oct */
.codehilite.stata-light .sa { color: #7A2424 } /* Literal.String.Affix */
.codehilite.stata-light .sb { color: #7A2424 } /* Literal.String.Backtick */
.codehilite.stata-light .sc { color: #7A2424 } /* Literal.String.Char */
.codehilite.stata-light .dl { color: #7A2424 } /* Literal.String.Delimiter */
.codehilite.stata-light .sd { color: #7A2424 } /* Literal.String.Doc */
.codehilite.stata-light .s2 { color: #7A2424 } /* Literal.String.Double */
.codehilite.stata-light .se { color: #7A2424 } /* Literal.String.Escape */
.codehilite.stata-light .sh { color: #7A2424 } /* Literal.String.Heredoc */
.codehilite.stata-light .si { color: #7A2424 } /* Literal.String.Interpol */
.codehilite.stata-light .sx { color: #7A2424 } /* Literal.String.Other */
.codehilite.stata-light .sr { color: #7A2424 } /* Literal.String.Regex */
.codehilite.stata-light .s1 { color: #7A2424 } /* Literal.String.Single */
.codehilite.stata-light .ss { color: #7A2424 } /* Literal.String.Symbol */
.codehilite.stata-light .fm { color: #2C2CFF } /* Name.Function.Magic */
.codehilite.stata-light .vc { color: #35BABA; font-weight: bold } /* Name.Variable.Class */
.codehilite.stata-light .vg { color: #B5565E; font-weight: bold } /* Name.Variable.Global */
.codehilite.stata-light .vi { color: #35BABA; font-weight: bold } /* Name.Variable.Instance */
.codehilite.stata-light .vm { color: #35BABA; font-weight: bold } /* Name.Variable.Magic */
.codehilite.stata-light .il { color: #2C2CFF } /* Literal.Number.Integer.Long */
.codehilite.tango .hll { background-color: #ffffcc }
.codehilite.tango { background: #f8f8f8; }
.codehilite.tango .c { color: #8F5902; font-style: italic } /* Comment */
.codehilite.tango .err { color: #A40000; border: 1px solid #EF2929 } /* Error */
.codehilite.tango .g { color: #000 } /* Generic */
.codehilite.tango .k { color: #204A87; font-weight: bold } /* Keyword */
.codehilite.tango .l { color: #000 } /* Literal */
.codehilite.tango .n { color: #000 } /* Name */
.codehilite.tango .o { color: #CE5C00; font-weight: bold } /* Operator */
.codehilite.tango .x { color: #000 } /* Other */
.codehilite.tango .p { color: #000; font-weight: bold } /* Punctuation */
.codehilite.tango .ch { color: #8F5902; font-style: italic } /* Comment.Hashbang */
.codehilite.tango .cm { color: #8F5902; font-style: italic } /* Comment.Multiline */
.codehilite.tango .cp { color: #8F5902; font-style: italic } /* Comment.Preproc */
.codehilite.tango .cpf { color: #8F5902; font-style: italic } /* Comment.PreprocFile */
.codehilite.tango .c1 { color: #8F5902; font-style: italic } /* Comment.Single */
.codehilite.tango .cs { color: #8F5902; font-style: italic } /* Comment.Special */
.codehilite.tango .gd { color: #A40000 } /* Generic.Deleted */
.codehilite.tango .ge { color: #000; font-style: italic } /* Generic.Emph */
.codehilite.tango .ges { color: #000; font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.tango .gr { color: #EF2929 } /* Generic.Error */
.codehilite.tango .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite.tango .gi { color: #00A000 } /* Generic.Inserted */
.codehilite.tango .go { color: #000; font-style: italic } /* Generic.Output */
.codehilite.tango .gp { color: #8F5902 } /* Generic.Prompt */
.codehilite.tango .gs { color: #000; font-weight: bold } /* Generic.Strong */
.codehilite.tango .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite.tango .gt { color: #A40000; font-weight: bold } /* Generic.Traceback */
.codehilite.tango .kc { color: #204A87; font-weight: bold } /* Keyword.Constant */
.codehilite.tango .kd { color: #204A87; font-weight: bold } /* Keyword.Declaration */
.codehilite.tango .kn { color: #204A87; font-weight: bold } /* Keyword.Namespace */
.codehilite.tango .kp { color: #204A87; font-weight: bold } /* Keyword.Pseudo */
.codehilite.tango .kr { color: #204A87; font-weight: bold } /* Keyword.Reserved */
.codehilite.tango .kt { color: #204A87; font-weight: bold } /* Keyword.Type */
.codehilite.tango .ld { color: #000 } /* Literal.Date */
.codehilite.tango .m { color: #0000CF; font-weight: bold } /* Literal.Number */
.codehilite.tango .s { color: #4E9A06 } /* Literal.String */
.codehilite.tango .na { color: #C4A000 } /* Name.Attribute */
.codehilite.tango .nb { color: #204A87 } /* Name.Builtin */
.codehilite.tango .nc { color: #000 } /* Name.Class */
.codehilite.tango .no { color: #000 } /* Name.Constant */
.codehilite.tango .nd { color: #5C35CC; font-weight: bold } /* Name.Decorator */
.codehilite.tango .ni { color: #CE5C00 } /* Name.Entity */
.codehilite.tango .ne { color: #C00; font-weight: bold } /* Name.Exception */
.codehilite.tango .nf { color: #000 } /* Name.Function */
.codehilite.tango .nl { color: #F57900 } /* Name.Label */
.codehilite.tango .nn { color: #000 } /* Name.Namespace */
.codehilite.tango .nx { color: #000 } /* Name.Other */
.codehilite.tango .py { color: #000 } /* Name.Property */
.codehilite.tango .nt { color: #204A87; font-weight: bold } /* Name.Tag */
.codehilite.tango .nv { color: #000 } /* Name.Variable */
.codehilite.tango .ow { color: #204A87; font-weight: bold } /* Operator.Word */
.codehilite.tango .pm { color: #000; font-weight: bold } /* Punctuation.Marker */
.codehilite.tango .w { color: #F8F8F8 } /* Text.Whitespace */
.codehilite.tango .mb { color: #0000CF; font-weight: bold } /* Literal.Number.Bin */
.codehilite.tango .mf { color: #0000CF; font-weight: bold } /* Literal.Number.Float */
.codehilite.tango .mh { color: #0000CF; font-weight: bold } /* Literal.Number.Hex */
.codehilite.tango .mi { color: #0000CF; font-weight: bold } /* Literal.Number.Integer */
.codehilite.tango .mo { color: #0000CF; font-weight: bold } /* Literal.Number.Oct */
.codehilite.tango .sa { color: #4E9A06 } /* Literal.String.Affix */
.codehilite.tango .sb { color: #4E9A06 } /* Literal.String.Backtick */
.codehilite.tango .sc { color: #4E9A06 } /* Literal.String.Char */
.codehilite.tango .dl { color: #4E9A06 } /* Literal.String.Delimiter */
.codehilite.tango .sd { color: #8F5902; font-style: italic } /* Literal.String.Doc */
.codehilite.tango .s2 { color: #4E9A06 } /* Literal.String.Double */
.codehilite.tango .se { color: #4E9A06 } /* Literal.String.Escape */
.codehilite.tango .sh { color: #4E9A06 } /* Literal.String.Heredoc */
.codehilite.tango .si { color: #4E9A06 } /* Literal.String.Interpol */
.codehilite.tango .sx { color: #4E9A06 } /* Literal.String.Other */
.codehilite.tango .sr { color: #4E9A06 } /* Literal.String.Regex */
.codehilite.tango .s1 { color: #4E9A06 } /* Literal.String.Single */
.codehilite.tango .ss { color: #4E9A06 } /* Literal.String.Symbol */
.codehilite.tango .bp { color: #3465A4 } /* Name.Builtin.Pseudo */
.codehilite.tango .fm { color: #000 } /* Name.Function.Magic */
.codehilite.tango .vc { color: #000 } /* Name.Variable.Class */
.codehilite.tango .vg { color: #000 } /* Name.Variable.Global */
.codehilite.tango .vi { color: #000 } /* Name.Variable.Instance */
.codehilite.tango .vm { color: #000 } /* Name.Variable.Magic */
.codehilite.tango .il { color: #0000CF; font-weight: bold } /* Literal.Number.Integer.Long */
.codehilite.trac .hll { background-color: #ffffcc }
.codehilite.trac { background: #ffffff; }
.codehilite.trac .c { color: #998; font-style: italic } /* Comment */
.codehilite.trac .err { color: #A61717; background-color: #E3D2D2 } /* Error */
.codehilite.trac .k { font-weight: bold } /* Keyword */
.codehilite.trac .o { font-weight: bold } /* Operator */
.codehilite.trac .ch { color: #998; font-style: italic } /* Comment.Hashbang */
.codehilite.trac .cm { color: #998; font-style: italic } /* Comment.Multiline */
.codehilite.trac .cp { color: #999; font-weight: bold } /* Comment.Preproc */
.codehilite.trac .cpf { color: #998; font-style: italic } /* Comment.PreprocFile */
.codehilite.trac .c1 { color: #998; font-style: italic } /* Comment.Single */
.codehilite.trac .cs { color: #999; font-weight: bold; font-style: italic } /* Comment.Special */
.codehilite.trac .gd { color: #000; background-color: #FDD } /* Generic.Deleted */
.codehilite.trac .ge { font-style: italic } /* Generic.Emph */
.codehilite.trac .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.trac .gr { color: #A00 } /* Generic.Error */
.codehilite.trac .gh { color: #999 } /* Generic.Heading */
.codehilite.trac .gi { color: #000; background-color: #DFD } /* Generic.Inserted */
.codehilite.trac .go { color: #888 } /* Generic.Output */
.codehilite.trac .gp { color: #555 } /* Generic.Prompt */
.codehilite.trac .gs { font-weight: bold } /* Generic.Strong */
.codehilite.trac .gu { color: #AAA } /* Generic.Subheading */
.codehilite.trac .gt { color: #A00 } /* Generic.Traceback */
.codehilite.trac .kc { font-weight: bold } /* Keyword.Constant */
.codehilite.trac .kd { font-weight: bold } /* Keyword.Declaration */
.codehilite.trac .kn { font-weight: bold } /* Keyword.Namespace */
.codehilite.trac .kp { font-weight: bold } /* Keyword.Pseudo */
.codehilite.trac .kr { font-weight: bold } /* Keyword.Reserved */
.codehilite.trac .kt { color: #458; font-weight: bold } /* Keyword.Type */
.codehilite.trac .m { color: #099 } /* Literal.Number */
.codehilite.trac .s { color: #B84 } /* Literal.String */
.codehilite.trac .na { color: #008080 } /* Name.Attribute */
.codehilite.trac .nb { color: #999 } /* Name.Builtin */
.codehilite.trac .nc { color: #458; font-weight: bold } /* Name.Class */
.codehilite.trac .no { color: #008080 } /* Name.Constant */
.codehilite.trac .ni { color: #800080 } /* Name.Entity */
.codehilite.trac .ne { color: #900; font-weight: bold } /* Name.Exception */
.codehilite.trac .nf { color: #900; font-weight: bold } /* Name.Function */
.codehilite.trac .nn { color: #555 } /* Name.Namespace */
.codehilite.trac .nt { color: #000080 } /* Name.Tag */
.codehilite.trac .nv { color: #008080 } /* Name.Variable */
.codehilite.trac .ow { font-weight: bold } /* Operator.Word */
.codehilite.trac .w { color: #BBB } /* Text.Whitespace */
.codehilite.trac .mb { color: #099 } /* Literal.Number.Bin */
.codehilite.trac .mf { color: #099 } /* Literal.Number.Float */
.codehilite.trac .mh { color: #099 } /* Literal.Number.Hex */
.codehilite.trac .mi { color: #099 } /* Literal.Number.Integer */
.codehilite.trac .mo { color: #099 } /* Literal.Number.Oct */
.codehilite.trac .sa { color: #B84 } /* Literal.String.Affix */
.codehilite.trac .sb { color: #B84 } /* Literal.String.Backtick */
.codehilite.trac .sc { color: #B84 } /* Literal.String.Char */
.codehilite.trac .dl { color: #B84 } /* Literal.String.Delimiter */
.codehilite.trac .sd { color: #B84 } /* Literal.String.Doc */
.codehilite.trac .s2 { color: #B84 } /* Literal.String.Double */
.codehilite.trac .se { color: #B84 } /* Literal.String.Escape */
.codehilite.trac .sh { color: #B84 } /* Literal.String.Heredoc */
.codehilite.trac .si { color: #B84 } /* Literal.String.Interpol */
.codehilite.trac .sx { color: #B84 } /* Literal.String.Other */
.codehilite.trac .sr { color: #808000 } /* Literal.String.Regex */
.codehilite.trac .s1 { color: #B84 } /* Literal.String.Single */
.codehilite.trac .ss { color: #B84 } /* Literal.String.Symbol */
.codehilite.trac .bp { color: #999 } /* Name.Builtin.Pseudo */
.codehilite.trac .fm { color: #900; font-weight: bold } /* Name.Function.Magic */
.codehilite.trac .vc { color: #008080 } /* Name.Variable.Class */
.codehilite.trac .vg { color: #008080 } /* Name.Variable.Global */
.codehilite.trac .vi { color: #008080 } /* Name.Variable.Instance */
.codehilite.trac .vm { color: #008080 } /* Name.Variable.Magic */
.codehilite.trac .il { color: #099 } /* Literal.Number.Integer.Long */
.codehilite.vim .hll { background-color: #222222 }
.codehilite.vim { background: #000000; color: #CCC }
.codehilite.vim .c { color: #000080 } /* Comment */
.codehilite.vim .err { color: #CCC; border: 1px solid #F00 } /* Error */
.codehilite.vim .esc { color: #CCC } /* Escape */
.codehilite.vim .g { color: #CCC } /* Generic */
.codehilite.vim .k { color: #CDCD00 } /* Keyword */
.codehilite.vim .l { color: #CCC } /* Literal */
.codehilite.vim .n { color: #CCC } /* Name */
.codehilite.vim .o { color: #39C } /* Operator */
.codehilite.vim .x { color: #CCC } /* Other */
.codehilite.vim .p { color: #CCC } /* Punctuation */
.codehilite.vim .ch { color: #000080 } /* Comment.Hashbang */
.codehilite.vim .cm { color: #000080 } /* Comment.Multiline */
.codehilite.vim .cp { color: #000080 } /* Comment.Preproc */
.codehilite.vim .cpf { color: #000080 } /* Comment.PreprocFile */
.codehilite.vim .c1 { color: #000080 } /* Comment.Single */
.codehilite.vim .cs { color: #CD0000; font-weight: bold } /* Comment.Special */
.codehilite.vim .gd { color: #CD0000 } /* Generic.Deleted */
.codehilite.vim .ge { color: #CCC; font-style: italic } /* Generic.Emph */
.codehilite.vim .ges { color: #CCC; font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.vim .gr { color: #F00 } /* Generic.Error */
.codehilite.vim .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.codehilite.vim .gi { color: #00CD00 } /* Generic.Inserted */
.codehilite.vim .go { color: #888 } /* Generic.Output */
.codehilite.vim .gp { color: #000080; font-weight: bold } /* Generic.Prompt */
.codehilite.vim .gs { color: #CCC; font-weight: bold } /* Generic.Strong */
.codehilite.vim .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.codehilite.vim .gt { color: #04D } /* Generic.Traceback */
.codehilite.vim .kc { color: #CDCD00 } /* Keyword.Constant */
.codehilite.vim .kd { color: #00CD00 } /* Keyword.Declaration */
.codehilite.vim .kn { color: #CD00CD } /* Keyword.Namespace */
.codehilite.vim .kp { color: #CDCD00 } /* Keyword.Pseudo */
.codehilite.vim .kr { color: #CDCD00 } /* Keyword.Reserved */
.codehilite.vim .kt { color: #00CD00 } /* Keyword.Type */
.codehilite.vim .ld { color: #CCC } /* Literal.Date */
.codehilite.vim .m { color: #CD00CD } /* Literal.Number */
.codehilite.vim .s { color: #CD0000 } /* Literal.String */
.codehilite.vim .na { color: #CCC } /* Name.Attribute */
.codehilite.vim .nb { color: #CD00CD } /* Name.Builtin */
.codehilite.vim .nc { color: #00CDCD } /* Name.Class */
.codehilite.vim .no { color: #CCC } /* Name.Constant */
.codehilite.vim .nd { color: #CCC } /* Name.Decorator */
.codehilite.vim .ni { color: #CCC } /* Name.Entity */
.codehilite.vim .ne { color: #669; font-weight: bold } /* Name.Exception */
.codehilite.vim .nf { color: #CCC } /* Name.Function */
.codehilite.vim .nl { color: #CCC } /* Name.Label */
.codehilite.vim .nn { color: #CCC } /* Name.Namespace */
.codehilite.vim .nx { color: #CCC } /* Name.Other */
.codehilite.vim .py { color: #CCC } /* Name.Property */
.codehilite.vim .nt { color: #CCC } /* Name.Tag */
.codehilite.vim .nv { color: #00CDCD } /* Name.Variable */
.codehilite.vim .ow { color: #CDCD00 } /* Operator.Word */
.codehilite.vim .pm { color: #CCC } /* Punctuation.Marker */
.codehilite.vim .w { color: #CCC } /* Text.Whitespace */
.codehilite.vim .mb { color: #CD00CD } /* Literal.Number.Bin */
.codehilite.vim .mf { color: #CD00CD } /* Literal.Number.Float */
.codehilite.vim .mh { color: #CD00CD } /* Literal.Number.Hex */
.codehilite.vim .mi { color: #CD00CD } /* Literal.Number.Integer */
.codehilite.vim .mo { color: #CD00CD } /* Literal.Number.Oct */
.codehilite.vim .sa { color: #CD0000 } /* Literal.String.Affix */
.codehilite.vim .sb { color: #CD0000 } /* Literal.String.Backtick */
.codehilite.vim .sc { color: #CD0000 } /* Literal.String.Char */
.codehilite.vim .dl { color: #CD0000 } /* Literal.String.Delimiter */
.codehilite.vim .sd { color: #CD0000 } /* Literal.String.Doc */
.codehilite.vim .s2 { color: #CD0000 } /* Literal.String.Double */
.codehilite.vim .se { color: #CD0000 } /* Literal.String.Escape */
.codehilite.vim .sh { color: #CD0000 } /* Literal.String.Heredoc */
.codehilite.vim .si { color: #CD0000 } /* Literal.String.Interpol */
.codehilite.vim .sx { color: #CD0000 } /* Literal.String.Other */
.codehilite.vim .sr { color: #CD0000 } /* Literal.String.Regex */
.codehilite.vim .s1 { color: #CD0000 } /* Literal.String.Single */
.codehilite.vim .ss { color: #CD0000 } /* Literal.String.Symbol */
.codehilite.vim .bp { color: #CD00CD } /* Name.Builtin.Pseudo */
.codehilite.vim .fm { color: #CCC } /* Name.Function.Magic */
.codehilite.vim .vc { color: #00CDCD } /* Name.Variable.Class */
.codehilite.vim .vg { color: #00CDCD } /* Name.Variable.Global */
.codehilite.vim .vi { color: #00CDCD } /* Name.Variable.Instance */
.codehilite.vim .vm { color: #00CDCD } /* Name.Variable.Magic */
.codehilite.vim .il { color: #CD00CD } /* Literal.Number.Integer.Long */
.codehilite.vs .hll { background-color: #ffffcc }
.codehilite.vs { background: #ffffff; }
.codehilite.vs .c { color: #008000 } /* Comment */
.codehilite.vs .err { border: 1px solid #F00 } /* Error */
.codehilite.vs .k { color: #00F } /* Keyword */
.codehilite.vs .ch { color: #008000 } /* Comment.Hashbang */
.codehilite.vs .cm { color: #008000 } /* Comment.Multiline */
.codehilite.vs .cp { color: #00F } /* Comment.Preproc */
.codehilite.vs .cpf { color: #008000 } /* Comment.PreprocFile */
.codehilite.vs .c1 { color: #008000 } /* Comment.Single */
.codehilite.vs .cs { color: #008000 } /* Comment.Special */
.codehilite.vs .ge { font-style: italic } /* Generic.Emph */
.codehilite.vs .ges { font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.vs .gh { font-weight: bold } /* Generic.Heading */
.codehilite.vs .gp { font-weight: bold } /* Generic.Prompt */
.codehilite.vs .gs { font-weight: bold } /* Generic.Strong */
.codehilite.vs .gu { font-weight: bold } /* Generic.Subheading */
.codehilite.vs .kc { color: #00F } /* Keyword.Constant */
.codehilite.vs .kd { color: #00F } /* Keyword.Declaration */
.codehilite.vs .kn { color: #00F } /* Keyword.Namespace */
.codehilite.vs .kp { color: #00F } /* Keyword.Pseudo */
.codehilite.vs .kr { color: #00F } /* Keyword.Reserved */
.codehilite.vs .kt { color: #2B91AF } /* Keyword.Type */
.codehilite.vs .s { color: #A31515 } /* Literal.String */
.codehilite.vs .nc { color: #2B91AF } /* Name.Class */
.codehilite.vs .ow { color: #00F } /* Operator.Word */
.codehilite.vs .sa { color: #A31515 } /* Literal.String.Affix */
.codehilite.vs .sb { color: #A31515 } /* Literal.String.Backtick */
.codehilite.vs .sc { color: #A31515 } /* Literal.String.Char */
.codehilite.vs .dl { color: #A31515 } /* Literal.String.Delimiter */
.codehilite.vs .sd { color: #A31515 } /* Literal.String.Doc */
.codehilite.vs .s2 { color: #A31515 } /* Literal.String.Double */
.codehilite.vs .se { color: #A31515 } /* Literal.String.Escape */
.codehilite.vs .sh { color: #A31515 } /* Literal.String.Heredoc */
.codehilite.vs .si { color: #A31515 } /* Literal.String.Interpol */
.codehilite.vs .sx { color: #A31515 } /* Literal.String.Other */
.codehilite.vs .sr { color: #A31515 } /* Literal.String.Regex */
.codehilite.vs .s1 { color: #A31515 } /* Literal.String.Single */
.codehilite.vs .ss { color: #A31515 } /* Literal.String.Symbol */
.codehilite.xcode .hll { background-color: #ffffcc }
.codehilite.xcode { background: #ffffff; }
.codehilite.xcode .c { color: #177500 } /* Comment */
.codehilite.xcode .err { color: #000 } /* Error */
.codehilite.xcode .k { color: #A90D91 } /* Keyword */
.codehilite.xcode .l { color: #1C01CE } /* Literal */
.codehilite.xcode .n { color: #000 } /* Name */
.codehilite.xcode .o { color: #000 } /* Operator */
.codehilite.xcode .ch { color: #177500 } /* Comment.Hashbang */
.codehilite.xcode .cm { color: #177500 } /* Comment.Multiline */
.codehilite.xcode .cp { color: #633820 } /* Comment.Preproc */
.codehilite.xcode .cpf { color: #177500 } /* Comment.PreprocFile */
.codehilite.xcode .c1 { color: #177500 } /* Comment.Single */
.codehilite.xcode .cs { color: #177500 } /* Comment.Special */
.codehilite.xcode .kc { color: #A90D91 } /* Keyword.Constant */
.codehilite.xcode .kd { color: #A90D91 } /* Keyword.Declaration */
.codehilite.xcode .kn { color: #A90D91 } /* Keyword.Namespace */
.codehilite.xcode .kp { color: #A90D91 } /* Keyword.Pseudo */
.codehilite.xcode .kr { color: #A90D91 } /* Keyword.Reserved */
.codehilite.xcode .kt { color: #A90D91 } /* Keyword.Type */
.codehilite.xcode .ld { color: #1C01CE } /* Literal.Date */
.codehilite.xcode .m { color: #1C01CE } /* Literal.Number */
.codehilite.xcode .s { color: #C41A16 } /* Literal.String */
.codehilite.xcode .na { color: #836C28 } /* Name.Attribute */
.codehilite.xcode .nb { color: #A90D91 } /* Name.Builtin */
.codehilite.xcode .nc { color: #3F6E75 } /* Name.Class */
.codehilite.xcode .no { color: #000 } /* Name.Constant */
.codehilite.xcode .nd { color: #000 } /* Name.Decorator */
.codehilite.xcode .ni { color: #000 } /* Name.Entity */
.codehilite.xcode .ne { color: #000 } /* Name.Exception */
.codehilite.xcode .nf { color: #000 } /* Name.Function */
.codehilite.xcode .nl { color: #000 } /* Name.Label */
.codehilite.xcode .nn { color: #000 } /* Name.Namespace */
.codehilite.xcode .nx { color: #000 } /* Name.Other */
.codehilite.xcode .py { color: #000 } /* Name.Property */
.codehilite.xcode .nt { color: #000 } /* Name.Tag */
.codehilite.xcode .nv { color: #000 } /* Name.Variable */
.codehilite.xcode .ow { color: #000 } /* Operator.Word */
.codehilite.xcode .mb { color: #1C01CE } /* Literal.Number.Bin */
.codehilite.xcode .mf { color: #1C01CE } /* Literal.Number.Float */
.codehilite.xcode .mh { color: #1C01CE } /* Literal.Number.Hex */
.codehilite.xcode .mi { color: #1C01CE } /* Literal.Number.Integer */
.codehilite.xcode .mo { color: #1C01CE } /* Literal.Number.Oct */
.codehilite.xcode .sa { color: #C41A16 } /* Literal.String.Affix */
.codehilite.xcode .sb { color: #C41A16 } /* Literal.String.Backtick */
.codehilite.xcode .sc { color: #2300CE } /* Literal.String.Char */
.codehilite.xcode .dl { color: #C41A16 } /* Literal.String.Delimiter */
.codehilite.xcode .sd { color: #C41A16 } /* Literal.String.Doc */
.codehilite.xcode .s2 { color: #C41A16 } /* Literal.String.Double */
.codehilite.xcode .se { color: #C41A16 } /* Literal.String.Escape */
.codehilite.xcode .sh { color: #C41A16 } /* Literal.String.Heredoc */
.codehilite.xcode .si { color: #C41A16 } /* Literal.String.Interpol */
.codehilite.xcode .sx { color: #C41A16 } /* Literal.String.Other */
.codehilite.xcode .sr { color: #C41A16 } /* Literal.String.Regex */
.codehilite.xcode .s1 { color: #C41A16 } /* Literal.String.Single */
.codehilite.xcode .ss { color: #C41A16 } /* Literal.String.Symbol */
.codehilite.xcode .bp { color: #5B269A } /* Name.Builtin.Pseudo */
.codehilite.xcode .fm { color: #000 } /* Name.Function.Magic */
.codehilite.xcode .vc { color: #000 } /* Name.Variable.Class */
.codehilite.xcode .vg { color: #000 } /* Name.Variable.Global */
.codehilite.xcode .vi { color: #000 } /* Name.Variable.Instance */
.codehilite.xcode .vm { color: #000 } /* Name.Variable.Magic */
.codehilite.xcode .il { color: #1C01CE } /* Literal.Number.Integer.Long */
.codehilite.zenburn .hll { background-color: #484848 }
.codehilite.zenburn { background: #3f3f3f; color: #DCDCCC }
.codehilite.zenburn .c { color: #7F9F7F; font-style: italic } /* Comment */
.codehilite.zenburn .err { color: #E37170; font-weight: bold } /* Error */
.codehilite.zenburn .esc { color: #DCDCCC } /* Escape */
.codehilite.zenburn .g { color: #ECBCBC; font-weight: bold } /* Generic */
.codehilite.zenburn .k { color: #EFDCBC } /* Keyword */
.codehilite.zenburn .l { color: #9FAFAF } /* Literal */
.codehilite.zenburn .n { color: #DCDCCC } /* Name */
.codehilite.zenburn .o { color: #F0EFD0 } /* Operator */
.codehilite.zenburn .x { color: #DCDCCC } /* Other */
.codehilite.zenburn .p { color: #F0EFD0 } /* Punctuation */
.codehilite.zenburn .ch { color: #7F9F7F; font-style: italic } /* Comment.Hashbang */
.codehilite.zenburn .cm { color: #7F9F7F; font-style: italic } /* Comment.Multiline */
.codehilite.zenburn .cp { color: #DFAF8F; font-weight: bold; font-style: italic } /* Comment.Preproc */
.codehilite.zenburn .cpf { color: #CC9393; font-style: italic } /* Comment.PreprocFile */
.codehilite.zenburn .c1 { color: #7F9F7F; font-style: italic } /* Comment.Single */
.codehilite.zenburn .cs { color: #DFDFDF; font-weight: bold; font-style: italic } /* Comment.Special */
.codehilite.zenburn .gd { color: #C3BF9F; font-weight: bold; background-color: #313C36 } /* Generic.Deleted */
.codehilite.zenburn .ge { color: #FFF; font-weight: bold } /* Generic.Emph */
.codehilite.zenburn .ges { color: #ECBCBC; font-weight: bold } /* Generic.EmphStrong */
.codehilite.zenburn .gr { color: #ECBCBC; font-weight: bold } /* Generic.Error */
.codehilite.zenburn .gh { color: #EFEFEF; font-weight: bold } /* Generic.Heading */
.codehilite.zenburn .gi { color: #709080; font-weight: bold; background-color: #313C36 } /* Generic.Inserted */
.codehilite.zenburn .go { color: #5B605E; font-weight: bold } /* Generic.Output */
.codehilite.zenburn .gp { color: #ECBCBC; font-weight: bold } /* Generic.Prompt */
.codehilite.zenburn .gs { color: #ECBCBC; font-weight: bold } /* Generic.Strong */
.codehilite.zenburn .gu { color: #EFEFEF; font-weight: bold } /* Generic.Subheading */
.codehilite.zenburn .gt { color: #80D4AA; font-weight: bold; background-color: #2F2F2F } /* Generic.Traceback */
.codehilite.zenburn .kc { color: #DCA3A3 } /* Keyword.Constant */
.codehilite.zenburn .kd { color: #F0DFAF } /* Keyword.Declaration */
.codehilite.zenburn .kn { color: #F0DFAF } /* Keyword.Namespace */
.codehilite.zenburn .kp { color: #EFDCBC } /* Keyword.Pseudo */
.codehilite.zenburn .kr { color: #EFDCBC } /* Keyword.Reserved */
.codehilite.zenburn .kt { color: #DFDFBF; font-weight: bold } /* Keyword.Type */
.codehilite.zenburn .ld { color: #9FAFAF } /* Literal.Date */
.codehilite.zenburn .m { color: #8CD0D3 } /* Literal.Number */
.codehilite.zenburn .s { color: #CC9393 } /* Literal.String */
.codehilite.zenburn .na { color: #EFEF8F } /* Name.Attribute */
.codehilite.zenburn .nb { color: #EFEF8F } /* Name.Builtin */
.codehilite.zenburn .nc { color: #EFEF8F } /* Name.Class */
.codehilite.zenburn .no { color: #DCA3A3 } /* Name.Constant */
.codehilite.zenburn .nd { color: #DCDCCC } /* Name.Decorator */
.codehilite.zenburn .ni { color: #CFBFAF } /* Name.Entity */
.codehilite.zenburn .ne { color: #C3BF9F; font-weight: bold } /* Name.Exception */
.codehilite.zenburn .nf { color: #EFEF8F } /* Name.Function */
.codehilite.zenburn .nl { color: #DCDCCC } /* Name.Label */
.codehilite.zenburn .nn { color: #DCDCCC } /* Name.Namespace */
.codehilite.zenburn .nx { color: #DCDCCC } /* Name.Other */
.codehilite.zenburn .py { color: #DCDCCC } /* Name.Property */
.codehilite.zenburn .nt { color: #E89393; font-weight: bold } /* Name.Tag */
.codehilite.zenburn .nv { color: #DCDCCC } /* Name.Variable */
.codehilite.zenburn .ow { color: #F0EFD0 } /* Operator.Word */
.codehilite.zenburn .pm { color: #F0EFD0 } /* Punctuation.Marker */
.codehilite.zenburn .w { color: #DCDCCC } /* Text.Whitespace */
.codehilite.zenburn .mb { color: #8CD0D3 } /* Literal.Number.Bin */
.codehilite.zenburn .mf { color: #C0BED1 } /* Literal.Number.Float */
.codehilite.zenburn .mh { color: #8CD0D3 } /* Literal.Number.Hex */
.codehilite.zenburn .mi { color: #8CD0D3 } /* Literal.Number.Integer */
.codehilite.zenburn .mo { color: #8CD0D3 } /* Literal.Number.Oct */
.codehilite.zenburn .sa { color: #CC9393 } /* Literal.String.Affix */
.codehilite.zenburn .sb { color: #CC9393 } /* Literal.String.Backtick */
.codehilite.zenburn .sc { color: #CC9393 } /* Literal.String.Char */
.codehilite.zenburn .dl { color: #CC9393 } /* Literal.String.Delimiter */
.codehilite.zenburn .sd { color: #7F9F7F } /* Literal.String.Doc */
.codehilite.zenburn .s2 { color: #CC9393 } /* Literal.String.Double */
.codehilite.zenburn .se { color: #CC9393 } /* Literal.String.Escape */
.codehilite.zenburn .sh { color: #CC9393 } /* Literal.String.Heredoc */
.codehilite.zenburn .si { color: #DCA3A3; font-weight: bold } /* Literal.String.Interpol */
.codehilite.zenburn .sx { color: #CC9393 } /* Literal.String.Other */
.codehilite.zenburn .sr { color: #CC9393 } /* Literal.String.Regex */
.codehilite.zenburn .s1 { color: #CC9393 } /* Literal.String.Single */
.codehilite.zenburn .ss { color: #CC9393 } /* Literal.String.Symbol */
.codehilite.zenburn .bp { color: #DCDCCC } /* Name.Builtin.Pseudo */
.codehilite.zenburn .fm { color: #EFEF8F } /* Name.Function.Magic */
.codehilite.zenburn .vc { color: #DCDCCC } /* Name.Variable.Class */
.codehilite.zenburn .vg { color: #DCDCCC } /* Name.Variable.Global */
.codehilite.zenburn .vi { color: #DCDCCC } /* Name.Variable.Instance */
.codehilite.zenburn .vm { color: #DCDCCC } /* Name.Variable.Magic */
.codehilite.zenburn .il { color: #8CD0D3 } /* Literal.Number.Integer.Long */
.codehilite.a11y-dark .hll { background-color: #ffd9002e }
.codehilite.a11y-dark { background: #2b2b2b; color: #F8F8F2 }
.codehilite.a11y-dark .c { color: #D4D0AB } /* Comment */
.codehilite.a11y-dark .err { color: #FFA07A } /* Error */
.codehilite.a11y-dark .k { color: #DCC6E0 } /* Keyword */
.codehilite.a11y-dark .l { color: #F5AB35 } /* Literal */
.codehilite.a11y-dark .n { color: #F8F8F2 } /* Name */
.codehilite.a11y-dark .o { color: #ABE338 } /* Operator */
.codehilite.a11y-dark .p { color: #F8F8F2 } /* Punctuation */
.codehilite.a11y-dark .ch { color: #D4D0AB } /* Comment.Hashbang */
.codehilite.a11y-dark .cm { color: #D4D0AB } /* Comment.Multiline */
.codehilite.a11y-dark .cp { color: #D4D0AB } /* Comment.Preproc */
.codehilite.a11y-dark .cpf { color: #D4D0AB } /* Comment.PreprocFile */
.codehilite.a11y-dark .c1 { color: #D4D0AB } /* Comment.Single */
.codehilite.a11y-dark .cs { color: #D4D0AB } /* Comment.Special */
.codehilite.a11y-dark .gd { color: #00E0E0 } /* Generic.Deleted */
.codehilite.a11y-dark .ge { font-style: italic } /* Generic.Emph */
.codehilite.a11y-dark .gh { color: #00E0E0 } /* Generic.Heading */
.codehilite.a11y-dark .gs { font-weight: bold } /* Generic.Strong */
.codehilite.a11y-dark .gu { color: #00E0E0 } /* Generic.Subheading */
.codehilite.a11y-dark .kc { color: #DCC6E0 } /* Keyword.Constant */
.codehilite.a11y-dark .kd { color: #DCC6E0 } /* Keyword.Declaration */
.codehilite.a11y-dark .kn { color: #DCC6E0 } /* Keyword.Namespace */
.codehilite.a11y-dark .kp { color: #DCC6E0 } /* Keyword.Pseudo */
.codehilite.a11y-dark .kr { color: #DCC6E0 } /* Keyword.Reserved */
.codehilite.a11y-dark .kt { color: #F5AB35 } /* Keyword.Type */
.codehilite.a11y-dark .ld { color: #F5AB35 } /* Literal.Date */
.codehilite.a11y-dark .m { color: #F5AB35 } /* Literal.Number */
.codehilite.a11y-dark .s { color: #ABE338 } /* Literal.String */
.codehilite.a11y-dark .na { color: #FFD700 } /* Name.Attribute */
.codehilite.a11y-dark .nb { color: #F5AB35 } /* Name.Builtin */
.codehilite.a11y-dark .nc { color: #00E0E0 } /* Name.Class */
.codehilite.a11y-dark .no { color: #00E0E0 } /* Name.Constant */
.codehilite.a11y-dark .nd { color: #F5AB35 } /* Name.Decorator */
.codehilite.a11y-dark .ni { color: #ABE338 } /* Name.Entity */
.codehilite.a11y-dark .ne { color: #DCC6E0 } /* Name.Exception */
.codehilite.a11y-dark .nf { color: #00E0E0 } /* Name.Function */
.codehilite.a11y-dark .nl { color: #F5AB35 } /* Name.Label */
.codehilite.a11y-dark .nn { color: #F8F8F2 } /* Name.Namespace */
.codehilite.a11y-dark .nx { color: #F8F8F2 } /* Name.Other */
.codehilite.a11y-dark .py { color: #00E0E0 } /* Name.Property */
.codehilite.a11y-dark .nt { color: #00E0E0 } /* Name.Tag */
.codehilite.a11y-dark .nv { color: #FFA07A } /* Name.Variable */
.codehilite.a11y-dark .ow { color: #DCC6E0 } /* Operator.Word */
.codehilite.a11y-dark .pm { color: #F8F8F2 } /* Punctuation.Marker */
.codehilite.a11y-dark .w { color: #F8F8F2 } /* Text.Whitespace */
.codehilite.a11y-dark .mb { color: #F5AB35 } /* Literal.Number.Bin */
.codehilite.a11y-dark .mf { color: #F5AB35 } /* Literal.Number.Float */
.codehilite.a11y-dark .mh { color: #F5AB35 } /* Literal.Number.Hex */
.codehilite.a11y-dark .mi { color: #F5AB35 } /* Literal.Number.Integer */
.codehilite.a11y-dark .mo { color: #F5AB35 } /* Literal.Number.Oct */
.codehilite.a11y-dark .sa { color: #ABE338 } /* Literal.String.Affix */
.codehilite.a11y-dark .sb { color: #ABE338 } /* Literal.String.Backtick */
.codehilite.a11y-dark .sc { color: #ABE338 } /* Literal.String.Char */
.codehilite.a11y-dark .dl { color: #ABE338 } /* Literal.String.Delimiter */
.codehilite.a11y-dark .sd { color: #ABE338 } /* Literal.String.Doc */
.codehilite.a11y-dark .s2 { color: #ABE338 } /* Literal.String.Double */
.codehilite.a11y-dark .se { color: #ABE338 } /* Literal.String.Escape */
.codehilite.a11y-dark .sh { color: #ABE338 } /* Literal.String.Heredoc */
.codehilite.a11y-dark .si { color: #ABE338 } /* Literal.String.Interpol */
.codehilite.a11y-dark .sx { color: #ABE338 } /* Literal.String.Other */
.codehilite.a11y-dark .sr { color: #FFA07A } /* Literal.String.Regex */
.codehilite.a11y-dark .s1 { color: #ABE338 } /* Literal.String.Single */
.codehilite.a11y-dark .ss { color: #00E0E0 } /* Literal.String.Symbol */
.codehilite.a11y-dark .bp { color: #F5AB35 } /* Name.Builtin.Pseudo */
.codehilite.a11y-dark .fm { color: #00E0E0 } /* Name.Function.Magic */
.codehilite.a11y-dark .vc { color: #FFA07A } /* Name.Variable.Class */
.codehilite.a11y-dark .vg { color: #FFA07A } /* Name.Variable.Global */
.codehilite.a11y-dark .vi { color: #FFA07A } /* Name.Variable.Instance */
.codehilite.a11y-dark .vm { color: #F5AB35 } /* Name.Variable.Magic */
.codehilite.a11y-dark .il { color: #F5AB35 } /* Literal.Number.Integer.Long */
.codehilite.a11y-high-contrast-dark .hll { background-color: #ffd9002e }
.codehilite.a11y-high-contrast-dark { background: #2b2b2b; color: #F8F8F2 }
.codehilite.a11y-high-contrast-dark .c { color: #FFD900 } /* Comment */
.codehilite.a11y-high-contrast-dark .err { color: #FFA07A } /* Error */
.codehilite.a11y-high-contrast-dark .k { color: #DCC6E0 } /* Keyword */
.codehilite.a11y-high-contrast-dark .l { color: #FFD900 } /* Literal */
.codehilite.a11y-high-contrast-dark .n { color: #F8F8F2 } /* Name */
.codehilite.a11y-high-contrast-dark .o { color: #ABE338 } /* Operator */
.codehilite.a11y-high-contrast-dark .p { color: #F8F8F2 } /* Punctuation */
.codehilite.a11y-high-contrast-dark .ch { color: #FFD900 } /* Comment.Hashbang */
.codehilite.a11y-high-contrast-dark .cm { color: #FFD900 } /* Comment.Multiline */
.codehilite.a11y-high-contrast-dark .cp { color: #FFD900 } /* Comment.Preproc */
.codehilite.a11y-high-contrast-dark .cpf { color: #FFD900 } /* Comment.PreprocFile */
.codehilite.a11y-high-contrast-dark .c1 { color: #FFD900 } /* Comment.Single */
.codehilite.a11y-high-contrast-dark .cs { color: #FFD900 } /* Comment.Special */
.codehilite.a11y-high-contrast-dark .gd { color: #00E0E0 } /* Generic.Deleted */
.codehilite.a11y-high-contrast-dark .ge { font-style: italic } /* Generic.Emph */
.codehilite.a11y-high-contrast-dark .gh { color: #00E0E0 } /* Generic.Heading */
.codehilite.a11y-high-contrast-dark .gs { font-weight: bold } /* Generic.Strong */
.codehilite.a11y-high-contrast-dark .gu { color: #00E0E0 } /* Generic.Subheading */
.codehilite.a11y-high-contrast-dark .kc { color: #DCC6E0 } /* Keyword.Constant */
.codehilite.a11y-high-contrast-dark .kd { color: #DCC6E0 } /* Keyword.Declaration */
.codehilite.a11y-high-contrast-dark .kn { color: #DCC6E0 } /* Keyword.Namespace */
.codehilite.a11y-high-contrast-dark .kp { color: #DCC6E0 } /* Keyword.Pseudo */
.codehilite.a11y-high-contrast-dark .kr { color: #DCC6E0 } /* Keyword.Reserved */
.codehilite.a11y-high-contrast-dark .kt { color: #FFD900 } /* Keyword.Type */
.codehilite.a11y-high-contrast-dark .ld { color: #FFD900 } /* Literal.Date */
.codehilite.a11y-high-contrast-dark .m { color: #FFD900 } /* Literal.Number */
.codehilite.a11y-high-contrast-dark .s { color: #ABE338 } /* Literal.String */
.codehilite.a11y-high-contrast-dark .na { color: #FFD900 } /* Name.Attribute */
.codehilite.a11y-high-contrast-dark .nb { color: #FFD900 } /* Name.Builtin */
.codehilite.a11y-high-contrast-dark .nc { color: #00E0E0 } /* Name.Class */
.codehilite.a11y-high-contrast-dark .no { color: #00E0E0 } /* Name.Constant */
.codehilite.a11y-high-contrast-dark .nd { color: #FFD900 } /* Name.Decorator */
.codehilite.a11y-high-contrast-dark .ni { color: #ABE338 } /* Name.Entity */
.codehilite.a11y-high-contrast-dark .ne { color: #DCC6E0 } /* Name.Exception */
.codehilite.a11y-high-contrast-dark .nf { color: #00E0E0 } /* Name.Function */
.codehilite.a11y-high-contrast-dark .nl { color: #FFD900 } /* Name.Label */
.codehilite.a11y-high-contrast-dark .nn { color: #F8F8F2 } /* Name.Namespace */
.codehilite.a11y-high-contrast-dark .nx { color: #F8F8F2 } /* Name.Other */
.codehilite.a11y-high-contrast-dark .py { color: #00E0E0 } /* Name.Property */
.codehilite.a11y-high-contrast-dark .nt { color: #00E0E0 } /* Name.Tag */
.codehilite.a11y-high-contrast-dark .nv { color: #FFA07A } /* Name.Variable */
.codehilite.a11y-high-contrast-dark .ow { color: #DCC6E0 } /* Operator.Word */
.codehilite.a11y-high-contrast-dark .pm { color: #F8F8F2 } /* Punctuation.Marker */
.codehilite.a11y-high-contrast-dark .w { color: #F8F8F2 } /* Text.Whitespace */
.codehilite.a11y-high-contrast-dark .mb { color: #FFD900 } /* Literal.Number.Bin */
.codehilite.a11y-high-contrast-dark .mf { color: #FFD900 } /* Literal.Number.Float */
.codehilite.a11y-high-contrast-dark .mh { color: #FFD900 } /* Literal.Number.Hex */
.codehilite.a11y-high-contrast-dark .mi { color: #FFD900 } /* Literal.Number.Integer */
.codehilite.a11y-high-contrast-dark .mo { color: #FFD900 } /* Literal.Number.Oct */
.codehilite.a11y-high-contrast-dark .sa { color: #ABE338 } /* Literal.String.Affix */
.codehilite.a11y-high-contrast-dark .sb { color: #ABE338 } /* Literal.String.Backtick */
.codehilite.a11y-high-contrast-dark .sc { color: #ABE338 } /* Literal.String.Char */
.codehilite.a11y-high-contrast-dark .dl { color: #ABE338 } /* Literal.String.Delimiter */
.codehilite.a11y-high-contrast-dark .sd { color: #ABE338 } /* Literal.String.Doc */
.codehilite.a11y-high-contrast-dark .s2 { color: #ABE338 } /* Literal.String.Double */
.codehilite.a11y-high-contrast-dark .se { color: #ABE338 } /* Literal.String.Escape */
.codehilite.a11y-high-contrast-dark .sh { color: #ABE338 } /* Literal.String.Heredoc */
.codehilite.a11y-high-contrast-dark .si { color: #ABE338 } /* Literal.String.Interpol */
.codehilite.a11y-high-contrast-dark .sx { color: #ABE338 } /* Literal.String.Other */
.codehilite.a11y-high-contrast-dark .sr { color: #FFA07A } /* Literal.String.Regex */
.codehilite.a11y-high-contrast-dark .s1 { color: #ABE338 } /* Literal.String.Single */
.codehilite.a11y-high-contrast-dark .ss { color: #00E0E0 } /* Literal.String.Symbol */
.codehilite.a11y-high-contrast-dark .bp { color: #FFD900 } /* Name.Builtin.Pseudo */
.codehilite.a11y-high-contrast-dark .fm { color: #00E0E0 } /* Name.Function.Magic */
.codehilite.a11y-high-contrast-dark .vc { color: #FFA07A } /* Name.Variable.Class */
.codehilite.a11y-high-contrast-dark .vg { color: #FFA07A } /* Name.Variable.Global */
.codehilite.a11y-high-contrast-dark .vi { color: #FFA07A } /* Name.Variable.Instance */
.codehilite.a11y-high-contrast-dark .vm { color: #FFD900 } /* Name.Variable.Magic */
.codehilite.a11y-high-contrast-dark .il { color: #FFD900 } /* Literal.Number.Integer.Long */
.codehilite.a11y-high-contrast-light .hll { background-color: #7971292e }
.codehilite.a11y-high-contrast-light { background: #fefefe; color: #545454 }
.codehilite.a11y-high-contrast-light .c { color: #797129 } /* Comment */
.codehilite.a11y-high-contrast-light .err { color: #D91E18 } /* Error */
.codehilite.a11y-high-contrast-light .k { color: #7928A1 } /* Keyword */
.codehilite.a11y-high-contrast-light .l { color: #797129 } /* Literal */
.codehilite.a11y-high-contrast-light .n { color: #545454 } /* Name */
.codehilite.a11y-high-contrast-light .o { color: #008000 } /* Operator */
.codehilite.a11y-high-contrast-light .p { color: #545454 } /* Punctuation */
.codehilite.a11y-high-contrast-light .ch { color: #797129 } /* Comment.Hashbang */
.codehilite.a11y-high-contrast-light .cm { color: #797129 } /* Comment.Multiline */
.codehilite.a11y-high-contrast-light .cp { color: #797129 } /* Comment.Preproc */
.codehilite.a11y-high-contrast-light .cpf { color: #797129 } /* Comment.PreprocFile */
.codehilite.a11y-high-contrast-light .c1 { color: #797129 } /* Comment.Single */
.codehilite.a11y-high-contrast-light .cs { color: #797129 } /* Comment.Special */
.codehilite.a11y-high-contrast-light .gd { color: #007FAA } /* Generic.Deleted */
.codehilite.a11y-high-contrast-light .ge { font-style: italic } /* Generic.Emph */
.codehilite.a11y-high-contrast-light .gh { color: #007FAA } /* Generic.Heading */
.codehilite.a11y-high-contrast-light .gs { font-weight: bold } /* Generic.Strong */
.codehilite.a11y-high-contrast-light .gu { color: #007FAA } /* Generic.Subheading */
.codehilite.a11y-high-contrast-light .kc { color: #7928A1 } /* Keyword.Constant */
.codehilite.a11y-high-contrast-light .kd { color: #7928A1 } /* Keyword.Declaration */
.codehilite.a11y-high-contrast-light .kn { color: #7928A1 } /* Keyword.Namespace */
.codehilite.a11y-high-contrast-light .kp { color: #7928A1 } /* Keyword.Pseudo */
.codehilite.a11y-high-contrast-light .kr { color: #7928A1 } /* Keyword.Reserved */
.codehilite.a11y-high-contrast-light .kt { color: #797129 } /* Keyword.Type */
.codehilite.a11y-high-contrast-light .ld { color: #797129 } /* Literal.Date */
.codehilite.a11y-high-contrast-light .m { color: #797129 } /* Literal.Number */
.codehilite.a11y-high-contrast-light .s { color: #008000 } /* Literal.String */
.codehilite.a11y-high-contrast-light .na { color: #797129 } /* Name.Attribute */
.codehilite.a11y-high-contrast-light .nb { color: #797129 } /* Name.Builtin */
.codehilite.a11y-high-contrast-light .nc { color: #007FAA } /* Name.Class */
.codehilite.a11y-high-contrast-light .no { color: #007FAA } /* Name.Constant */
.codehilite.a11y-high-contrast-light .nd { color: #797129 } /* Name.Decorator */
.codehilite.a11y-high-contrast-light .ni { color: #008000 } /* Name.Entity */
.codehilite.a11y-high-contrast-light .ne { color: #7928A1 } /* Name.Exception */
.codehilite.a11y-high-contrast-light .nf { color: #007FAA } /* Name.Function */
.codehilite.a11y-high-contrast-light .nl { color: #797129 } /* Name.Label */
.codehilite.a11y-high-contrast-light .nn { color: #545454 } /* Name.Namespace */
.codehilite.a11y-high-contrast-light .nx { color: #545454 } /* Name.Other */
.codehilite.a11y-high-contrast-light .py { color: #007FAA } /* Name.Property */
.codehilite.a11y-high-contrast-light .nt { color: #007FAA } /* Name.Tag */
.codehilite.a11y-high-contrast-light .nv { color: #D91E18 } /* Name.Variable */
.codehilite.a11y-high-contrast-light .ow { color: #7928A1 } /* Operator.Word */
.codehilite.a11y-high-contrast-light .pm { color: #545454 } /* Punctuation.Marker */
.codehilite.a11y-high-contrast-light .w { color: #545454 } /* Text.Whitespace */
.codehilite.a11y-high-contrast-light .mb { color: #797129 } /* Literal.Number.Bin */
.codehilite.a11y-high-contrast-light .mf { color: #797129 } /* Literal.Number.Float */
.codehilite.a11y-high-contrast-light .mh { color: #797129 } /* Literal.Number.Hex */
.codehilite.a11y-high-contrast-light .mi { color: #797129 } /* Literal.Number.Integer */
.codehilite.a11y-high-contrast-light .mo { color: #797129 } /* Literal.Number.Oct */
.codehilite.a11y-high-contrast-light .sa { color: #008000 } /* Literal.String.Affix */
.codehilite.a11y-high-contrast-light .sb { color: #008000 } /* Literal.String.Backtick */
.codehilite.a11y-high-contrast-light .sc { color: #008000 } /* Literal.String.Char */
.codehilite.a11y-high-contrast-light .dl { color: #008000 } /* Literal.String.Delimiter */
.codehilite.a11y-high-contrast-light .sd { color: #008000 } /* Literal.String.Doc */
.codehilite.a11y-high-contrast-light .s2 { color: #008000 } /* Literal.String.Double */
.codehilite.a11y-high-contrast-light .se { color: #008000 } /* Literal.String.Escape */
.codehilite.a11y-high-contrast-light .sh { color: #008000 } /* Literal.String.Heredoc */
.codehilite.a11y-high-contrast-light .si { color: #008000 } /* Literal.String.Interpol */
.codehilite.a11y-high-contrast-light .sx { color: #008000 } /* Literal.String.Other */
.codehilite.a11y-high-contrast-light .sr { color: #D91E18 } /* Literal.String.Regex */
.codehilite.a11y-high-contrast-light .s1 { color: #008000 } /* Literal.String.Single */
.codehilite.a11y-high-contrast-light .ss { color: #007FAA } /* Literal.String.Symbol */
.codehilite.a11y-high-contrast-light .bp { color: #797129 } /* Name.Builtin.Pseudo */
.codehilite.a11y-high-contrast-light .fm { color: #007FAA } /* Name.Function.Magic */
.codehilite.a11y-high-contrast-light .vc { color: #D91E18 } /* Name.Variable.Class */
.codehilite.a11y-high-contrast-light .vg { color: #D91E18 } /* Name.Variable.Global */
.codehilite.a11y-high-contrast-light .vi { color: #D91E18 } /* Name.Variable.Instance */
.codehilite.a11y-high-contrast-light .vm { color: #797129 } /* Name.Variable.Magic */
.codehilite.a11y-high-contrast-light .il { color: #797129 } /* Literal.Number.Integer.Long */
.codehilite.a11y-light .hll { background-color: #7971292e }
.codehilite.a11y-light { background: #fefefe; color: #545454 }
.codehilite.a11y-light .c { color: #696969 } /* Comment */
.codehilite.a11y-light .err { color: #D91E18 } /* Error */
.codehilite.a11y-light .k { color: #7928A1 } /* Keyword */
.codehilite.a11y-light .l { color: #AA5D00 } /* Literal */
.codehilite.a11y-light .n { color: #545454 } /* Name */
.codehilite.a11y-light .o { color: #008000 } /* Operator */
.codehilite.a11y-light .p { color: #545454 } /* Punctuation */
.codehilite.a11y-light .ch { color: #696969 } /* Comment.Hashbang */
.codehilite.a11y-light .cm { color: #696969 } /* Comment.Multiline */
.codehilite.a11y-light .cp { color: #696969 } /* Comment.Preproc */
.codehilite.a11y-light .cpf { color: #696969 } /* Comment.PreprocFile */
.codehilite.a11y-light .c1 { color: #696969 } /* Comment.Single */
.codehilite.a11y-light .cs { color: #696969 } /* Comment.Special */
.codehilite.a11y-light .gd { color: #007FAA } /* Generic.Deleted */
.codehilite.a11y-light .ge { font-style: italic } /* Generic.Emph */
.codehilite.a11y-light .gh { color: #007FAA } /* Generic.Heading */
.codehilite.a11y-light .gs { font-weight: bold } /* Generic.Strong */
.codehilite.a11y-light .gu { color: #007FAA } /* Generic.Subheading */
.codehilite.a11y-light .kc { color: #7928A1 } /* Keyword.Constant */
.codehilite.a11y-light .kd { color: #7928A1 } /* Keyword.Declaration */
.codehilite.a11y-light .kn { color: #7928A1 } /* Keyword.Namespace */
.codehilite.a11y-light .kp { color: #7928A1 } /* Keyword.Pseudo */
.codehilite.a11y-light .kr { color: #7928A1 } /* Keyword.Reserved */
.codehilite.a11y-light .kt { color: #AA5D00 } /* Keyword.Type */
.codehilite.a11y-light .ld { color: #AA5D00 } /* Literal.Date */
.codehilite.a11y-light .m { color: #AA5D00 } /* Literal.Number */
.codehilite.a11y-light .s { color: #008000 } /* Literal.String */
.codehilite.a11y-light .na { color: #AA5D00 } /* Name.Attribute */
.codehilite.a11y-light .nb { color: #AA5D00 } /* Name.Builtin */
.codehilite.a11y-light .nc { color: #007FAA } /* Name.Class */
.codehilite.a11y-light .no { color: #007FAA } /* Name.Constant */
.codehilite.a11y-light .nd { color: #AA5D00 } /* Name.Decorator */
.codehilite.a11y-light .ni { color: #008000 } /* Name.Entity */
.codehilite.a11y-light .ne { color: #7928A1 } /* Name.Exception */
.codehilite.a11y-light .nf { color: #007FAA } /* Name.Function */
.codehilite.a11y-light .nl { color: #AA5D00 } /* Name.Label */
.codehilite.a11y-light .nn { color: #545454 } /* Name.Namespace */
.codehilite.a11y-light .nx { color: #545454 } /* Name.Other */
.codehilite.a11y-light .py { color: #007FAA } /* Name.Property */
.codehilite.a11y-light .nt { color: #007FAA } /* Name.Tag */
.codehilite.a11y-light .nv { color: #D91E18 } /* Name.Variable */
.codehilite.a11y-light .ow { color: #7928A1 } /* Operator.Word */
.codehilite.a11y-light .pm { color: #545454 } /* Punctuation.Marker */
.codehilite.a11y-light .w { color: #545454 } /* Text.Whitespace */
.codehilite.a11y-light .mb { color: #AA5D00 } /* Literal.Number.Bin */
.codehilite.a11y-light .mf { color: #AA5D00 } /* Literal.Number.Float */
.codehilite.a11y-light .mh { color: #AA5D00 } /* Literal.Number.Hex */
.codehilite.a11y-light .mi { color: #AA5D00 } /* Literal.Number.Integer */
.codehilite.a11y-light .mo { color: #AA5D00 } /* Literal.Number.Oct */
.codehilite.a11y-light .sa { color: #008000 } /* Literal.String.Affix */
.codehilite.a11y-light .sb { color: #008000 } /* Literal.String.Backtick */
.codehilite.a11y-light .sc { color: #008000 } /* Literal.String.Char */
.codehilite.a11y-light .dl { color: #008000 } /* Literal.String.Delimiter */
.codehilite.a11y-light .sd { color: #008000 } /* Literal.String.Doc */
.codehilite.a11y-light .s2 { color: #008000 } /* Literal.String.Double */
.codehilite.a11y-light .se { color: #008000 } /* Literal.String.Escape */
.codehilite.a11y-light .sh { color: #008000 } /* Literal.String.Heredoc */
.codehilite.a11y-light .si { color: #008000 } /* Literal.String.Interpol */
.codehilite.a11y-light .sx { color: #008000 } /* Literal.String.Other */
.codehilite.a11y-light .sr { color: #D91E18 } /* Literal.String.Regex */
.codehilite.a11y-light .s1 { color: #008000 } /* Literal.String.Single */
.codehilite.a11y-light .ss { color: #007FAA } /* Literal.String.Symbol */
.codehilite.a11y-light .bp { color: #AA5D00 } /* Name.Builtin.Pseudo */
.codehilite.a11y-light .fm { color: #007FAA } /* Name.Function.Magic */
.codehilite.a11y-light .vc { color: #D91E18 } /* Name.Variable.Class */
.codehilite.a11y-light .vg { color: #D91E18 } /* Name.Variable.Global */
.codehilite.a11y-light .vi { color: #D91E18 } /* Name.Variable.Instance */
.codehilite.a11y-light .vm { color: #AA5D00 } /* Name.Variable.Magic */
.codehilite.a11y-light .il { color: #AA5D00 } /* Literal.Number.Integer.Long */
.codehilite.blinds-dark .hll { background-color: #66666691 }
.codehilite.blinds-dark { background: #242424; color: #BBB }
.codehilite.blinds-dark .c { color: #8C8C8C } /* Comment */
.codehilite.blinds-dark .err { color: #5391CF } /* Error */
.codehilite.blinds-dark .k { color: #D166A3 } /* Keyword */
.codehilite.blinds-dark .l { color: #5391CF } /* Literal */
.codehilite.blinds-dark .n { color: #5391CF } /* Name */
.codehilite.blinds-dark .o { color: #E67 } /* Operator */
.codehilite.blinds-dark .p { color: #BBB } /* Punctuation */
.codehilite.blinds-dark .ch { color: #8C8C8C } /* Comment.Hashbang */
.codehilite.blinds-dark .cm { color: #8C8C8C } /* Comment.Multiline */
.codehilite.blinds-dark .cp { color: #8C8C8C } /* Comment.Preproc */
.codehilite.blinds-dark .cpf { color: #8C8C8C } /* Comment.PreprocFile */
.codehilite.blinds-dark .c1 { color: #8C8C8C } /* Comment.Single */
.codehilite.blinds-dark .cs { color: #8C8C8C } /* Comment.Special */
.codehilite.blinds-dark .gd { color: #5391CF } /* Generic.Deleted */
.codehilite.blinds-dark .ge { font-style: italic } /* Generic.Emph */
.codehilite.blinds-dark .gh { color: #5391CF } /* Generic.Heading */
.codehilite.blinds-dark .gs { font-weight: bold } /* Generic.Strong */
.codehilite.blinds-dark .gu { color: #5391CF } /* Generic.Subheading */
.codehilite.blinds-dark .kc { color: #D166A3 } /* Keyword.Constant */
.codehilite.blinds-dark .kd { color: #D166A3 } /* Keyword.Declaration */
.codehilite.blinds-dark .kn { color: #D166A3 } /* Keyword.Namespace */
.codehilite.blinds-dark .kp { color: #D166A3 } /* Keyword.Pseudo */
.codehilite.blinds-dark .kr { color: #D166A3 } /* Keyword.Reserved */
.codehilite.blinds-dark .kt { color: #6CE } /* Keyword.Type */
.codehilite.blinds-dark .ld { color: #5391CF } /* Literal.Date */
.codehilite.blinds-dark .m { color: #BBB } /* Literal.Number */
.codehilite.blinds-dark .s { color: #D166A3 } /* Literal.String */
.codehilite.blinds-dark .na { color: #D166A3 } /* Name.Attribute */
.codehilite.blinds-dark .nb { color: #6CE } /* Name.Builtin */
.codehilite.blinds-dark .nc { color: #E67 } /* Name.Class */
.codehilite.blinds-dark .no { color: #E67 } /* Name.Constant */
.codehilite.blinds-dark .nd { color: #CB4 } /* Name.Decorator */
.codehilite.blinds-dark .ni { color: #CB4 } /* Name.Entity */
.codehilite.blinds-dark .ne { color: #5391CF } /* Name.Exception */
.codehilite.blinds-dark .nf { color: #6CE } /* Name.Function */
.codehilite.blinds-dark .nl { color: #E67 } /* Name.Label */
.codehilite.blinds-dark .nn { color: #6CE } /* Name.Namespace */
.codehilite.blinds-dark .nx { color: #5391CF } /* Name.Other */
.codehilite.blinds-dark .py { color: #5391CF } /* Name.Property */
.codehilite.blinds-dark .nt { color: #6CE } /* Name.Tag */
.codehilite.blinds-dark .nv { color: #5391CF } /* Name.Variable */
.codehilite.blinds-dark .ow { color: #D166A3 } /* Operator.Word */
.codehilite.blinds-dark .pm { color: #BBB } /* Punctuation.Marker */
.codehilite.blinds-dark .w { color: #BBB } /* Text.Whitespace */
.codehilite.blinds-dark .mb { color: #BBB } /* Literal.Number.Bin */
.codehilite.blinds-dark .mf { color: #BBB } /* Literal.Number.Float */
.codehilite.blinds-dark .mh { color: #BBB } /* Literal.Number.Hex */
.codehilite.blinds-dark .mi { color: #BBB } /* Literal.Number.Integer */
.codehilite.blinds-dark .mo { color: #BBB } /* Literal.Number.Oct */
.codehilite.blinds-dark .sa { color: #D166A3 } /* Literal.String.Affix */
.codehilite.blinds-dark .sb { color: #D166A3 } /* Literal.String.Backtick */
.codehilite.blinds-dark .sc { color: #D166A3 } /* Literal.String.Char */
.codehilite.blinds-dark .dl { color: #D166A3 } /* Literal.String.Delimiter */
.codehilite.blinds-dark .sd { color: #D166A3 } /* Literal.String.Doc */
.codehilite.blinds-dark .s2 { color: #D166A3 } /* Literal.String.Double */
.codehilite.blinds-dark .se { color: #D166A3 } /* Literal.String.Escape */
.codehilite.blinds-dark .sh { color: #D166A3 } /* Literal.String.Heredoc */
.codehilite.blinds-dark .si { color: #D166A3 } /* Literal.String.Interpol */
.codehilite.blinds-dark .sx { color: #D166A3 } /* Literal.String.Other */
.codehilite.blinds-dark .sr { color: #D166A3 } /* Literal.String.Regex */
.codehilite.blinds-dark .s1 { color: #D166A3 } /* Literal.String.Single */
.codehilite.blinds-dark .ss { color: #E67 } /* Literal.String.Symbol */
.codehilite.blinds-dark .bp { color: #6CE } /* Name.Builtin.Pseudo */
.codehilite.blinds-dark .fm { color: #6CE } /* Name.Function.Magic */
.codehilite.blinds-dark .vc { color: #5391CF } /* Name.Variable.Class */
.codehilite.blinds-dark .vg { color: #5391CF } /* Name.Variable.Global */
.codehilite.blinds-dark .vi { color: #5391CF } /* Name.Variable.Instance */
.codehilite.blinds-dark .vm { color: #E67 } /* Name.Variable.Magic */
.codehilite.blinds-dark .il { color: #BBB } /* Literal.Number.Integer.Long */
.codehilite.blinds-light .hll { background-color: #add6ff }
.codehilite.blinds-light { background: #fcfcfc; color: #000 }
.codehilite.blinds-light .c { color: #737373 } /* Comment */
.codehilite.blinds-light .err { color: #0072B2 } /* Error */
.codehilite.blinds-light .k { color: #CC398B } /* Keyword */
.codehilite.blinds-light .l { color: #0072B2 } /* Literal */
.codehilite.blinds-light .n { color: #0072B2 } /* Name */
.codehilite.blinds-light .o { color: #BF5400 } /* Operator */
.codehilite.blinds-light .p { color: #000 } /* Punctuation */
.codehilite.blinds-light .ch { color: #737373 } /* Comment.Hashbang */
.codehilite.blinds-light .cm { color: #737373 } /* Comment.Multiline */
.codehilite.blinds-light .cp { color: #737373 } /* Comment.Preproc */
.codehilite.blinds-light .cpf { color: #737373 } /* Comment.PreprocFile */
.codehilite.blinds-light .c1 { color: #737373 } /* Comment.Single */
.codehilite.blinds-light .cs { color: #737373 } /* Comment.Special */
.codehilite.blinds-light .gd { color: #0072B2 } /* Generic.Deleted */
.codehilite.blinds-light .ge { font-style: italic } /* Generic.Emph */
.codehilite.blinds-light .gh { color: #0072B2 } /* Generic.Heading */
.codehilite.blinds-light .gs { font-weight: bold } /* Generic.Strong */
.codehilite.blinds-light .gu { color: #0072B2 } /* Generic.Subheading */
.codehilite.blinds-light .kc { color: #CC398B } /* Keyword.Constant */
.codehilite.blinds-light .kd { color: #CC398B } /* Keyword.Declaration */
.codehilite.blinds-light .kn { color: #CC398B } /* Keyword.Namespace */
.codehilite.blinds-light .kp { color: #CC398B } /* Keyword.Pseudo */
.codehilite.blinds-light .kr { color: #CC398B } /* Keyword.Reserved */
.codehilite.blinds-light .kt { color: #008561 } /* Keyword.Type */
.codehilite.blinds-light .ld { color: #0072B2 } /* Literal.Date */
.codehilite.blinds-light .m { color: #000 } /* Literal.Number */
.codehilite.blinds-light .s { color: #CC398B } /* Literal.String */
.codehilite.blinds-light .na { color: #CC398B } /* Name.Attribute */
.codehilite.blinds-light .nb { color: #008561 } /* Name.Builtin */
.codehilite.blinds-light .nc { color: #BF5400 } /* Name.Class */
.codehilite.blinds-light .no { color: #BF5400 } /* Name.Constant */
.codehilite.blinds-light .nd { color: #996B00 } /* Name.Decorator */
.codehilite.blinds-light .ni { color: #0072B2 } /* Name.Entity */
.codehilite.blinds-light .ne { color: #0072B2 } /* Name.Exception */
.codehilite.blinds-light .nf { color: #008561 } /* Name.Function */
.codehilite.blinds-light .nl { color: #BF5400 } /* Name.Label */
.codehilite.blinds-light .nn { color: #008561 } /* Name.Namespace */
.codehilite.blinds-light .nx { color: #0072B2 } /* Name.Other */
.codehilite.blinds-light .py { color: #0072B2 } /* Name.Property */
.codehilite.blinds-light .nt { color: #008561 } /* Name.Tag */
.codehilite.blinds-light .nv { color: #0072B2 } /* Name.Variable */
.codehilite.blinds-light .ow { color: #CC398B } /* Operator.Word */
.codehilite.blinds-light .pm { color: #000 } /* Punctuation.Marker */
.codehilite.blinds-light .w { color: #000 } /* Text.Whitespace */
.codehilite.blinds-light .mb { color: #000 } /* Literal.Number.Bin */
.codehilite.blinds-light .mf { color: #000 } /* Literal.Number.Float */
.codehilite.blinds-light .mh { color: #000 } /* Literal.Number.Hex */
.codehilite.blinds-light .mi { color: #000 } /* Literal.Number.Integer */
.codehilite.blinds-light .mo { color: #000 } /* Literal.Number.Oct */
.codehilite.blinds-light .sa { color: #CC398B } /* Literal.String.Affix */
.codehilite.blinds-light .sb { color: #CC398B } /* Literal.String.Backtick */
.codehilite.blinds-light .sc { color: #CC398B } /* Literal.String.Char */
.codehilite.blinds-light .dl { color: #CC398B } /* Literal.String.Delimiter */
.codehilite.blinds-light .sd { color: #CC398B } /* Literal.String.Doc */
.codehilite.blinds-light .s2 { color: #CC398B } /* Literal.String.Double */
.codehilite.blinds-light .se { color: #CC398B } /* Literal.String.Escape */
.codehilite.blinds-light .sh { color: #CC398B } /* Literal.String.Heredoc */
.codehilite.blinds-light .si { color: #CC398B } /* Literal.String.Interpol */
.codehilite.blinds-light .sx { color: #CC398B } /* Literal.String.Other */
.codehilite.blinds-light .sr { color: #CC398B } /* Literal.String.Regex */
.codehilite.blinds-light .s1 { color: #CC398B } /* Literal.String.Single */
.codehilite.blinds-light .ss { color: #BF5400 } /* Literal.String.Symbol */
.codehilite.blinds-light .bp { color: #008561 } /* Name.Builtin.Pseudo */
.codehilite.blinds-light .fm { color: #008561 } /* Name.Function.Magic */
.codehilite.blinds-light .vc { color: #0072B2 } /* Name.Variable.Class */
.codehilite.blinds-light .vg { color: #0072B2 } /* Name.Variable.Global */
.codehilite.blinds-light .vi { color: #0072B2 } /* Name.Variable.Instance */
.codehilite.blinds-light .vm { color: #BF5400 } /* Name.Variable.Magic */
.codehilite.blinds-light .il { color: #000 } /* Literal.Number.Integer.Long */
.codehilite.github-dark .hll { background-color: #6e7681 }
.codehilite.github-dark { background: #0d1117; color: #E6EDF3 }
.codehilite.github-dark .c { color: #8B949E; font-style: italic } /* Comment */
.codehilite.github-dark .err { color: #F85149 } /* Error */
.codehilite.github-dark .esc { color: #E6EDF3 } /* Escape */
.codehilite.github-dark .g { color: #E6EDF3 } /* Generic */
.codehilite.github-dark .k { color: #FF7B72 } /* Keyword */
.codehilite.github-dark .l { color: #A5D6FF } /* Literal */
.codehilite.github-dark .n { color: #E6EDF3 } /* Name */
.codehilite.github-dark .o { color: #FF7B72; font-weight: bold } /* Operator */
.codehilite.github-dark .x { color: #E6EDF3 } /* Other */
.codehilite.github-dark .p { color: #E6EDF3 } /* Punctuation */
.codehilite.github-dark .ch { color: #8B949E; font-style: italic } /* Comment.Hashbang */
.codehilite.github-dark .cm { color: #8B949E; font-style: italic } /* Comment.Multiline */
.codehilite.github-dark .cp { color: #8B949E; font-weight: bold; font-style: italic } /* Comment.Preproc */
.codehilite.github-dark .cpf { color: #8B949E; font-style: italic } /* Comment.PreprocFile */
.codehilite.github-dark .c1 { color: #8B949E; font-style: italic } /* Comment.Single */
.codehilite.github-dark .cs { color: #8B949E; font-weight: bold; font-style: italic } /* Comment.Special */
.codehilite.github-dark .gd { color: #FFA198; background-color: #490202 } /* Generic.Deleted */
.codehilite.github-dark .ge { color: #E6EDF3; font-style: italic } /* Generic.Emph */
.codehilite.github-dark .ges { color: #E6EDF3; font-weight: bold; font-style: italic } /* Generic.EmphStrong */
.codehilite.github-dark .gr { color: #FFA198 } /* Generic.Error */
.codehilite.github-dark .gh { color: #79C0FF; font-weight: bold } /* Generic.Heading */
.codehilite.github-dark .gi { color: #56D364; background-color: #0F5323 } /* Generic.Inserted */
.codehilite.github-dark .go { color: #8B949E } /* Generic.Output */
.codehilite.github-dark .gp { color: #8B949E } /* Generic.Prompt */
.codehilite.github-dark .gs { color: #E6EDF3; font-weight: bold } /* Generic.Strong */
.codehilite.github-dark .gu { color: #79C0FF } /* Generic.Subheading */
.codehilite.github-dark .gt { color: #FF7B72 } /* Generic.Traceback */
.codehilite.github-dark .g-Underline { color: #E6EDF3; text-decoration: underline } /* Generic.Underline */
.codehilite.github-dark .kc { color: #79C0FF } /* Keyword.Constant */
.codehilite.github-dark .kd { color: #FF7B72 } /* Keyword.Declaration */
.codehilite.github-dark .kn { color: #FF7B72 } /* Keyword.Namespace */
.codehilite.github-dark .kp { color: #79C0FF } /* Keyword.Pseudo */
.codehilite.github-dark .kr { color: #FF7B72 } /* Keyword.Reserved */
.codehilite.github-dark .kt { color: #FF7B72 } /* Keyword.Type */
.codehilite.github-dark .ld { color: #79C0FF } /* Literal.Date */
.codehilite.github-dark .m { color: #A5D6FF } /* Literal.Number */
.codehilite.github-dark .s { color: #A5D6FF } /* Literal.String */
.codehilite.github-dark .na { color: #E6EDF3 } /* Name.Attribute */
.codehilite.github-dark .nb { color: #E6EDF3 } /* Name.Builtin */
.codehilite.github-dark .nc { color: #F0883E; font-weight: bold } /* Name.Class */
.codehilite.github-dark .no { color: #79C0FF; font-weight: bold } /* Name.Constant */
.codehilite.github-dark .nd { color: #D2A8FF; font-weight: bold } /* Name.Decorator */
.codehilite.github-dark .ni { color: #FFA657 } /* Name.Entity */
.codehilite.github-dark .ne { color: #F0883E; font-weight: bold } /* Name.Exception */
.codehilite.github-dark .nf { color: #D2A8FF; font-weight: bold } /* Name.Function */
.codehilite.github-dark .nl { color: #79C0FF; font-weight: bold } /* Name.Label */
.codehilite.github-dark .nn { color: #FF7B72 } /* Name.Namespace */
.codehilite.github-dark .nx { color: #E6EDF3 } /* Name.Other */
.codehilite.github-dark .py { color: #79C0FF } /* Name.Property */
.codehilite.github-dark .nt { color: #7EE787 } /* Name.Tag */
.codehilite.github-dark .nv { color: #79C0FF } /* Name.Variable */
.codehilite.github-dark .ow { color: #FF7B72; font-weight: bold } /* Operator.Word */
.codehilite.github-dark .pm { color: #E6EDF3 } /* Punctuation.Marker */
.codehilite.github-dark .w { color: #6E7681 } /* Text.Whitespace */
.codehilite.github-dark .mb { color: #A5D6FF } /* Literal.Number.Bin */
.codehilite.github-dark .mf { color: #A5D6FF } /* Literal.Number.Float */
.codehilite.github-dark .mh { color: #A5D6FF } /* Literal.Number.Hex */
.codehilite.github-dark .mi { color: #A5D6FF } /* Literal.Number.Integer */
.codehilite.github-dark .mo { color: #A5D6FF } /* Literal.Number.Oct */
.codehilite.github-dark .sa { color: #79C0FF } /* Literal.String.Affix */
.codehilite.github-dark .sb { color: #A5D6FF } /* Literal.String.Backtick */
.codehilite.github-dark .sc { color: #A5D6FF } /* Literal.String.Char */
.codehilite.github-dark .dl { color: #79C0FF } /* Literal.String.Delimiter */
.codehilite.github-dark .sd { color: #A5D6FF } /* Literal.String.Doc */
.codehilite.github-dark .s2 { color: #A5D6FF } /* Literal.String.Double */
.codehilite.github-dark .se { color: #79C0FF } /* Literal.String.Escape */
.codehilite.github-dark .sh { color: #79C0FF } /* Literal.String.Heredoc */
.codehilite.github-dark .si { color: #A5D6FF } /* Literal.String.Interpol */
.codehilite.github-dark .sx { color: #A5D6FF } /* Literal.String.Other */
.codehilite.github-dark .sr { color: #79C0FF } /* Literal.String.Regex */
.codehilite.github-dark .s1 { color: #A5D6FF } /* Literal.String.Single */
.codehilite.github-dark .ss { color: #A5D6FF } /* Literal.String.Symbol */
.codehilite.github-dark .bp { color: #E6EDF3 } /* Name.Builtin.Pseudo */
.codehilite.github-dark .fm { color: #D2A8FF; font-weight: bold } /* Name.Function.Magic */
.codehilite.github-dark .vc { color: #79C0FF } /* Name.Variable.Class */
.codehilite.github-dark .vg { color: #79C0FF } /* Name.Variable.Global */
.codehilite.github-dark .vi { color: #79C0FF } /* Name.Variable.Instance */
.codehilite.github-dark .vm { color: #79C0FF } /* Name.Variable.Magic */
.codehilite.github-dark .il { color: #A5D6FF } /* Literal.Number.Integer.Long */
.codehilite.github-dark-colorblind .hll { background-color: #58a6ff70 }
.codehilite.github-dark-colorblind { background: #0d1117; color: #C9D1D9 }
.codehilite.github-dark-colorblind .c { color: #B1BAC4 } /* Comment */
.codehilite.github-dark-colorblind .err { color: #EC8E2C } /* Error */
.codehilite.github-dark-colorblind .k { color: #EC8E2C } /* Keyword */
.codehilite.github-dark-colorblind .l { color: #FDAC54 } /* Literal */
.codehilite.github-dark-colorblind .n { color: #D2A8FF } /* Name */
.codehilite.github-dark-colorblind .o { color: #A5D6FF } /* Operator */
.codehilite.github-dark-colorblind .p { color: #C9D1D9 } /* Punctuation */
.codehilite.github-dark-colorblind .ch { color: #B1BAC4 } /* Comment.Hashbang */
.codehilite.github-dark-colorblind .cm { color: #B1BAC4 } /* Comment.Multiline */
.codehilite.github-dark-colorblind .cp { color: #B1BAC4 } /* Comment.Preproc */
.codehilite.github-dark-colorblind .cpf { color: #B1BAC4 } /* Comment.PreprocFile */
.codehilite.github-dark-colorblind .c1 { color: #B1BAC4 } /* Comment.Single */
.codehilite.github-dark-colorblind .cs { color: #B1BAC4 } /* Comment.Special */
.codehilite.github-dark-colorblind .gd { color: #79C0FF } /* Generic.Deleted */
.codehilite.github-dark-colorblind .ge { font-style: italic } /* Generic.Emph */
.codehilite.github-dark-colorblind .gr { color: #EC8E2C } /* Generic.Error */
.codehilite.github-dark-colorblind .gh { color: #79C0FF } /* Generic.Heading */
.codehilite.github-dark-colorblind .gs { font-weight: bold } /* Generic.Strong */
.codehilite.github-dark-colorblind .gu { color: #79C0FF } /* Generic.Subheading */
.codehilite.github-dark-colorblind .kc { color: #79C0FF } /* Keyword.Constant */
.codehilite.github-dark-colorblind .kd { color: #EC8E2C } /* Keyword.Declaration */
.codehilite.github-dark-colorblind .kn { color: #EC8E2C } /* Keyword.Namespace */
.codehilite.github-dark-colorblind .kp { color: #EC8E2C } /* Keyword.Pseudo */
.codehilite.github-dark-colorblind .kr { color: #EC8E2C } /* Keyword.Reserved */
.codehilite.github-dark-colorblind .kt { color: #EC8E2C } /* Keyword.Type */
.codehilite.github-dark-colorblind .ld { color: #FDAC54 } /* Literal.Date */
.codehilite.github-dark-colorblind .m { color: #FDAC54 } /* Literal.Number */
.codehilite.github-dark-colorblind .s { color: #79C0FF } /* Literal.String */
.codehilite.github-dark-colorblind .na { color: #FDAC54 } /* Name.Attribute */
.codehilite.github-dark-colorblind .nb { color: #FDAC54 } /* Name.Builtin */
.codehilite.github-dark-colorblind .nc { color: #79C0FF } /* Name.Class */
.codehilite.github-dark-colorblind .no { color: #79C0FF } /* Name.Constant */
.codehilite.github-dark-colorblind .nd { color: #FDAC54 } /* Name.Decorator */
.codehilite.github-dark-colorblind .ni { color: #A5D6FF } /* Name.Entity */
.codehilite.github-dark-colorblind .ne { color: #D2A8FF } /* Name.Exception */
.codehilite.github-dark-colorblind .nf { color: #79C0FF } /* Name.Function */
.codehilite.github-dark-colorblind .nl { color: #FDAC54 } /* Name.Label */
.codehilite.github-dark-colorblind .nn { color: #C9D1D9 } /* Name.Namespace */
.codehilite.github-dark-colorblind .nx { color: #D2A8FF } /* Name.Other */
.codehilite.github-dark-colorblind .py { color: #79C0FF } /* Name.Property */
.codehilite.github-dark-colorblind .nt { color: #A5D6FF } /* Name.Tag */
.codehilite.github-dark-colorblind .nv { color: #FDAC54 } /* Name.Variable */
.codehilite.github-dark-colorblind .ow { color: #D2A8FF } /* Operator.Word */
.codehilite.github-dark-colorblind .pm { color: #C9D1D9 } /* Punctuation.Marker */
.codehilite.github-dark-colorblind .w { color: #C9D1D9 } /* Text.Whitespace */
.codehilite.github-dark-colorblind .mb { color: #FDAC54 } /* Literal.Number.Bin */
.codehilite.github-dark-colorblind .mf { color: #FDAC54 } /* Literal.Number.Float */
.codehilite.github-dark-colorblind .mh { color: #FDAC54 } /* Literal.Number.Hex */
.codehilite.github-dark-colorblind .mi { color: #FDAC54 } /* Literal.Number.Integer */
.codehilite.github-dark-colorblind .mo { color: #FDAC54 } /* Literal.Number.Oct */
.codehilite.github-dark-colorblind .sa { color: #79C0FF } /* Literal.String.Affix */
.codehilite.github-dark-colorblind .sb { color: #79C0FF } /* Literal.String.Backtick */
.codehilite.github-dark-colorblind .sc { color: #79C0FF } /* Literal.String.Char */
.codehilite.github-dark-colorblind .dl { color: #79C0FF } /* Literal.String.Delimiter */
.codehilite.github-dark-colorblind .sd { color: #79C0FF } /* Literal.String.Doc */
.codehilite.github-dark-colorblind .s2 { color: #79C0FF } /* Literal.String.Double */
.codehilite.github-dark-colorblind .se { color: #79C0FF } /* Literal.String.Escape */
.codehilite.github-dark-colorblind .sh { color: #79C0FF } /* Literal.String.Heredoc */
.codehilite.github-dark-colorblind .si { color: #79C0FF } /* Literal.String.Interpol */
.codehilite.github-dark-colorblind .sx { color: #79C0FF } /* Literal.String.Other */
.codehilite.github-dark-colorblind .sr { color: #79C0FF } /* Literal.String.Regex */
.codehilite.github-dark-colorblind .s1 { color: #79C0FF } /* Literal.String.Single */
.codehilite.github-dark-colorblind .ss { color: #79C0FF } /* Literal.String.Symbol */
.codehilite.github-dark-colorblind .bp { color: #FDAC54 } /* Name.Builtin.Pseudo */
.codehilite.github-dark-colorblind .fm { color: #79C0FF } /* Name.Function.Magic */
.codehilite.github-dark-colorblind .vc { color: #FDAC54 } /* Name.Variable.Class */
.codehilite.github-dark-colorblind .vg { color: #FDAC54 } /* Name.Variable.Global */
.codehilite.github-dark-colorblind .vi { color: #FDAC54 } /* Name.Variable.Instance */
.codehilite.github-dark-colorblind .vm { color: #FDAC54 } /* Name.Variable.Magic */
.codehilite.github-dark-colorblind .il { color: #FDAC54 } /* Literal.Number.Integer.Long */
.codehilite.github-dark-high-contrast .hll { background-color: #58a6ff70 }
.codehilite.github-dark-high-contrast { background: #0d1117; color: #C9D1D9 }
.codehilite.github-dark-high-contrast .c { color: #D9DEE3 } /* Comment */
.codehilite.github-dark-high-contrast .err { color: #FF9492 } /* Error */
.codehilite.github-dark-high-contrast .k { color: #FF9492 } /* Keyword */
.codehilite.github-dark-high-contrast .l { color: #FFB757 } /* Literal */
.codehilite.github-dark-high-contrast .n { color: #DBB7FF } /* Name */
.codehilite.github-dark-high-contrast .o { color: #72F088 } /* Operator */
.codehilite.github-dark-high-contrast .p { color: #C9D1D9 } /* Punctuation */
.codehilite.github-dark-high-contrast .ch { color: #D9DEE3 } /* Comment.Hashbang */
.codehilite.github-dark-high-contrast .cm { color: #D9DEE3 } /* Comment.Multiline */
.codehilite.github-dark-high-contrast .cp { color: #D9DEE3 } /* Comment.Preproc */
.codehilite.github-dark-high-contrast .cpf { color: #D9DEE3 } /* Comment.PreprocFile */
.codehilite.github-dark-high-contrast .c1 { color: #D9DEE3 } /* Comment.Single */
.codehilite.github-dark-high-contrast .cs { color: #D9DEE3 } /* Comment.Special */
.codehilite.github-dark-high-contrast .gd { color: #91CBFF } /* Generic.Deleted */
.codehilite.github-dark-high-contrast .ge { font-style: italic } /* Generic.Emph */
.codehilite.github-dark-high-contrast .gr { color: #FF9492 } /* Generic.Error */
.codehilite.github-dark-high-contrast .gh { color: #91CBFF } /* Generic.Heading */
.codehilite.github-dark-high-contrast .gs { font-weight: bold } /* Generic.Strong */
.codehilite.github-dark-high-contrast .gu { color: #91CBFF } /* Generic.Subheading */
.codehilite.github-dark-high-contrast .kc { color: #91CBFF } /* Keyword.Constant */
.codehilite.github-dark-high-contrast .kd { color: #FF9492 } /* Keyword.Declaration */
.codehilite.github-dark-high-contrast .kn { color: #FF9492 } /* Keyword.Namespace */
.codehilite.github-dark-high-contrast .kp { color: #FF9492 } /* Keyword.Pseudo */
.codehilite.github-dark-high-contrast .kr { color: #FF9492 } /* Keyword.Reserved */
.codehilite.github-dark-high-contrast .kt { color: #FF9492 } /* Keyword.Type */
.codehilite.github-dark-high-contrast .ld { color: #FFB757 } /* Literal.Date */
.codehilite.github-dark-high-contrast .m { color: #FFB757 } /* Literal.Number */
.codehilite.github-dark-high-contrast .s { color: #91CBFF } /* Literal.String */
.codehilite.github-dark-high-contrast .na { color: #FFB757 } /* Name.Attribute */
.codehilite.github-dark-high-contrast .nb { color: #FFB757 } /* Name.Builtin */
.codehilite.github-dark-high-contrast .nc { color: #91CBFF } /* Name.Class */
.codehilite.github-dark-high-contrast .no { color: #91CBFF } /* Name.Constant */
.codehilite.github-dark-high-contrast .nd { color: #FFB757 } /* Name.Decorator */
.codehilite.github-dark-high-contrast .ni { color: #72F088 } /* Name.Entity */
.codehilite.github-dark-high-contrast .ne { color: #DBB7FF } /* Name.Exception */
.codehilite.github-dark-high-contrast .nf { color: #91CBFF } /* Name.Function */
.codehilite.github-dark-high-contrast .nl { color: #FFB757 } /* Name.Label */
.codehilite.github-dark-high-contrast .nn { color: #C9D1D9 } /* Name.Namespace */
.codehilite.github-dark-high-contrast .nx { color: #DBB7FF } /* Name.Other */
.codehilite.github-dark-high-contrast .py { color: #91CBFF } /* Name.Property */
.codehilite.github-dark-high-contrast .nt { color: #72F088 } /* Name.Tag */
.codehilite.github-dark-high-contrast .nv { color: #FFB757 } /* Name.Variable */
.codehilite.github-dark-high-contrast .ow { color: #DBB7FF } /* Operator.Word */
.codehilite.github-dark-high-contrast .pm { color: #C9D1D9 } /* Punctuation.Marker */
.codehilite.github-dark-high-contrast .w { color: #C9D1D9 } /* Text.Whitespace */
.codehilite.github-dark-high-contrast .mb { color: #FFB757 } /* Literal.Number.Bin */
.codehilite.github-dark-high-contrast .mf { color: #FFB757 } /* Literal.Number.Float */
.codehilite.github-dark-high-contrast .mh { color: #FFB757 } /* Literal.Number.Hex */
.codehilite.github-dark-high-contrast .mi { color: #FFB757 } /* Literal.Number.Integer */
.codehilite.github-dark-high-contrast .mo { color: #FFB757 } /* Literal.Number.Oct */
.codehilite.github-dark-high-contrast .sa { color: #91CBFF } /* Literal.String.Affix */
.codehilite.github-dark-high-contrast .sb { color: #91CBFF } /* Literal.String.Backtick */
.codehilite.github-dark-high-contrast .sc { color: #91CBFF } /* Literal.String.Char */
.codehilite.github-dark-high-contrast .dl { color: #91CBFF } /* Literal.String.Delimiter */
.codehilite.github-dark-high-contrast .sd { color: #91CBFF } /* Literal.String.Doc */
.codehilite.github-dark-high-contrast .s2 { color: #91CBFF } /* Literal.String.Double */
.codehilite.github-dark-high-contrast .se { color: #91CBFF } /* Literal.String.Escape */
.codehilite.github-dark-high-contrast .sh { color: #91CBFF } /* Literal.String.Heredoc */
.codehilite.github-dark-high-contrast .si { color: #91CBFF } /* Literal.String.Interpol */
.codehilite.github-dark-high-contrast .sx { color: #91CBFF } /* Literal.String.Other */
.codehilite.github-dark-high-contrast .sr { color: #91CBFF } /* Literal.String.Regex */
.codehilite.github-dark-high-contrast .s1 { color: #91CBFF } /* Literal.String.Single */
.codehilite.github-dark-high-contrast .ss { color: #91CBFF } /* Literal.String.Symbol */
.codehilite.github-dark-high-contrast .bp { color: #FFB757 } /* Name.Builtin.Pseudo */
.codehilite.github-dark-high-contrast .fm { color: #91CBFF } /* Name.Function.Magic */
.codehilite.github-dark-high-contrast .vc { color: #FFB757 } /* Name.Variable.Class */
.codehilite.github-dark-high-contrast .vg { color: #FFB757 } /* Name.Variable.Global */
.codehilite.github-dark-high-contrast .vi { color: #FFB757 } /* Name.Variable.Instance */
.codehilite.github-dark-high-contrast .vm { color: #FFB757 } /* Name.Variable.Magic */
.codehilite.github-dark-high-contrast .il { color: #FFB757 } /* Literal.Number.Integer.Long */
.codehilite.github-light .hll { background-color: #0969da4a }
.codehilite.github-light { background: #ffffff; color: #24292F }
.codehilite.github-light .c { color: #6E7781 } /* Comment */
.codehilite.github-light .err { color: #CF222E } /* Error */
.codehilite.github-light .k { color: #CF222E } /* Keyword */
.codehilite.github-light .l { color: #953800 } /* Literal */
.codehilite.github-light .n { color: #8250DF } /* Name */
.codehilite.github-light .o { color: #116329 } /* Operator */
.codehilite.github-light .p { color: #24292F } /* Punctuation */
.codehilite.github-light .ch { color: #6E7781 } /* Comment.Hashbang */
.codehilite.github-light .cm { color: #6E7781 } /* Comment.Multiline */
.codehilite.github-light .cp { color: #6E7781 } /* Comment.Preproc */
.codehilite.github-light .cpf { color: #6E7781 } /* Comment.PreprocFile */
.codehilite.github-light .c1 { color: #6E7781 } /* Comment.Single */
.codehilite.github-light .cs { color: #6E7781 } /* Comment.Special */
.codehilite.github-light .gd { color: #0550AE } /* Generic.Deleted */
.codehilite.github-light .ge { font-style: italic } /* Generic.Emph */
.codehilite.github-light .gr { color: #CF222E } /* Generic.Error */
.codehilite.github-light .gh { color: #0550AE } /* Generic.Heading */
.codehilite.github-light .gs { font-weight: bold } /* Generic.Strong */
.codehilite.github-light .gu { color: #0550AE } /* Generic.Subheading */
.codehilite.github-light .kc { color: #0550AE } /* Keyword.Constant */
.codehilite.github-light .kd { color: #CF222E } /* Keyword.Declaration */
.codehilite.github-light .kn { color: #CF222E } /* Keyword.Namespace */
.codehilite.github-light .kp { color: #CF222E } /* Keyword.Pseudo */
.codehilite.github-light .kr { color: #CF222E } /* Keyword.Reserved */
.codehilite.github-light .kt { color: #CF222E } /* Keyword.Type */
.codehilite.github-light .ld { color: #953800 } /* Literal.Date */
.codehilite.github-light .m { color: #953800 } /* Literal.Number */
.codehilite.github-light .s { color: #0550AE } /* Literal.String */
.codehilite.github-light .na { color: #953800 } /* Name.Attribute */
.codehilite.github-light .nb { color: #953800 } /* Name.Builtin */
.codehilite.github-light .nc { color: #0550AE } /* Name.Class */
.codehilite.github-light .no { color: #0550AE } /* Name.Constant */
.codehilite.github-light .nd { color: #953800 } /* Name.Decorator */
.codehilite.github-light .ni { color: #116329 } /* Name.Entity */
.codehilite.github-light .ne { color: #8250DF } /* Name.Exception */
.codehilite.github-light .nf { color: #0550AE } /* Name.Function */
.codehilite.github-light .nl { color: #953800 } /* Name.Label */
.codehilite.github-light .nn { color: #24292F } /* Name.Namespace */
.codehilite.github-light .nx { color: #8250DF } /* Name.Other */
.codehilite.github-light .py { color: #0550AE } /* Name.Property */
.codehilite.github-light .nt { color: #116329 } /* Name.Tag */
.codehilite.github-light .nv { color: #953800 } /* Name.Variable */
.codehilite.github-light .ow { color: #8250DF } /* Operator.Word */
.codehilite.github-light .pm { color: #24292F } /* Punctuation.Marker */
.codehilite.github-light .w { color: #24292F } /* Text.Whitespace */
.codehilite.github-light .mb { color: #953800 } /* Literal.Number.Bin */
.codehilite.github-light .mf { color: #953800 } /* Literal.Number.Float */
.codehilite.github-light .mh { color: #953800 } /* Literal.Number.Hex */
.codehilite.github-light .mi { color: #953800 } /* Literal.Number.Integer */
.codehilite.github-light .mo { color: #953800 } /* Literal.Number.Oct */
.codehilite.github-light .sa { color: #0550AE } /* Literal.String.Affix */
.codehilite.github-light .sb { color: #0550AE } /* Literal.String.Backtick */
.codehilite.github-light .sc { color: #0550AE } /* Literal.String.Char */
.codehilite.github-light .dl { color: #0550AE } /* Literal.String.Delimiter */
.codehilite.github-light .sd { color: #0550AE } /* Literal.String.Doc */
.codehilite.github-light .s2 { color: #0550AE } /* Literal.String.Double */
.codehilite.github-light .se { color: #0550AE } /* Literal.String.Escape */
.codehilite.github-light .sh { color: #0550AE } /* Literal.String.Heredoc */
.codehilite.github-light .si { color: #0550AE } /* Literal.String.Interpol */
.codehilite.github-light .sx { color: #0550AE } /* Literal.String.Other */
.codehilite.github-light .sr { color: #0550AE } /* Literal.String.Regex */
.codehilite.github-light .s1 { color: #0550AE } /* Literal.String.Single */
.codehilite.github-light .ss { color: #0550AE } /* Literal.String.Symbol */
.codehilite.github-light .bp { color: #953800 } /* Name.Builtin.Pseudo */
.codehilite.github-light .fm { color: #0550AE } /* Name.Function.Magic */
.codehilite.github-light .vc { color: #953800 } /* Name.Variable.Class */
.codehilite.github-light .vg { color: #953800 } /* Name.Variable.Global */
.codehilite.github-light .vi { color: #953800 } /* Name.Variable.Instance */
.codehilite.github-light .vm { color: #953800 } /* Name.Variable.Magic */
.codehilite.github-light .il { color: #953800 } /* Literal.Number.Integer.Long */
.codehilite.github-light-colorblind .hll { background-color: #0969da4a }
.codehilite.github-light-colorblind { background: #ffffff; color: #24292F }
.codehilite.github-light-colorblind .c { color: #6E7781 } /* Comment */
.codehilite.github-light-colorblind .err { color: #B35900 } /* Error */
.codehilite.github-light-colorblind .k { color: #B35900 } /* Keyword */
.codehilite.github-light-colorblind .l { color: #8A4600 } /* Literal */
.codehilite.github-light-colorblind .n { color: #8250DF } /* Name */
.codehilite.github-light-colorblind .o { color: #0550AE } /* Operator */
.codehilite.github-light-colorblind .p { color: #24292F } /* Punctuation */
.codehilite.github-light-colorblind .ch { color: #6E7781 } /* Comment.Hashbang */
.codehilite.github-light-colorblind .cm { color: #6E7781 } /* Comment.Multiline */
.codehilite.github-light-colorblind .cp { color: #6E7781 } /* Comment.Preproc */
.codehilite.github-light-colorblind .cpf { color: #6E7781 } /* Comment.PreprocFile */
.codehilite.github-light-colorblind .c1 { color: #6E7781 } /* Comment.Single */
.codehilite.github-light-colorblind .cs { color: #6E7781 } /* Comment.Special */
.codehilite.github-light-colorblind .gd { color: #0550AE } /* Generic.Deleted */
.codehilite.github-light-colorblind .ge { font-style: italic } /* Generic.Emph */
.codehilite.github-light-colorblind .gr { color: #B35900 } /* Generic.Error */
.codehilite.github-light-colorblind .gh { color: #0550AE } /* Generic.Heading */
.codehilite.github-light-colorblind .gs { font-weight: bold } /* Generic.Strong */
.codehilite.github-light-colorblind .gu { color: #0550AE } /* Generic.Subheading */
.codehilite.github-light-colorblind .kc { color: #0550AE } /* Keyword.Constant */
.codehilite.github-light-colorblind .kd { color: #B35900 } /* Keyword.Declaration */
.codehilite.github-light-colorblind .kn { color: #B35900 } /* Keyword.Namespace */
.codehilite.github-light-colorblind .kp { color: #B35900 } /* Keyword.Pseudo */
.codehilite.github-light-colorblind .kr { color: #B35900 } /* Keyword.Reserved */
.codehilite.github-light-colorblind .kt { color: #B35900 } /* Keyword.Type */
.codehilite.github-light-colorblind .ld { color: #8A4600 } /* Literal.Date */
.codehilite.github-light-colorblind .m { color: #8A4600 } /* Literal.Number */
.codehilite.github-light-colorblind .s { color: #0550AE } /* Literal.String */
.codehilite.github-light-colorblind .na { color: #8A4600 } /* Name.Attribute */
.codehilite.github-light-colorblind .nb { color: #8A4600 } /* Name.Builtin */
.codehilite.github-light-colorblind .nc { color: #0550AE } /* Name.Class */
.codehilite.github-light-colorblind .no { color: #0550AE } /* Name.Constant */
.codehilite.github-light-colorblind .nd { color: #8A4600 } /* Name.Decorator */
.codehilite.github-light-colorblind .ni { color: #0550AE } /* Name.Entity */
.codehilite.github-light-colorblind .ne { color: #8250DF } /* Name.Exception */
.codehilite.github-light-colorblind .nf { color: #0550AE } /* Name.Function */
.codehilite.github-light-colorblind .nl { color: #8A4600 } /* Name.Label */
.codehilite.github-light-colorblind .nn { color: #24292F } /* Name.Namespace */
.codehilite.github-light-colorblind .nx { color: #8250DF } /* Name.Other */
.codehilite.github-light-colorblind .py { color: #0550AE } /* Name.Property */
.codehilite.github-light-colorblind .nt { color: #0550AE } /* Name.Tag */
.codehilite.github-light-colorblind .nv { color: #8A4600 } /* Name.Variable */
.codehilite.github-light-colorblind .ow { color: #8250DF } /* Operator.Word */
.codehilite.github-light-colorblind .pm { color: #24292F } /* Punctuation.Marker */
.codehilite.github-light-colorblind .w { color: #24292F } /* Text.Whitespace */
.codehilite.github-light-colorblind .mb { color: #8A4600 } /* Literal.Number.Bin */
.codehilite.github-light-colorblind .mf { color: #8A4600 } /* Literal.Number.Float */
.codehilite.github-light-colorblind .mh { color: #8A4600 } /* Literal.Number.Hex */
.codehilite.github-light-colorblind .mi { color: #8A4600 } /* Literal.Number.Integer */
.codehilite.github-light-colorblind .mo { color: #8A4600 } /* Literal.Number.Oct */
.codehilite.github-light-colorblind .sa { color: #0550AE } /* Literal.String.Affix */
.codehilite.github-light-colorblind .sb { color: #0550AE } /* Literal.String.Backtick */
.codehilite.github-light-colorblind .sc { color: #0550AE } /* Literal.String.Char */
.codehilite.github-light-colorblind .dl { color: #0550AE } /* Literal.String.Delimiter */
.codehilite.github-light-colorblind .sd { color: #0550AE } /* Literal.String.Doc */
.codehilite.github-light-colorblind .s2 { color: #0550AE } /* Literal.String.Double */
.codehilite.github-light-colorblind .se { color: #0550AE } /* Literal.String.Escape */
.codehilite.github-light-colorblind .sh { color: #0550AE } /* Literal.String.Heredoc */
.codehilite.github-light-colorblind .si { color: #0550AE } /* Literal.String.Interpol */
.codehilite.github-light-colorblind .sx { color: #0550AE } /* Literal.String.Other */
.codehilite.github-light-colorblind .sr { color: #0550AE } /* Literal.String.Regex */
.codehilite.github-light-colorblind .s1 { color: #0550AE } /* Literal.String.Single */
.codehilite.github-light-colorblind .ss { color: #0550AE } /* Literal.String.Symbol */
.codehilite.github-light-colorblind .bp { color: #8A4600 } /* Name.Builtin.Pseudo */
.codehilite.github-light-colorblind .fm { color: #0550AE } /* Name.Function.Magic */
.codehilite.github-light-colorblind .vc { color: #8A4600 } /* Name.Variable.Class */
.codehilite.github-light-colorblind .vg { color: #8A4600 } /* Name.Variable.Global */
.codehilite.github-light-colorblind .vi { color: #8A4600 } /* Name.Variable.Instance */
.codehilite.github-light-colorblind .vm { color: #8A4600 } /* Name.Variable.Magic */
.codehilite.github-light-colorblind .il { color: #8A4600 } /* Literal.Number.Integer.Long */
.codehilite.github-light-high-contrast .hll { background-color: #0969da4a }
.codehilite.github-light-high-contrast { background: #ffffff; color: #24292F }
.codehilite.github-light-high-contrast .c { color: #66707B } /* Comment */
.codehilite.github-light-high-contrast .err { color: #A0111F } /* Error */
.codehilite.github-light-high-contrast .k { color: #A0111F } /* Keyword */
.codehilite.github-light-high-contrast .l { color: #702C00 } /* Literal */
.codehilite.github-light-high-contrast .n { color: #622CBC } /* Name */
.codehilite.github-light-high-contrast .o { color: #024C1A } /* Operator */
.codehilite.github-light-high-contrast .p { color: #24292F } /* Punctuation */
.codehilite.github-light-high-contrast .ch { color: #66707B } /* Comment.Hashbang */
.codehilite.github-light-high-contrast .cm { color: #66707B } /* Comment.Multiline */
.codehilite.github-light-high-contrast .cp { color: #66707B } /* Comment.Preproc */
.codehilite.github-light-high-contrast .cpf { color: #66707B } /* Comment.PreprocFile */
.codehilite.github-light-high-contrast .c1 { color: #66707B } /* Comment.Single */
.codehilite.github-light-high-contrast .cs { color: #66707B } /* Comment.Special */
.codehilite.github-light-high-contrast .gd { color: #023B95 } /* Generic.Deleted */
.codehilite.github-light-high-contrast .ge { font-style: italic } /* Generic.Emph */
.codehilite.github-light-high-contrast .gr { color: #A0111F } /* Generic.Error */
.codehilite.github-light-high-contrast .gh { color: #023B95 } /* Generic.Heading */
.codehilite.github-light-high-contrast .gs { font-weight: bold } /* Generic.Strong */
.codehilite.github-light-high-contrast .gu { color: #023B95 } /* Generic.Subheading */
.codehilite.github-light-high-contrast .kc { color: #023B95 } /* Keyword.Constant */
.codehilite.github-light-high-contrast .kd { color: #A0111F } /* Keyword.Declaration */
.codehilite.github-light-high-contrast .kn { color: #A0111F } /* Keyword.Namespace */
.codehilite.github-light-high-contrast .kp { color: #A0111F } /* Keyword.Pseudo */
.codehilite.github-light-high-contrast .kr { color: #A0111F } /* Keyword.Reserved */
.codehilite.github-light-high-contrast .kt { color: #A0111F } /* Keyword.Type */
.codehilite.github-light-high-contrast .ld { color: #702C00 } /* Literal.Date */
.codehilite.github-light-high-contrast .m { color: #702C00 } /* Literal.Number */
.codehilite.github-light-high-contrast .s { color: #023B95 } /* Literal.String */
.codehilite.github-light-high-contrast .na { color: #702C00 } /* Name.Attribute */
.codehilite.github-light-high-contrast .nb { color: #702C00 } /* Name.Builtin */
.codehilite.github-light-high-contrast .nc { color: #023B95 } /* Name.Class */
.codehilite.github-light-high-contrast .no { color: #023B95 } /* Name.Constant */
.codehilite.github-light-high-contrast .nd { color: #702C00 } /* Name.Decorator */
.codehilite.github-light-high-contrast .ni { color: #024C1A } /* Name.Entity */
.codehilite.github-light-high-contrast .ne { color: #622CBC } /* Name.Exception */
.codehilite.github-light-high-contrast .nf { color: #023B95 } /* Name.Function */
.codehilite.github-light-high-contrast .nl { color: #702C00 } /* Name.Label */
.codehilite.github-light-high-contrast .nn { color: #24292F } /* Name.Namespace */
.codehilite.github-light-high-contrast .nx { color: #622CBC } /* Name.Other */
.codehilite.github-light-high-contrast .py { color: #023B95 } /* Name.Property */
.codehilite.github-light-high-contrast .nt { color: #024C1A } /* Name.Tag */
.codehilite.github-light-high-contrast .nv { color: #702C00 } /* Name.Variable */
.codehilite.github-light-high-contrast .ow { color: #622CBC } /* Operator.Word */
.codehilite.github-light-high-contrast .pm { color: #24292F } /* Punctuation.Marker */
.codehilite.github-light-high-contrast .w { color: #24292F } /* Text.Whitespace */
.codehilite.github-light-high-contrast .mb { color: #702C00 } /* Literal.Number.Bin */
.codehilite.github-light-high-contrast .mf { color: #702C00 } /* Literal.Number.Float */
.codehilite.github-light-high-contrast .mh { color: #702C00 } /* Literal.Number.Hex */
.codehilite.github-light-high-contrast .mi { color: #702C00 } /* Literal.Number.Integer */
.codehilite.github-light-high-contrast .mo { color: #702C00 } /* Literal.Number.Oct */
.codehilite.github-light-high-contrast .sa { color: #023B95 } /* Literal.String.Affix */
.codehilite.github-light-high-contrast .sb { color: #023B95 } /* Literal.String.Backtick */
.codehilite.github-light-high-contrast .sc { color: #023B95 } /* Literal.String.Char */
.codehilite.github-light-high-contrast .dl { color: #023B95 } /* Literal.String.Delimiter */
.codehilite.github-light-high-contrast .sd { color: #023B95 } /* Literal.String.Doc */
.codehilite.github-light-high-contrast .s2 { color: #023B95 } /* Literal.String.Double */
.codehilite.github-light-high-contrast .se { color: #023B95 } /* Literal.String.Escape */
.codehilite.github-light-high-contrast .sh { color: #023B95 } /* Literal.String.Heredoc */
.codehilite.github-light-high-contrast .si { color: #023B95 } /* Literal.String.Interpol */
.codehilite.github-light-high-contrast .sx { color: #023B95 } /* Literal.String.Other */
.codehilite.github-light-high-contrast .sr { color: #023B95 } /* Literal.String.Regex */
.codehilite.github-light-high-contrast .s1 { color: #023B95 } /* Literal.String.Single */
.codehilite.github-light-high-contrast .ss { color: #023B95 } /* Literal.String.Symbol */
.codehilite.github-light-high-contrast .bp { color: #702C00 } /* Name.Builtin.Pseudo */
.codehilite.github-light-high-contrast .fm { color: #023B95 } /* Name.Function.Magic */
.codehilite.github-light-high-contrast .vc { color: #702C00 } /* Name.Variable.Class */
.codehilite.github-light-high-contrast .vg { color: #702C00 } /* Name.Variable.Global */
.codehilite.github-light-high-contrast .vi { color: #702C00 } /* Name.Variable.Instance */
.codehilite.github-light-high-contrast .vm { color: #702C00 } /* Name.Variable.Magic */
.codehilite.github-light-high-contrast .il { color: #702C00 } /* Literal.Number.Integer.Long */
.codehilite.gotthard-dark .hll { background-color: #4c4b4be8 }
.codehilite.gotthard-dark { background: #000000; color: #F5F5F5 }
.codehilite.gotthard-dark .c { color: #B19DB4 } /* Comment */
.codehilite.gotthard-dark .err { color: #AB6369 } /* Error */
.codehilite.gotthard-dark .k { color: #B19DB4 } /* Keyword */
.codehilite.gotthard-dark .l { color: #B19DB4 } /* Literal */
.codehilite.gotthard-dark .n { color: #F5F5F5 } /* Name */
.codehilite.gotthard-dark .o { color: #6F98B3 } /* Operator */
.codehilite.gotthard-dark .p { color: #F5F5F5 } /* Punctuation */
.codehilite.gotthard-dark .ch { color: #B19DB4 } /* Comment.Hashbang */
.codehilite.gotthard-dark .cm { color: #B19DB4 } /* Comment.Multiline */
.codehilite.gotthard-dark .cp { color: #B19DB4 } /* Comment.Preproc */
.codehilite.gotthard-dark .cpf { color: #B19DB4 } /* Comment.PreprocFile */
.codehilite.gotthard-dark .c1 { color: #B19DB4 } /* Comment.Single */
.codehilite.gotthard-dark .cs { color: #B19DB4 } /* Comment.Special */
.codehilite.gotthard-dark .gd { color: #AB6369 } /* Generic.Deleted */
.codehilite.gotthard-dark .gh { color: #81B19B } /* Generic.Heading */
.codehilite.gotthard-dark .gs { font-weight: bold } /* Generic.Strong */
.codehilite.gotthard-dark .gu { color: #81B19B } /* Generic.Subheading */
.codehilite.gotthard-dark .kc { color: #AB6369 } /* Keyword.Constant */
.codehilite.gotthard-dark .kd { color: #B19DB4 } /* Keyword.Declaration */
.codehilite.gotthard-dark .kn { color: #B19DB4 } /* Keyword.Namespace */
.codehilite.gotthard-dark .kp { color: #B19DB4 } /* Keyword.Pseudo */
.codehilite.gotthard-dark .kr { color: #B19DB4 } /* Keyword.Reserved */
.codehilite.gotthard-dark .kt { color: #81B19B } /* Keyword.Type */
.codehilite.gotthard-dark .ld { color: #B19DB4 } /* Literal.Date */
.codehilite.gotthard-dark .m { color: #AB6369 } /* Literal.Number */
.codehilite.gotthard-dark .s { color: #81B19B } /* Literal.String */
.codehilite.gotthard-dark .na { color: #B19DB4 } /* Name.Attribute */
.codehilite.gotthard-dark .nb { color: #81B19B } /* Name.Builtin */
.codehilite.gotthard-dark .nc { color: #CAAB6D } /* Name.Class */
.codehilite.gotthard-dark .no { color: #AB6369 } /* Name.Constant */
.codehilite.gotthard-dark .nd { color: #81B19B } /* Name.Decorator */
.codehilite.gotthard-dark .ni { color: #81B19B } /* Name.Entity */
.codehilite.gotthard-dark .ne { color: #AB6369 } /* Name.Exception */
.codehilite.gotthard-dark .nf { color: #B19DB4 } /* Name.Function */
.codehilite.gotthard-dark .nl { color: #81B19B } /* Name.Label */
.codehilite.gotthard-dark .nn { color: #CAAB6D } /* Name.Namespace */
.codehilite.gotthard-dark .nx { color: #F5F5F5 } /* Name.Other */
.codehilite.gotthard-dark .py { color: #B19DB4 } /* Name.Property */
.codehilite.gotthard-dark .nt { color: #AB6369 } /* Name.Tag */
.codehilite.gotthard-dark .nv { color: #F5F5F5 } /* Name.Variable */
.codehilite.gotthard-dark .ow { color: #B19DB4 } /* Operator.Word */
.codehilite.gotthard-dark .pm { color: #F5F5F5 } /* Punctuation.Marker */
.codehilite.gotthard-dark .w { color: #F5F5F5 } /* Text.Whitespace */
.codehilite.gotthard-dark .mb { color: #AB6369 } /* Literal.Number.Bin */
.codehilite.gotthard-dark .mf { color: #AB6369 } /* Literal.Number.Float */
.codehilite.gotthard-dark .mh { color: #AB6369 } /* Literal.Number.Hex */
.codehilite.gotthard-dark .mi { color: #AB6369 } /* Literal.Number.Integer */
.codehilite.gotthard-dark .mo { color: #AB6369 } /* Literal.Number.Oct */
.codehilite.gotthard-dark .sa { color: #81B19B } /* Literal.String.Affix */
.codehilite.gotthard-dark .sb { color: #CAAB6D } /* Literal.String.Backtick */
.codehilite.gotthard-dark .sc { color: #81B19B } /* Literal.String.Char */
.codehilite.gotthard-dark .dl { color: #81B19B } /* Literal.String.Delimiter */
.codehilite.gotthard-dark .sd { color: #81B19B } /* Literal.String.Doc */
.codehilite.gotthard-dark .s2 { color: #81B19B } /* Literal.String.Double */
.codehilite.gotthard-dark .se { color: #6F98B3 } /* Literal.String.Escape */
.codehilite.gotthard-dark .sh { color: #81B19B } /* Literal.String.Heredoc */
.codehilite.gotthard-dark .si { color: #81B19B } /* Literal.String.Interpol */
.codehilite.gotthard-dark .sx { color: #81B19B } /* Literal.String.Other */
.codehilite.gotthard-dark .sr { color: #6F98B3 } /* Literal.String.Regex */
.codehilite.gotthard-dark .s1 { color: #81B19B } /* Literal.String.Single */
.codehilite.gotthard-dark .ss { color: #81B19B } /* Literal.String.Symbol */
.codehilite.gotthard-dark .bp { color: #81B19B } /* Name.Builtin.Pseudo */
.codehilite.gotthard-dark .fm { color: #B19DB4 } /* Name.Function.Magic */
.codehilite.gotthard-dark .vc { color: #F5F5F5 } /* Name.Variable.Class */
.codehilite.gotthard-dark .vg { color: #F5F5F5 } /* Name.Variable.Global */
.codehilite.gotthard-dark .vi { color: #F5F5F5 } /* Name.Variable.Instance */
.codehilite.gotthard-dark .vm { color: #F5F5F5 } /* Name.Variable.Magic */
.codehilite.gotthard-dark .il { color: #AB6369 } /* Literal.Number.Integer.Long */
.codehilite.gotthard-light .hll { background-color: #E1E1E1 }
.codehilite.gotthard-light { background: #F5F5F5; color: #141414 }
.codehilite.gotthard-light .c { color: #974EB7 } /* Comment */
.codehilite.gotthard-light .err { color: #9F4E55 } /* Error */
.codehilite.gotthard-light .k { color: #974EB7 } /* Keyword */
.codehilite.gotthard-light .l { color: #974EB7 } /* Literal */
.codehilite.gotthard-light .n { color: #141414 } /* Name */
.codehilite.gotthard-light .o { color: #3D73A9 } /* Operator */
.codehilite.gotthard-light .p { color: #141414 } /* Punctuation */
.codehilite.gotthard-light .ch { color: #974EB7 } /* Comment.Hashbang */
.codehilite.gotthard-light .cm { color: #974EB7 } /* Comment.Multiline */
.codehilite.gotthard-light .cp { color: #974EB7 } /* Comment.Preproc */
.codehilite.gotthard-light .cpf { color: #974EB7 } /* Comment.PreprocFile */
.codehilite.gotthard-light .c1 { color: #974EB7 } /* Comment.Single */
.codehilite.gotthard-light .cs { color: #974EB7 } /* Comment.Special */
.codehilite.gotthard-light .gd { color: #9F4E55 } /* Generic.Deleted */
.codehilite.gotthard-light .gh { color: #437A6B } /* Generic.Heading */
.codehilite.gotthard-light .gs { font-weight: bold } /* Generic.Strong */
.codehilite.gotthard-light .gu { color: #437A6B } /* Generic.Subheading */
.codehilite.gotthard-light .kc { color: #9F4E55 } /* Keyword.Constant */
.codehilite.gotthard-light .kd { color: #974EB7 } /* Keyword.Declaration */
.codehilite.gotthard-light .kn { color: #974EB7 } /* Keyword.Namespace */
.codehilite.gotthard-light .kp { color: #974EB7 } /* Keyword.Pseudo */
.codehilite.gotthard-light .kr { color: #974EB7 } /* Keyword.Reserved */
.codehilite.gotthard-light .kt { color: #437A6B } /* Keyword.Type */
.codehilite.gotthard-light .ld { color: #974EB7 } /* Literal.Date */
.codehilite.gotthard-light .m { color: #9F4E55 } /* Literal.Number */
.codehilite.gotthard-light .s { color: #437A6B } /* Literal.String */
.codehilite.gotthard-light .na { color: #974EB7 } /* Name.Attribute */
.codehilite.gotthard-light .nb { color: #437A6B } /* Name.Builtin */
.codehilite.gotthard-light .nc { color: #98661B } /* Name.Class */
.codehilite.gotthard-light .no { color: #9F4E55 } /* Name.Constant */
.codehilite.gotthard-light .nd { color: #437A6B } /* Name.Decorator */
.codehilite.gotthard-light .ni { color: #437A6B } /* Name.Entity */
.codehilite.gotthard-light .ne { color: #9F4E55 } /* Name.Exception */
.codehilite.gotthard-light .nf { color: #974EB7 } /* Name.Function */
.codehilite.gotthard-light .nl { color: #437A6B } /* Name.Label */
.codehilite.gotthard-light .nn { color: #98661B } /* Name.Namespace */
.codehilite.gotthard-light .nx { color: #141414 } /* Name.Other */
.codehilite.gotthard-light .py { color: #974EB7 } /* Name.Property */
.codehilite.gotthard-light .nt { color: #9F4E55 } /* Name.Tag */
.codehilite.gotthard-light .nv { color: #141414 } /* Name.Variable */
.codehilite.gotthard-light .ow { color: #974EB7 } /* Operator.Word */
.codehilite.gotthard-light .pm { color: #141414 } /* Punctuation.Marker */
.codehilite.gotthard-light .w { color: #141414 } /* Text.Whitespace */
.codehilite.gotthard-light .mb { color: #9F4E55 } /* Literal.Number.Bin */
.codehilite.gotthard-light .mf { color: #9F4E55 } /* Literal.Number.Float */
.codehilite.gotthard-light .mh { color: #9F4E55 } /* Literal.Number.Hex */
.codehilite.gotthard-light .mi { color: #9F4E55 } /* Literal.Number.Integer */
.codehilite.gotthard-light .mo { color: #9F4E55 } /* Literal.Number.Oct */
.codehilite.gotthard-light .sa { color: #437A6B } /* Literal.String.Affix */
.codehilite.gotthard-light .sb { color: #98661B } /* Literal.String.Backtick */
.codehilite.gotthard-light .sc { color: #437A6B } /* Literal.String.Char */
.codehilite.gotthard-light .dl { color: #437A6B } /* Literal.String.Delimiter */
.codehilite.gotthard-light .sd { color: #437A6B } /* Literal.String.Doc */
.codehilite.gotthard-light .s2 { color: #437A6B } /* Literal.String.Double */
.codehilite.gotthard-light .se { color: #3D73A9 } /* Literal.String.Escape */
.codehilite.gotthard-light .sh { color: #437A6B } /* Literal.String.Heredoc */
.codehilite.gotthard-light .si { color: #437A6B } /* Literal.String.Interpol */
.codehilite.gotthard-light .sx { color: #437A6B } /* Literal.String.Other */
.codehilite.gotthard-light .sr { color: #3D73A9 } /* Literal.String.Regex */
.codehilite.gotthard-light .s1 { color: #437A6B } /* Literal.String.Single */
.codehilite.gotthard-light .ss { color: #437A6B } /* Literal.String.Symbol */
.codehilite.gotthard-light .bp { color: #437A6B } /* Name.Builtin.Pseudo */
.codehilite.gotthard-light .fm { color: #974EB7 } /* Name.Function.Magic */
.codehilite.gotthard-light .vc { color: #141414 } /* Name.Variable.Class */
.codehilite.gotthard-light .vg { color: #141414 } /* Name.Variable.Global */
.codehilite.gotthard-light .vi { color: #141414 } /* Name.Variable.Instance */
.codehilite.gotthard-light .vm { color: #141414 } /* Name.Variable.Magic */
.codehilite.gotthard-light .il { color: #9F4E55 } /* Literal.Number.Integer.Long */
.codehilite.greative .hll { background-color: #473d18 }
.codehilite.greative { background: #010726; color: #A2BFFC }
.codehilite.greative .c { color: #797979 } /* Comment */
.codehilite.greative .err { color: #A2BFFC } /* Error */
.codehilite.greative .k { color: #9E86C8 } /* Keyword */
.codehilite.greative .l { color: #A2BFFC } /* Literal */
.codehilite.greative .n { color: #A2BFFC } /* Name */
.codehilite.greative .o { color: #F78C6C } /* Operator */
.codehilite.greative .p { color: #A2BFFC } /* Punctuation */
.codehilite.greative .ch { color: #797979 } /* Comment.Hashbang */
.codehilite.greative .cm { color: #797979 } /* Comment.Multiline */
.codehilite.greative .cp { color: #797979 } /* Comment.Preproc */
.codehilite.greative .cpf { color: #797979 } /* Comment.PreprocFile */
.codehilite.greative .c1 { color: #797979 } /* Comment.Single */
.codehilite.greative .cs { color: #797979 } /* Comment.Special */
.codehilite.greative .gd { color: #A2BFFC } /* Generic.Deleted */
.codehilite.greative .ge { font-style: italic } /* Generic.Emph */
.codehilite.greative .gh { color: #A2BFFC } /* Generic.Heading */
.codehilite.greative .gs { font-weight: bold } /* Generic.Strong */
.codehilite.greative .gu { color: #A2BFFC } /* Generic.Subheading */
.codehilite.greative .kc { color: #9E86C8 } /* Keyword.Constant */
.codehilite.greative .kd { color: #9E86C8 } /* Keyword.Declaration */
.codehilite.greative .kn { color: #9E86C8 } /* Keyword.Namespace */
.codehilite.greative .kp { color: #9E86C8 } /* Keyword.Pseudo */
.codehilite.greative .kr { color: #9E86C8 } /* Keyword.Reserved */
.codehilite.greative .kt { color: #C5E478 } /* Keyword.Type */
.codehilite.greative .ld { color: #A2BFFC } /* Literal.Date */
.codehilite.greative .m { color: #9E86C8 } /* Literal.Number */
.codehilite.greative .s { color: #9E8741 } /* Literal.String */
.codehilite.greative .na { color: #9E86C8 } /* Name.Attribute */
.codehilite.greative .nb { color: #C5E478 } /* Name.Builtin */
.codehilite.greative .nc { color: #F78C6C } /* Name.Class */
.codehilite.greative .no { color: #A2BFFC } /* Name.Constant */
.codehilite.greative .nd { color: #9E8741 } /* Name.Decorator */
.codehilite.greative .ni { color: #9E8741 } /* Name.Entity */
.codehilite.greative .ne { color: #A2BFFC } /* Name.Exception */
.codehilite.greative .nf { color: #9E86C8 } /* Name.Function */
.codehilite.greative .nl { color: #F78C6C } /* Name.Label */
.codehilite.greative .nn { color: #C5E478 } /* Name.Namespace */
.codehilite.greative .nx { color: #A2BFFC } /* Name.Other */
.codehilite.greative .py { color: #A2BFFC } /* Name.Property */
.codehilite.greative .nt { color: #5CA7E4 } /* Name.Tag */
.codehilite.greative .nv { color: #C5E478 } /* Name.Variable */
.codehilite.greative .ow { color: #9E86C8 } /* Operator.Word */
.codehilite.greative .pm { color: #A2BFFC } /* Punctuation.Marker */
.codehilite.greative .w { color: #A2BFFC } /* Text.Whitespace */
.codehilite.greative .mb { color: #9E86C8 } /* Literal.Number.Bin */
.codehilite.greative .mf { color: #9E86C8 } /* Literal.Number.Float */
.codehilite.greative .mh { color: #9E86C8 } /* Literal.Number.Hex */
.codehilite.greative .mi { color: #9E86C8 } /* Literal.Number.Integer */
.codehilite.greative .mo { color: #9E86C8 } /* Literal.Number.Oct */
.codehilite.greative .sa { color: #9E8741 } /* Literal.String.Affix */
.codehilite.greative .sb { color: #9E8741 } /* Literal.String.Backtick */
.codehilite.greative .sc { color: #9E8741 } /* Literal.String.Char */
.codehilite.greative .dl { color: #9E8741 } /* Literal.String.Delimiter */
.codehilite.greative .sd { color: #9E8741 } /* Literal.String.Doc */
.codehilite.greative .s2 { color: #9E8741 } /* Literal.String.Double */
.codehilite.greative .se { color: #F78C6C } /* Literal.String.Escape */
.codehilite.greative .sh { color: #9E8741 } /* Literal.String.Heredoc */
.codehilite.greative .si { color: #9E8741 } /* Literal.String.Interpol */
.codehilite.greative .sx { color: #9E8741 } /* Literal.String.Other */
.codehilite.greative .sr { color: #5CA7E4 } /* Literal.String.Regex */
.codehilite.greative .s1 { color: #9E8741 } /* Literal.String.Single */
.codehilite.greative .ss { color: #F78C6C } /* Literal.String.Symbol */
.codehilite.greative .bp { color: #C5E478 } /* Name.Builtin.Pseudo */
.codehilite.greative .fm { color: #9E86C8 } /* Name.Function.Magic */
.codehilite.greative .vc { color: #C5E478 } /* Name.Variable.Class */
.codehilite.greative .vg { color: #C5E478 } /* Name.Variable.Global */
.codehilite.greative .vi { color: #C5E478 } /* Name.Variable.Instance */
.codehilite.greative .vm { color: #F78C6C } /* Name.Variable.Magic */
.codehilite.greative .il { color: #9E86C8 } /* Literal.Number.Integer.Long */
.codehilite.pitaya-smoothie .hll { background-color: #2A1968 }
.codehilite.pitaya-smoothie { background: #181036; color: #FEFEFF }
.codehilite.pitaya-smoothie .c { color: #8786AC } /* Comment */
.codehilite.pitaya-smoothie .err { color: #F26196 } /* Error */
.codehilite.pitaya-smoothie .k { color: #FAD000 } /* Keyword */
.codehilite.pitaya-smoothie .l { color: #F5A394 } /* Literal */
.codehilite.pitaya-smoothie .n { color: #FEFEFF } /* Name */
.codehilite.pitaya-smoothie .o { color: #18C1C4 } /* Operator */
.codehilite.pitaya-smoothie .p { color: #FEFEFF } /* Punctuation */
.codehilite.pitaya-smoothie .ch { color: #8786AC } /* Comment.Hashbang */
.codehilite.pitaya-smoothie .cm { color: #8786AC } /* Comment.Multiline */
.codehilite.pitaya-smoothie .cp { color: #8786AC } /* Comment.Preproc */
.codehilite.pitaya-smoothie .cpf { color: #8786AC } /* Comment.PreprocFile */
.codehilite.pitaya-smoothie .c1 { color: #8786AC } /* Comment.Single */
.codehilite.pitaya-smoothie .cs { color: #8786AC } /* Comment.Special */
.codehilite.pitaya-smoothie .gd { color: #7998F2 } /* Generic.Deleted */
.codehilite.pitaya-smoothie .ge { font-style: italic } /* Generic.Emph */
.codehilite.pitaya-smoothie .gh { color: #7998F2 } /* Generic.Heading */
.codehilite.pitaya-smoothie .gs { font-weight: bold } /* Generic.Strong */
.codehilite.pitaya-smoothie .gu { color: #7998F2 } /* Generic.Subheading */
.codehilite.pitaya-smoothie .kc { color: #C4A2F5 } /* Keyword.Constant */
.codehilite.pitaya-smoothie .kd { color: #FAD000 } /* Keyword.Declaration */
.codehilite.pitaya-smoothie .kn { color: #FAD000 } /* Keyword.Namespace */
.codehilite.pitaya-smoothie .kp { color: #FAD000 } /* Keyword.Pseudo */
.codehilite.pitaya-smoothie .kr { color: #FAD000 } /* Keyword.Reserved */
.codehilite.pitaya-smoothie .kt { color: #F5A394 } /* Keyword.Type */
.codehilite.pitaya-smoothie .ld { color: #F5A394 } /* Literal.Date */
.codehilite.pitaya-smoothie .m { color: #F5A394 } /* Literal.Number */
.codehilite.pitaya-smoothie .s { color: #7998F2 } /* Literal.String */
.codehilite.pitaya-smoothie .na { color: #FAD000 } /* Name.Attribute */
.codehilite.pitaya-smoothie .nb { color: #C4A2F5 } /* Name.Builtin */
.codehilite.pitaya-smoothie .nc { color: #7998F2 } /* Name.Class */
.codehilite.pitaya-smoothie .no { color: #C4A2F5 } /* Name.Constant */
.codehilite.pitaya-smoothie .nd { color: #F5A394 } /* Name.Decorator */
.codehilite.pitaya-smoothie .ni { color: #7998F2 } /* Name.Entity */
.codehilite.pitaya-smoothie .ne { color: #C4A2F5 } /* Name.Exception */
.codehilite.pitaya-smoothie .nf { color: #7998F2 } /* Name.Function */
.codehilite.pitaya-smoothie .nl { color: #F5A394 } /* Name.Label */
.codehilite.pitaya-smoothie .nn { color: #FEFEFF } /* Name.Namespace */
.codehilite.pitaya-smoothie .nx { color: #FEFEFF } /* Name.Other */
.codehilite.pitaya-smoothie .py { color: #7998F2 } /* Name.Property */
.codehilite.pitaya-smoothie .nt { color: #7998F2 } /* Name.Tag */
.codehilite.pitaya-smoothie .nv { color: #F5A394 } /* Name.Variable */
.codehilite.pitaya-smoothie .ow { color: #C4A2F5 } /* Operator.Word */
.codehilite.pitaya-smoothie .pm { color: #FEFEFF } /* Punctuation.Marker */
.codehilite.pitaya-smoothie .w { color: #FEFEFF } /* Text.Whitespace */
.codehilite.pitaya-smoothie .mb { color: #F5A394 } /* Literal.Number.Bin */
.codehilite.pitaya-smoothie .mf { color: #F5A394 } /* Literal.Number.Float */
.codehilite.pitaya-smoothie .mh { color: #F5A394 } /* Literal.Number.Hex */
.codehilite.pitaya-smoothie .mi { color: #F5A394 } /* Literal.Number.Integer */
.codehilite.pitaya-smoothie .mo { color: #F5A394 } /* Literal.Number.Oct */
.codehilite.pitaya-smoothie .sa { color: #7998F2 } /* Literal.String.Affix */
.codehilite.pitaya-smoothie .sb { color: #66E9EC } /* Literal.String.Backtick */
.codehilite.pitaya-smoothie .sc { color: #7998F2 } /* Literal.String.Char */
.codehilite.pitaya-smoothie .dl { color: #7998F2 } /* Literal.String.Delimiter */
.codehilite.pitaya-smoothie .sd { color: #C4A2F5 } /* Literal.String.Doc */
.codehilite.pitaya-smoothie .s2 { color: #7998F2 } /* Literal.String.Double */
.codehilite.pitaya-smoothie .se { color: #F5A394 } /* Literal.String.Escape */
.codehilite.pitaya-smoothie .sh { color: #7998F2 } /* Literal.String.Heredoc */
.codehilite.pitaya-smoothie .si { color: #7998F2 } /* Literal.String.Interpol */
.codehilite.pitaya-smoothie .sx { color: #7998F2 } /* Literal.String.Other */
.codehilite.pitaya-smoothie .sr { color: #7998F2 } /* Literal.String.Regex */
.codehilite.pitaya-smoothie .s1 { color: #7998F2 } /* Literal.String.Single */
.codehilite.pitaya-smoothie .ss { color: #7998F2 } /* Literal.String.Symbol */
.codehilite.pitaya-smoothie .bp { color: #F5A394 } /* Name.Builtin.Pseudo */
.codehilite.pitaya-smoothie .fm { color: #7998F2 } /* Name.Function.Magic */
.codehilite.pitaya-smoothie .vc { color: #F5A394 } /* Name.Variable.Class */
.codehilite.pitaya-smoothie .vg { color: #F5A394 } /* Name.Variable.Global */
.codehilite.pitaya-smoothie .vi { color: #F5A394 } /* Name.Variable.Instance */
.codehilite.pitaya-smoothie .vm { color: #F5A394 } /* Name.Variable.Magic */
.codehilite.pitaya-smoothie .il { color: #F5A394 } /* Literal.Number.Integer.Long */
